
	/* =============================================================================
		Project				: 	India poverty estimates - 2011-12 & 2022-23 
		File purpose		:   Master do file: repository of all the work
		Authors				: 	Poverty and Equity India Team
	============================================================================= */

	clear all
	set logtype text
	cap log close
	set more off
	set maxvar 10000
	
	/* -----------------------------------------------------------------------------
					2. Set Working Directory
	----------------------------------------------------------------------------- */
	* Update the path manually

		global user	"C:/WBG/Rep-checks/RR_IND_2025_344"
		
		sysdir set PLUS "$user/code/ado"

	/* -----------------------------------------------------------------------------
					2. Install programs 
	----------------------------------------------------------------------------- */
 	
	* this are commented because the packages are already included in the code/ado folder
	/*
	ssc install fastreshape, all replace
 	ssc install ainequal, all replace
 	ssc install distinct, all replace
 	ssc install mdesc, all replace
 	ssc install egenmore, all replace
	ssc install glcurve, all replace
	ssc install unique, replace
    ssc install _gwmean, replace
    ssc install winsor2, all replace
    ssc install fre, all replace
	ssc install estout, all replace
    */

	* -----------------------------------------------------------------------------
	*				3. Create folder structure - Run ONLY once
	*------------------------------------------------------------------------------*

	*Three main folders 

	mkdir "${user}\\output" 
	
	*Subfolders for main output
	mkdir "${user}\\output\\excel"
	mkdir "${user}\\output\\figures"
	mkdir "${user}\\output\\log"
	
	*Subfolder for data processed by the team within data folder
	mkdir "${user}\\data\\processed"
	mkdir "${user}\\data\\processed\\ces"
	mkdir "${user}\\data\\processed\\ces\\temp"	
	mkdir "${user}\\data\\processed\\ces\\sensitivity_checks"
	mkdir "${user}\\data\\processed\\ces\\sensitivity_checks\\outliers"	
	mkdir "${user}\\data\\processed\\ces\\sensitivity_checks\\inter_temporal"
	mkdir "${user}\\data\\processed\\ces\\sensitivity_checks\\inter_temporal\\temp"	
	mkdir "${user}\\data\\processed\\ces\\sensitivity_checks\\add_housing"	
	mkdir "${user}\\data\\processed\\ces\\sensitivity_checks\\hhsize"	
	mkdir "${user}\\data\\processed\\other"
	
	*Subfolders for output of Sensivity to outliers correction
	mkdir "${user}\\output\\sensitivity_checks"
	mkdir "${user}\\output\\sensitivity_checks\\outliers"
	mkdir "${user}\\output\\sensitivity_checks\\outliers\\log"	
	
	mkdir "${user}\\output\\sensitivity_checks\\inter_temporal"
	mkdir "${user}\\output\\sensitivity_checks\\inter_temporal\\log"	
	
	mkdir "${user}\\output\\sensitivity_checks\\add_housing"
	mkdir "${user}\\output\\sensitivity_checks\\add_housing\\log"	
		
	mkdir "${user}\\output\\sensitivity_checks\\hhsize"
	mkdir "${user}\\output\\sensitivity_checks\\hhsize\\log"
	
	/*-----------------------------------------------------------------------------
					6. Run Core do files
	----------------------------------------------------------------------------- */

	*Data cleaning

	do "${user}/code/01_ces_clean.do"
	do "${user}/code/01a_cpi_clean.do"
	do "${user}/code/01b_population_MoH.do"
	
	*Master datasets
	
	do "${user}/code/02_master_datasets_create.do"  	
	do "${user}/code/02a_match_survey_cpi_items_2011.do"
	do "${user}/code/02b_match_survey_cpi_items_2022.do"

	*Imputation of food and non-food subsidies

	do "${user}/code/02c_PDS_imputation_2011.do" 	
	do "${user}/code/02d_PDS_imputation_2022.do" 	
	do "${user}/code/02e_nonfood_school_imputation_2022.do" 	
	
	*************************************************
	*Execution of do file sequence for each scenario
	*************************************************
	
	*A) Baseline Scenario 

	global s ""

	do "${user}/code/03_consumption_adjustments.do" 
	do "${user}/code/04_deflators_wy.do" 
	do "${user}/code/05_deflators_spatial.do" //only need to run once for baseline scenario
	do "${user}/code/06_welfare_agg.do"
				
	macro drop s
	
	*B) Impute food and non-food subsidies
	
	 global s "_pds" 
		
	do "${user}/code/03_consumption_adjustments.do" 
	do "${user}/code/04_deflators_wy.do" 
	do "${user}/code/06_welfare_agg.do"

	macro drop s
	
	*C) Remove lumpy expenditures 	
		
	global s "_lumpexp" 

	do "${user}/code/03_consumption_adjustments.do" 
	do "${user}/code/04_deflators_wy.do" 
	do "${user}/code/06_welfare_agg.do"

	macro drop s
	
	*D) Remove rents 
	
	global s "_rent" 
	
	do "${user}/code/03_consumption_adjustments.do" 
	do "${user}/code/04_deflators_wy.do" 
	do "${user}/code/06_welfare_agg.do"

	macro drop s
	
	*E) Remove hospitlization expenditures 
	
	global s "_hosp" 
	
	do "${user}/code/03_consumption_adjustments.do" 
	do "${user}/code/04_deflators_wy.do" 
	do "${user}/code/06_welfare_agg.do"
	
	macro drop s
	
	*E) All adjustment simulteanously 

	global s "_all" 

	do "${user}/code/03_consumption_adjustments.do" 
	do "${user}/code/04_deflators_wy.do" 
	do "${user}/code/06_welfare_agg.do"
	do "${user}/code/07_pov_ineq.do"  //only for all adjustmens
	
	macro drop s
	
	/* -----------------------------------------------------------------------------
					8. Other sensitivity dofiles
	----------------------------------------------------------------------------- */
	*1. Outliers checks
		
	global zs "_out3_all"   // outliers check using real WA at 3 sd
	do "${user}/code/sensitivity_checks/outliers/04_outliers_flags_deflators_wy.do" 
	do "${user}/code/sensitivity_checks/outliers/06_outliers_welfare_agg.do" 	
	do "${user}/code/sensitivity_checks/outliers/07_outliers_pov_ineq.do" 	
	macro drop s
	macro drop zs
	
	global zs "_out4_all" // outliers check using real WA at 4 sd
	do "${user}/code/sensitivity_checks/outliers/04_outliers_flags_deflators_wy.do" 
	do "${user}/code/sensitivity_checks/outliers/06_outliers_welfare_agg.do" 	
	do "${user}/code/sensitivity_checks/outliers/07_outliers_pov_ineq.do" 
	macro drop s
	macro drop zs
		
	*2. Inter-temporal deflators using survey unit values
 	do "${user}/code/sensitivity_checks/inter_temporal/05_intertemporal_uv_v1.do" 
 	do "${user}/code/sensitivity_checks/inter_temporal/05_intertemporal_uv_v2.do"
 	do "${user}/code/sensitivity_checks/inter_temporal/06_intertemporal_welfare_agg.do"
 	do "${user}/code/sensitivity_checks/inter_temporal/07_intertemporal_pov_ineq.do"	

	*5. Use household size from corresponding schedule instead of Food questionnaire

	do "${user}/code/sensitivity_checks/hhsize/06_welfare_agg_h3.do" 
	do "${user}/code/sensitivity_checks/hhsize/06_welfare_agg_h4.do" 
 	do "${user}/code/sensitivity_checks/hhsize/07_pov_ineq_h3.do"
	do "${user}/code/sensitivity_checks/hhsize/07_pov_ineq_h4.do"

	***************************************
	*Export tables and figures for report	
	**************************************	
	do "${user}/code/08_tables.do"
	do "${user}/code/09_figures.do"
	
	exit
	
	*----------------------------------------------------------------------------
	*Housing sensitivity_scenario
	
	do "${user}/code/sensitivity_checks/add_housing/02a_housing_2022_prematch.do"
	*---> (((Run R script 02b_matching_rents_2022.R for matching exercise))) <------
	do "${user}/code/sensitivity_checks/add_housing/02c_housing_2022_postmatch.do"
	do "${user}/code/sensitivity_checks/add_housing/03_consumption_adjustments.do"
	do "${user}/code/sensitivity_checks/add_housing/04_deflators_wy.do"	
	do "${user}/code/sensitivity_checks/add_housing/06_welfare_agg.do"
	do "${user}/code/sensitivity_checks/add_housing/07_pov_ineq.do"
	do "${user}/code/sensitivity_checks/add_housing/09_housing_tables_figures.do"
	
	/* -----------------------------------------------------------------------------
	THE END
	----------------------------------------------------------------------------- */
	
	