	
	loc date: display %tdCCYY-NN-DD =daily("`c(current_date)'", "DMY")
	cap log close
	log using "${user}/output/log/01_ces_clean_`date'", replace

	/* =========================================================================
		Project			: India poverty estimates - 2011-12 & 2022-23 
		Dofile			: 01_clean.do
		Last modified	: 25th March 2025
		Inputs			: "${user}/data/raw/ces"											
		Outputs			: "${user}/data/processed/ces"
		File purpose	: Clean CES 2011-12 raw dta 
						: Convert HCES 2022-23 raw txt data into dta 	
	========================================================================= */

	*This do file imports the raw microdata of the Consumption Expenditure Survey (CES) from MOSPI, cleans it, harmonizes it and labels many variables and dataset names for easiness of the workflow. This process is structured in three steps:
	
	
	* Step 1: 2011-12 Uniform Recall Period        (URP   - Schedule Type 1)
	* Step 2: 2011-12 Mixed Modified Recall Period (MMRRP - Schedule Type 2)
	* Step 3: 2022-23 Mixed Modified Recall Period (MMRP only option)
	

	/* =============================================================================
						Step 1: 2011-12 - URP	(Schedule Type 1)
								
		Step 1: Download the MMRP data from MoSPI's website (README for more information)
		Step 2: Convert the files in dta using NESSTAR 
		Step 3: Save the raw data in raw-ces folder
		Step 4: Rename and destring variables
		Step 5: Save the data (.dta) in processed-ces folder
	==============================================================================*/	
		

	********************************************************************************
	**BLOCKS 1 & 2:  identification of sample household + particulars of field operations
	********************************************************************************

	use "${user}/data/raw/ces/2011-12/URP/block0102_2011_urp.dta", clear
	
	ren HHID hhid
	ren Second_Stage_Stratum_No sss
	ren State_code state
	ren Sector sector
	ren Date_of_Survey survey_date
	ren District district
	ren FSU_Serial_no  fsu
	ren Hamlet_Group_Sub_Stratum_No  hamlet 
	
	destring state, replace
	destring district, replace
	destring sector, replace
	
	label define sector ///
	1 "Rural" ///
	2 "Urban"
	label values sector "sector"
	
	save "${user}/data/processed/ces/block0102_2011_urp.dta", replace

	
	********************************************************************************
	**BLOCK 3A: household characteristics
	********************************************************************************	

	use "${user}/data/raw/ces/2011-12/URP/block03a_2011_urp.dta", clear
	
	ren HHID hhid
	ren HH_Size hhsize
	ren Level level
	ren NSS nss
	ren NSC nsc
	ren MLT mult 
	
	destring hhsize, replace
	
	gen hhwt = mult/200 if nss!=nsc
	replace hhwt = mult/100 if nss==nsc

    save "${user}/data/processed/ces/block03a_2011_urp.dta", replace
	
	
	
	*******************************************************************************
	**BLOCK 3B: household characteristics
	********************************************************************************
			
	use "${user}/data/raw/ces/2011-12/URP/block03b_2011_urp.dta", clear 
		
	ren HHID hhid
	ren Level level
	ren NSS nss
	ren NSC nsc
	ren MLT mult 
	ren Dwelling_unit_Code dwellingcode
	
	destring dwellingcode, replace
	
	gen hhwt = mult/200 if nss!=nsc
	replace hhwt = mult/100 if nss==nsc
		
		
    save "${user}/data/processed/ces/block03b_2011_urp.dta", replace
		
	********************************************************************************
	**BLOCK 4: demographic and other particulars of household members
	********************************************************************************
	
	use "${user}/data/raw/ces/2011-12/URP/block04_2011_urp.dta", clear
	
	
	ren HHID hhid
	ren Level level
	ren NSS nss
	ren NSC nsc
	ren MLT mult 
	ren Relation relation_to_head
	ren Sex sex
	ren Age age
	ren Marital_status marital_status
	ren Education education
	
	gen hhwt = mult/200 if nss!=nsc
	replace hhwt = mult/100 if nss==nsc


	destring relation_to_head, replace
	label define relation ///
	1 "Self" ///
	2 "Spouse of head" ///
	3 "Married child" ///
	4 "Spouse of married child" ///
	5 "Unmarried child" ///
	6 "Grandchild" ///
	7 "Father/Mother/Father-in-law/Mother-in-law" ///
	8 "Brother/Sister/Brother-in-law/Sister-in-law" ///
	9 "Servants/Employees/Other non-relatives"
	label values relation_to_head "relation"
	
	destring marital_status, replace
	label define marital_status ///
	1 "Never married" ///
	2 "Currently married" ///
	3 "Widowed" ///
	4 "Divorced/Separated"
	label values marital_status "marital_status"
	
	destring sex, replace
	label define sex ///
	1 "Male" ///
	2 "Female"
	label values sex "sex"
	
	destring education, replace
	label define education ///
	1 "Not literate" ///
	2 "Literate without formal schooling: through EGS/NFEC/AEC" ///
	3 "Literate without formal schooling: Through TLC" ///
	4 "Literate without formal schooling: Others" ///
	5 "Below primary" ///
	6 "Primary" ///
	7 "Middle" ///
	8 "Secondary" ///
	10 "Higher secondary" ///
	11 "Diploma/Certificate course" ///
	12 "Graduate" ///
	13 "Postgraduate and above"
	label values education "education"
	
	save "${user}/data/processed/ces/block04_2011_urp.dta", replace

	********************************************************************************
	**BLOCK 5 & 6 : Food and Energy
	********************************************************************************	
	use "${user}/data/raw/ces/2011-12/URP/block0506_2011_urp.dta", clear

	ren HHID hhid
	ren Level level
	ren NSS nss
	ren NSC nsc
	ren MLT mult
	ren Item_Code item
	ren Source_Code source
	ren Total_Consumption_Quantity qty_total
	ren Total_Consumption_Value value_total
	
	destring item, replace
	destring source, replace
	destring nss nsc mult, replace

	save "${user}/data/processed/ces/block0506_2011_urp.dta", replace

	
	********************************************************************************
	**BLOCKS 7 & 8: Clothing and Footwear
	********************************************************************************	
	use "${user}/data/raw/ces/2011-12/URP/blocks0708_2011_urp.dta", clear
	
	ren HHID hhid
	ren Level level
	ren NSS nss
	ren NSC nsc
	ren MLT mult
	ren Item_Code item
	
	destring item, replace

	save "${user}/data/processed/ces/blocks0708_2011_urp.dta", replace
	
	********************************************************************************
	**BLOCK 9: Education and Medical
	********************************************************************************
	
	
	use "${user}/data/raw/ces/2011-12/URP/block09_2011_urp.dta", clear
	
	ren HHID hhid
	ren Level level
	ren NSS nss
	ren NSC nsc
	ren MLT mult
	ren Item_Code item
	
	destring item, replace
	

	save "${user}/data/processed/ces/block09_2011_urp.dta", replace

	********************************************************************************
	**BLOCK 10: Miscellaneous
	********************************************************************************
	

	use "${user}/data/raw/ces/2011-12/URP/block10_2011_urp.dta", clear 
	
	ren HHID hhid
	ren Level level
	ren NSS nss
	ren NSC nsc
	ren MLT mult
	rename Item_code item
	
	destring item, replace


	save "${user}/data/processed/ces/block10_2011_urp.dta", replace
	
	********************************************************************************
	**BLOCK 11: Durable goods
	********************************************************************************	

	use "${user}/data/raw/ces/2011-12/URP/block11_2011_urp.dta", clear
	
	ren HHID hhid
	ren Level level
	ren NSS nss
	ren NSC nsc
	ren MLT mult
	ren Item_Code item
	ren Whether_Possesses possess
	
	destring item, replace

	destring possess, replace
	label define yesno ///
	1 "Yes" ///
	2 "No"
	label values possess yesno
	
		
	save "${user}/data/processed/ces/block11_2011_urp.dta", replace
	
	********************************************************************************
	**BLOCK 12: Summary of expenditure
	********************************************************************************		

	use "${user}/data/raw/ces/2011-12/URP/block12_2011_urp.dta", clear
	
	ren HHID hhid
	ren Level level
	ren NSS nss
	ren NSC nsc
	ren MLT mult


	save "${user}/data/processed/ces/block12_2011_urp.dta", replace
	
	***************************************************
	**BLOCK 13 : Ayurveda, Yoga, etc
	*****************************************************
	

	use "${user}/data/raw/ces/2011-12/URP/block13_2011_urp.dta", clear

	save "${user}/data/processed/ces/block13_2011_urp.dta", replace
	

	
	
	/* =============================================================================
			Step 2: 2011-12 - Mixed Modified Recall Period (MMRP: Schedule Type 2)
								
		Step 1: Download the MMRP data from MoSPI's website (README for more information)
		Step 2: Convert the files in dta using NESSTAR 
		Step 3: Save the raw data in raw-ces folder
		Step 4: Rename and destring variables
		Step 5: Save the data (.dta) in processed-ces folder
	==============================================================================*/

	************************************************************************************
	* BLOCKS 1 & 2:  identification of sample household + particulars of field operations
	************************************************************************************

	use "${user}/data/raw/ces/2011-12/MMRP/block0102_2011_mmrp.dta", clear
	
	ren Date_of_Survey date_of_survey
	ren HHID hhid
	ren District district
	ren State_code state
	ren Sector sector
	ren FSU_Serial_No fsu
	ren Stratum stratum
	ren Second_Stage_Stratum_No sss
	ren Round round
	ren Hamlet_Group_Sub_Stratum_no hamlet
	ren Sample_hhld_no hhserial 
	
	destring sector, replace
	destring state, replace
	destring district, replace 
	
	label define sector ///
	1 "Rural" ///
	2 "Urban" 
	
	label value sector "sector"
	
	save "${user}/data/processed/ces/block0102_2011_mmrp.dta", replace

	****************************************	
	* BLOCK 3A: household characteristics
	****************************************

	use "${user}/data/raw/ces/2011-12/MMRP/block03a_2011_mmrp.dta", clear
	rename HHID hhid
	rename Second_Stage_Stratum_No sss
	rename Level level
	rename NSS nss
	rename NSC nsc
	rename MLT mult 
	rename hh_size hhsize
	
	destring hhsize, replace
	
	lab var sss "Second Stage Stratum"
		
	gen hhwt = mult/200 if nss!=nsc
	replace hhwt = mult/100 if nss==nsc
	
	gen pwt = hhwt*hhsize
	
	save "${user}/data/processed/ces/block03a_2011_mmrp.dta", replace

	
	**************************************	
	* BLOCK 3B: household characteristics
	**************************************

	use "${user}/data/raw/ces/2011-12/MMRP/block03b_2011_mmrp.dta", clear 
	
	ren HHID hhid
	ren Level level
	ren NSS nss
	ren NSC nsc
	ren MLT mult 
	ren Dwelling_unit_code dwellingcode
	
	destring dwellingcode, replace
	
	gen hhwt = mult/200 if nss!=nsc
	replace hhwt = mult/100 if nss==nsc
	
	
	save "${user}/data/processed/ces/block03b_2011_mmrp.dta", replace
	

	******************************************************************	
	* BLOCK 4: demographic and other particulars of household members
	******************************************************************
	
	use "${user}/data/raw/ces/2011-12/MMRP/block04_2011_mmrp.dta", clear
	
		
	ren HHID hhid
	ren Level level
	ren NSS nss
	ren NSC nsc
	ren MLT mult 
	ren Relation relation_to_head
	ren Sex sex
	ren Age age
	ren Marital_Status marital_status
	ren Education education
	
	gen hhwt = mult/200 if nss!=nsc
	replace hhwt = mult/100 if nss==nsc


	destring relation_to_head, replace
	label define relation ///
	1 "Self" ///
	2 "Spouse of head" ///
	3 "Married child" ///
	4 "Spouse of married child" ///
	5 "Unmarried child" ///
	6 "Grandchild" ///
	7 "Father/Mother/Father-in-law/Mother-in-law" ///
	8 "Brother/Sister/Brother-in-law/Sister-in-law" ///
	9 "Servants/Employees/Other non-relatives"
	label values relation_to_head "relation"
	
	destring marital_status, replace
	label define marital_status ///
	1 "Never married" ///
	2 "Currently married" ///
	3 "Widowed" ///
	4 "Divorced/Separated"
	label values marital_status "marital_status"
	
	destring sex, replace
	label define sex ///
	1 "Male" ///
	2 "Female"
	label values sex "sex"
	
	destring education, replace
	label define education ///
	1 "Not literate" ///
	2 "Literate without formal schooling: through EGS/NFEC/AEC" ///
	3 "Literate without formal schooling: Through TLC" ///
	4 "Literate without formal schooling: Others" ///
	5 "Below primary" ///
	6 "Primary" ///
	7 "Middle" ///
	8 "Secondary" ///
	10 "Higher secondary" ///
	11 "Diploma/Certificate course" ///
	12 "Graduate" ///
	13 "Postgraduate and above"
	label values education "education"
	
	save "${user}/data/processed/ces/block04_2011_mmrp.dta", replace

	
	
	********************************
	*BLOCK 5 & 6 : Food and Energy
	********************************
	use "${user}/data/raw/ces/2011-12/MMRP/block0506_2011_mmrp.dta", clear
	
	ren HHID hhid
	ren Level level
	ren NSS nss
	ren NSC nsc
	ren MLT mult 
	
	ren Item_Code item
	ren Total_Consumption_Quantity qty_total
	ren Total_Consumption_Value value_total
	ren Source source
	rename Second_Stage_Stratum_No sss
		
	destring source, replace 
	destring item, replace
	
	lab var sss "Second Stage Stratum"
	
	gen hhwt = mult/200 if nss!=nsc
	replace hhwt = mult/100 if nss==nsc
	label variable hhwt "household weight"
		
		
		
	save "${user}/data/processed/ces/block0506_2011_mmrp.dta", replace

	**************************************
	* BLOCKS 7 & 8: Clothing and Footwear
	**************************************
	use "${user}/data/raw/ces/2011-12/MMRP/blocks0708_2011_mmrp.dta", clear
	
	ren HHID hhid
	ren Level level
	ren NSS nss
	ren NSC nsc
	ren MLT mult 
	ren Item_Code item
	ren Second_Stage_Stratum_No sss
	ren Last_365_days_Quantity_or_no qty_total
	ren Last_365_days_Value value_total
	
	destring item, replace

	gen hhwt = mult/200 if nss!=nsc
	replace hhwt = mult/100 if nss==nsc

	save "${user}/data/processed/ces/blocks0708_2011_mmrp.dta", replace

	*********************************
	* BLOCK 9: Education and Medical
	*********************************

	use "${user}/data/raw/ces/2011-12/MMRP/block09_2011_mmrp.dta", clear
	
	ren HHID hhid
	ren Level level
	ren NSS nss
	ren NSC nsc
	ren MLT mult 
	ren Second_Stage_Stratum_No sss
	ren Item_Code item
	ren Value value_total
	
	destring nss nsc mult, replace
	destring item, replace
	
	gen hhwt = mult/200 if nss!=nsc
	replace hhwt = mult/100 if nss==nsc
	
	save "${user}/data/processed/ces/block09_2011_mmrp.dta", replace

	**************************
	* BLOCK 10: Miscellaneous
	**************************
	
	use "${user}/data/raw/ces/2011-12/MMRP/block10_2011_mmrp.dta", clear
	
	rename HHID hhid
	rename Level level
	rename NSS nss
	rename NSC nsc
	rename MLT mult 
	rename Value value_total
	rename Second_Stage_Stratum_No sss
	rename Item_Code item
	
	destring item, replace
	
	lab var sss "Second Stage Stratum"
	
	gen hhwt = mult/200 if nss!=nsc
	replace hhwt = mult/100 if nss==nsc

	save "${user}/data/processed/ces/block10_2011_mmrp.dta", replace

	***************************
	* BLOCK 11: Durable goods
	***************************

	use "${user}/data/raw/ces/2011-12/MMRP/block11_2011_mmrp.dta", clear
	
	ren HHID hhid
	ren Level level
	ren NSS nss
	ren NSC nsc
	ren MLT mult
	ren Second_Stage_Stratum_No sss
	ren Item_Code item
	ren Total_expenditure_365_days value_total
	ren Whether_possesses possess_yn
	ren First_hand_purchase_number_365_d first_hand_num
	ren whether_hire_purchased_365_days hired
	ren First_hand_purchase_Value_365_da first_hand_value
	ren Cost_raw_material_service_repair repair_maint_cost 
	ren Second_hand_purchase_Number_365_ second_hand_num 
	ren Second_hand_purchase_Value_365_d second_hand_value
	
	destring item, replace
	
	lab var sss "Second Stage Stratum"
		
	gen hhwt = mult/200 if nss!=nsc
	replace hhwt = mult/100 if nss==nsc

	save "${user}/data/processed/ces/block11_2011_mmrp.dta", replace

	
	***********************************	
	* BLOCK 12: Summary of expenditure
	***********************************

	use "${user}/data/raw/ces/2011-12/MMRP/block12_2011_mmrp.dta", clear

	ren HHID hhid
	ren Level level
	ren NSS nss
	ren NSC nsc
	ren MLT mult
	
	
	save "${user}/data/processed/ces/block12_2011_mmrp.dta", replace
	
	
	**********************************	
	* BLOCK 13 : Ayurveda, Yoga, etc
	**********************************

    use "${user}/data/raw/ces/2011-12/MMRP/block13_2011_mmrp.dta", clear 

	save "${user}/data/processed/ces/block13_2011_mmrp.dta", replace

	
	
	
	/* =============================================================================
							Step 3: 2022-23 (only MMRP exists)
		Step 1: Download txt data from MoSPI's website (README for more information)
		Step 2: Destring and label variables 
		Step 3: Save the data (.dta) in processed-ces folder
	==============================================================================*/

	*********************************************
	* Level 1 - Household Characteristics (HCQ)
	*********************************************	
	use "${user}/data/raw/ces/2022-23/level01_2022.dta", clear
	
	ren survey_name survey
	ren sub_sample subsample
	ren fod_subregion fod_subsample
	ren b1q1pt7 sample_su
	ren b1q1pt10 sample_subdivision
	ren b1q1pt11 sss
	ren b1q1pt12 hhno
	ren b1q1pt13 survey_code
	ren b1q1pt14 reason_substitute
	
	tostring year, replace
	destring mult, replace

	egen hhid = concat(fsu sss hhno)
	gen hhwt = mult/100
	
	label variable hhid "Unique household id"
	label variable hhwt "Household weight"
		
	destring sector, replace
	label define sector ///
	1 "rural" ///
	2 "urban"
	label values sector "sector"
	
	destring state, replace
	label define state ///
	28 "Andhra Pradesh" ///
	12 "Arunachal Pradesh" ///
	18 "Assam" ///
	10 "Bihar" ///
	22 "Chattisgarh" ///
	7 "Delhi" ///
	30 "Goa" ///
	24 "Gujarat" ///
	6 "Haryana" ///
	2 "Himachal Pradesh" ///
	20 "Jharkhand" ///
	29 "Karnataka" ///
	32 "Kerala" ///
	23 "Madhya Pradesh" ///
	27 "Maharashtra" ///
	14 "Manipur" ///
	17 "Meghalaya" ///
	15 "Mizoram" ///
	13 "Nagaland" ///
	21 "Odisha" ///
	3 "Punjab" ///
	8 "Rajasthan" ///
	11 "Sikkim" ///
	33 "Tamil Nadu" ///
	36 "Telangana" ///
	16 "Tripura" ///
	5 "Uttrakhand" ///
	9 "Uttar Pradesh" ///
	19 "West Bengal" ///
	35 "Andaman and Nicobar Islands" ///
	4 "Chandigarh" ///
	25 "Dadra Nagar Haveli & Diu Daman" ///
	1 "Jammu and Kashmir" ///
	37 "Ladakh" ///
	31 "Lakshadweep" ///
	34 "Puducherry" 
	label values state "state"
	
	destring panel, replace
	label define panel ///
	1 "August - October 2022" ///
	2 "September - November 2022" ///
	3 "October - December 2022" ///
	4 "November 2022-January 2023" ///
	5 "December 2022 -February 2023" ///
	6 "January - March 2023" ///
	7 "February - April 2023" ///
	8 "March - May 2023" ///
	9 "April - June 2023" ///
	10 "May - July 2023"
	label values panel "panel"
	
	destring sss, replace
	label define sss ///
	1 "Affluent households" ///
	2 "Middle households" ///
	3 "Remaining households"
	label values sss "sss"
	
	destring survey_code, replace
	label define survey_code ///
	1 "Original" ///
	2 "Substitute" ///
	3 "Casualty"
	label values survey_code "survey_code"
	
	destring reason_substitute, replace
	label define reason ///
	1 "Informant busy" ///
	2 "Members away from home" ///
	3 "Informant non-cooperative" ///
	9 "Others"
	label values reason_substitute "reason"
	
	order hhid
	save "${user}/data/processed/ces/level01_2022.dta", replace	

	********************************************	
	* Level 2 - Household Characteristics (HCQ)
	********************************************
	use "${user}/data/raw/ces/2022-23/level02_2022.dta", clear
	tostring *, replace
	
	rename survey_name survey
	rename sub_sample subsample
	rename fod_subregion fod_subsample
	rename b1q1pt7 sample_su
	rename b1q1pt10 sample_subdivision
	rename b1q1pt11 sss
	rename b1q1pt12 hhno
	rename questionaire_no questionnaire
	rename b3q1 personno
	rename b3q3 relation_to_head
	rename b3q4 sex
	rename b3q5 age
	rename b3q6 marital_status
	rename b3q7 highest_edu
	rename b3q8 years_edu
	rename b3q9 internet
	rename b3q10 days_home_away
	rename b3q11 meals_per_day_usual
	rename b3q12 meals_balwadi
	rename b3q13 meals_employer
	rename b3q14 meals_other
	rename b3q15 meals_paid
	rename b3q16 meals_home
	rename b3q17 member_status
	rename fdq fdq_og_member

	tostring year, replace
	
	egen hhid = concat(fsu sss hhno)
	egen pid = concat(fsu sss hhno personno)
	
	destring mult, replace
	gen pwt = mult/100
	
	label variable hhid "Unique household id"
	label variable pwt "Person weight"
	label variable pid "Unique person id"

	destring sector, replace
	label define sector ///
	1 "rural" ///
	2 "urban"
	label values sector "sector"
	
	destring state, replace
	label define state ///
	28 "Andhra Pradesh" ///
	12 "Arunachal Pradesh" ///
	18 "Assam" ///
	10 "Bihar" ///
	22 "Chattisgarh" ///
	7 "Delhi" ///
	30 "Goa" ///
	24 "Gujarat" ///
	6 "Haryana" ///
	2 "Himachal Pradesh" ///
	20 "Jharkhand" ///
	29 "Karnataka" ///
	32 "Kerala" ///
	23 "Madhya Pradesh" ///
	27 "Maharashtra" ///
	14 "Manipur" ///
	17 "Meghalaya" ///
	15 "Mizoram" ///
	13 "Nagaland" ///
	21 "Odisha" ///
	3 "Punjab" ///
	8 "Rajasthan" ///
	11 "Sikkim" ///
	33 "Tamil Nadu" ///
	36 "Telangana" ///
	16 "Tripura" ///
	5 "Uttrakhand" ///
	9 "Uttar Pradesh" ///
	19 "West Bengal" ///
	35 "Andaman and Nicobar Islands" ///
	4 "Chandigarh" ///
	25 "Dadra Nagar Haveli & Diu Daman" ///
	1 "Jammu and Kashmir" ///
	37 "Ladakh" ///
	31 "Lakshadweep" ///
	34 "Puducherry" 
	label values state "state"
	
	destring panel, replace
	label define panel ///
	1 "August - October 2022" ///
	2 "September - November 2022" ///
	3 "October - December 2022" ///
	4 "November 2022-January 2023" ///
	5 "December 2022 -February 2023" ///
	6 "January - March 2023" ///
	7 "February - April 2023" ///
	8 "March - May 2023" ///
	9 "April - June 2023" ///
	10 "May - July 2023"
	label values panel "panel"
	
	destring sss, replace
	label define sss ///
	1 "Affluent households" ///
	2 "Middle households" ///
	3 "Remaining households"
	label values sss "sss"
	
	destring relation_to_head, replace
	label define relations ///
	1 "Self" ///
	2 "Spouse of head" ///
	3 "Married child" ///
	4 "Spouse of married child" ///
	5 "Unmarried child" ///
	6 "Grandchild" ///
	7 "Father/Mother/Father-in-law/Mother-in-law" ///
	8 "Brother/Sister/Brother-in-law/Sister-in-law/Other relatives" ///
	9 "Servants/Employees/Other non-relatives"
	label values relation_to_head "relations"
	
	destring sex, replace
	label define sex ///
	1 "Male" ///
	2 "Female" /// 
	3 "Transgender" 
	label values sex "sex"
	
	destring marital_status, replace
	label define marital_status ///
	1 "Never married" ///
	2 "Currently married" ///
	3 "Widowed" ///
	4 "Divorced/Separated" 
	label values marital_status "marital_status"
	
	destring highest_edu, replace
	label define highest_edu ///
	1 "Not literate" ///
	2 "Literate with no formal education" ///
	3 "Below primary" ///
	4 "Primary" ///
	5 "Upper primary/middle" ///
	6 "Secondary" ///
	7 "Higher secondary" ///
	8 "Diploma / Certificate course (up to secondary)" ///
	10 "Diploma / Certificate course (higher secondary)" ///
	11 "Diploma / Certificate course (graduation and above)" ///
	12 "Graduate" ///
	13 "Post graduate and above" 
	label values highest_edu "highest_edu"
	
	destring internet, replace
	label define internet ///
	1 "Yes" ///
	2 "No"
	label values internet "internet"
	
	destring meals*, replace
	destring days_home_away, replace
	
	order hhid pid	
	save "${user}/data/processed/ces/level02_2022.dta", replace

	********************************************	
	* Level 3 - Household Characteristics (HCQ)
	********************************************
	use "${user}/data/raw/ces/2022-23/level03_2022.dta", clear
	tostring *, replace

	rename survey_name survey
	rename sub_sample subsample
	rename fod_subregion fod_subsample
	rename b1q1pt7 sample_su
	rename b1q1pt10 sample_subdivision
	rename b1q1pt11 sss
	rename b1q1pt12 hhno
	rename questionaire_no questionnaire
	rename b2q2pt1 hhsize
	rename b4q4pt1 hhmember_economic_activity
	rename b4q4pt3 nco_code
	rename b4q4pt5 nic_code
	rename b4q4pt6 maxincome_activity
	rename b4q4pt7 majorincome_selfemployed
	rename b4q4pt8 majorincome_salaried
	rename b4q4pt9 majorincome_casual
	rename b4q4pt10 hhtype
	rename b4q4pt11 religion
	rename b4q4pt12 caste
	rename b4q4pt13 land_ownership
	rename b4q4pt14 typeof_land
	rename b4q4pt15 area_owned
	rename b4q4pt16 dwelling_unit
	rename b4q4pt17 typeof_dwelling
	rename b4q4pt18 wall_material
	rename b4q4pt19 roof_material
	rename b4q4pt20 floor_material
	rename b4q4pt21 cooking
	rename b4q4pt22 lighting
	rename b4q4pt23 drinking_water
	rename b4q4pt24 time_taken_water
	rename b4q4pt25 latrine_access
	rename b4q4pt26 latrine_type
	rename b4q4pt29 ration_card_type
	rename b4q4pt30 rent_rate
	rename b4q4pt31 pmgky_beneficiary
	rename b4q4pt32 anydeath_below18
	rename b4q4pt33 noofdeath_below18
		
	egen hhid = concat(fsu sss hhno)
	
	destring mult, replace
	gen hhwt = mult/100
	
	label variable hhid "Unique household id"
	label variable hhwt "Household weight"
	
	destring sector, replace
	label define sector ///
	1 "rural" ///
	2 "urban"
	label values sector "sector"
	
	destring state, replace
	label define state ///
	28 "Andhra Pradesh" ///
	12 "Arunachal Pradesh" ///
	18 "Assam" ///
	10 "Bihar" ///
	22 "Chattisgarh" ///
	7 "Delhi" ///
	30 "Goa" ///
	24 "Gujarat" ///
	6 "Haryana" ///
	2 "Himachal Pradesh" ///
	20 "Jharkhand" ///
	29 "Karnataka" ///
	32 "Kerala" ///
	23 "Madhya Pradesh" ///
	27 "Maharashtra" ///
	14 "Manipur" ///
	17 "Meghalaya" ///
	15 "Mizoram" ///
	13 "Nagaland" ///
	21 "Odisha" ///
	3 "Punjab" ///
	8 "Rajasthan" ///
	11 "Sikkim" ///
	33 "Tamil Nadu" ///
	36 "Telangana" ///
	16 "Tripura" ///
	5 "Uttrakhand" ///
	9 "Uttar Pradesh" ///
	19 "West Bengal" ///
	35 "Andaman and Nicobar Islands" ///
	4 "Chandigarh" ///
	25 "Dadra Nagar Haveli & Diu Daman" ///
	1 "Jammu and Kashmir" ///
	37 "Ladakh" ///
	31 "Lakshadweep" ///
	34 "Puducherry" 
	label values state "state"
	
	destring panel, replace
	label define panel ///
	1 "August - October 2022" ///
	2 "September - November 2022" ///
	3 "October - December 2022" ///
	4 "November 2022-January 2023" ///
	5 "December 2022 -February 2023" ///
	6 "January - March 2023" ///
	7 "February - April 2023" ///
	8 "March - May 2023" ///
	9 "April - June 2023" ///
	10 "May - July 2023"
	label values panel "panel"
	
	destring sss, replace
	label define sss ///
	1 "Affluent households" ///
	2 "Middle households" ///
	3 "Remaining households"
	label values sss "sss"
	
	destring hhsize, replace
	
	destring hhmember_economic_activity, replace
	label define yesno ///
	1 "Yes" ///
	2 "No"
	label values hhmember_economic_activity "yesno"
	
	destring maxincome_activity, replace
	label define maxincome ///
	1 "Self-employment" ///
	2 "Regular wage/salaried earnings" ///
	3 "Casual labor" 
	label values maxincome_activity "maxincome"
	
	destring majorincome_selfemployed, replace
	label define se ///
	1 "Self-employment in agriculture" ///
	2 "Self-employment in non-agriculture"
	label values majorincome_selfemployed "se"
	
	destring majorincome_salaried, replace
	label define wage ///
	3 "Regular wage/salary earning in agriculture" ///
	4 "Regular wage/salary earning in non-agriculture"
	label values majorincome_salaried "wage" 
	
	destring majorincome_casual, replace
	label define casual ///
	5 "Casual labor in agriculture" ///
	6 "Casual labor in non-agriculture" 
	label values majorincome_casual "casual" 
	
	destring religion, replace
	label define religion ///
	1 "Hinduism" ///
	2 "Islam" ///
	3 "Christianity" ///
	4 "Sikhism" ///
	5 "Jainism" ///
	6 "Buddhism" ///
	7 "Zoroastrianism" ///
	9 "Others" ///
	0 "Not reported"
	label values religion "religion" 
	
	destring caste, replace
	label define caste ///
	1 "Scheduled Tribe" ///
	2 "Scheduled Caste" ///
	3 "Other Backward Class" ///
	9 "Others" ///
	0 "Not reported" 
	label values caste "caste" 
	
	destring land_ownership, replace
	label values land_ownership "yesno"
	
	destring typeof_land, replace
	label define typeof_land ///
	1 "Homestead only" ///
	2 "Homestead and other land" ///
	3 "Other land only"
	label values typeof_land "typeof_land"
	
	destring area_owned, replace
	
	destring dwelling_unit, replace
	label values dwelling_unit "yesno"
	
	destring typeof_dwelling, replace
	label define dwell ///
	1 "Owned" ///
	2 "Hired" ///
	3 "Others"
	label values typeof_dwelling "dwell"
	
	destring wall_material, replace
	label define material1 ///
	1 "Grass/straw/leaves/reeds/bamboo etc." ///
	2 "Mud (with/without bamboo)/unburnt brick" ///
	3 "Canvas/cloth" ///
	4 "Other katcha" ///
	5 "Timber" ///
	6 "Burnt brick/stone/lime stone" ///
	7 "Iron or other metal sheet" ///
	8 "Cement/RBC/RCC" ///
	9 "Other pucca"
	label values wall_material "material1"
	
	destring roof_material, replace
	label define material2 ///
	1 "Grass/straw/leaves/reeds/bamboo etc." ///
	2 "Mud (with/without bamboo)/unburnt brick" ///
	3 "Canvas/cloth" ///
	4 "Other katcha" ///
	5 "Tiles/slate" ///
	6 "Burnt brick/stone/lime stone" ///
	7 "Iron/zinc/othe metal sheet/asbestos sheet" ///
	8 "Cement/RBC/RCC" ///
	9 "Other pucca"
	label values wall_material "material2"
	
	destring floor_material, replace
	label values floor_material "material2"
	
	destring cooking, replace
	label define cooking ///
	1 "Firewood and chips" ///
	2 "LPG" ///
	3 "Other natural gas" ///
	4 "Dung cake" ///
	5 "Kerosene" ///
	6 "Coke,coal" ///
	7 "Gobar gas" ///
	8 "Other biogas" ///
	10 "Charcoal" ///
	11 "Electricity" ///
	12 "No cooking arrangement" ///
	9 "Others"
	label values cooking "cooking"
	
	destring drinking, replace
	label define drinking ///
	1 "Bottled water" ///
	2 "Piped water into dwelling" ///
	3 "Piped water to yard/plot" ///
	4 "Piped water from neighbour" ///
	5 "Public tap/standpipe" ///
	6 "Tube well" ///
	7 "Hand pump" ///
	8 "Well: Protected" ///
	9 "Well: Unprotected" ///
	10 "Tanker trunk: Public" ///
	11 "Tanker trunk: Private" ///
	12 "Spring: Protected" ///
	13 "Spring: Unprotected" ///
	14 "Rainwater collection" ///
	15 "Surface water: tank/pond" ///
	16 "Other surface water (river, dam, stream, canal, lake etc.)" ///
	19 "Others (cart with small tank or drum etc.)"
	label values drinking "drinking"
	
	destring latrine_access, replace
	label define latrine_access ///
	1 "Exclusive use of household" ///
	2 "Common use of households in the building" ///
	3 "Public/community latrine without payment" ///
	4 "Public/community latrine with payment" ///
	9 "Others" ///
	5 "No access to latrine" 
	label values latrine_access "latrine_access"
	
	destring latrine_type, replace
	label define latrine_type ///
	1 "Flush/pour-flush to: piped sewer system" ///
	2 "Flush/pour-flush to: septic tank" ///
	3 "Flush/pour-flush to: twin leach pit" ///
	4 "Flush/pour-flush to: single leach pit" ///
	5 "Flush/pour-flush to: elsewhere (open drain, open pit, open field, etc.)" ///
	6 "Ventilated improved pit latrine" ///
	7 "Pit latrine with slab" ///
	8 "Pit latrine without slab/open pit" ///
	10 "Composting latrine" ///
	11 "Open drain/nallah" ///
	19 "Others" 
	label values latrine_type "latrine_type"
	
	destring ration_card_type, replace
	label define ration_card_type ///
	1 "Antyodaya Anna Yojna" ///
	2 "Below Poverty Line" ///
	3 "Above Poverty Line" ///
	4 "Priority Households" ///
	5 "State Food Security Scheme" ///
	9 "Others" ///
	0 "No ration card" 
	label values ration_card_type "ration_card_type"
	
	destring rent_rate, replace
	label value rent_rate "yesno"
	
	destring pmgky_beneficiary, replace
	label value pmgky_beneficiary "yesno"
	
	destring anydeath_below18, replace
	label value anydeath_below18 "yesno"
	
	order hhid
	save "${user}/data/processed/ces/level03_2022.dta", replace

	***********************
	* Level 4 - Food (FDQ)
	***********************	
	use "${user}/data/raw/ces/2022-23/level04_2022.dta", clear
	tostring *, replace

	rename survey_name survey
	rename sub_sample subsample
	rename fod_subregion fod_subsample
	rename b1q1pt7 sample_su
	rename b1q1pt10 sample_subdivision
	rename b1q1pt11 sss
	rename b1q1pt12 hhno
	rename questionaire_no questionnaire
	rename b4pt1q411 ration_purchase
	rename b4pt14121 ration_rice
	rename b4pt14122 ration_wheat
	rename b4pt14123 ration_grain
	rename b4pt14124 ration_sugar
	rename b4pt14125 ration_pulses
	rename b4pt14126 ration_oil
	rename b4pt14127 ration_other
	rename b4pt14131 online_groceries
	rename b4pt14132 online_milk
	rename b4pt14133 online_vegetables
	rename b4pt14134 online_fruits_fresh
	rename b4pt14135 online_fruits_dry
	rename b4pt14136 online_eggs
	rename b4pt14137 online_processed_served
	rename b4pt14138 online_processed_packed
	rename b4pt14139 online_other
	rename b4pt1414 ceremony
	rename b4pt1415 meals_nonhh
	
	egen hhid = concat(fsu sss hhno)
	
	destring mult, replace
	gen hhwt = mult/100
	
	label variable hhid "Unique household id"
	label variable hhwt "Household weight"
	
	destring sector, replace
	label define sector ///
	1 "rural" ///
	2 "urban"
	label values sector "sector"
	
	destring state, replace
	label define state ///
	28 "Andhra Pradesh" ///
	12 "Arunachal Pradesh" ///
	18 "Assam" ///
	10 "Bihar" ///
	22 "Chattisgarh" ///
	7 "Delhi" ///
	30 "Goa" ///
	24 "Gujarat" ///
	6 "Haryana" ///
	2 "Himachal Pradesh" ///
	20 "Jharkhand" ///
	29 "Karnataka" ///
	32 "Kerala" ///
	23 "Madhya Pradesh" ///
	27 "Maharashtra" ///
	14 "Manipur" ///
	17 "Meghalaya" ///
	15 "Mizoram" ///
	13 "Nagaland" ///
	21 "Odisha" ///
	3 "Punjab" ///
	8 "Rajasthan" ///
	11 "Sikkim" ///
	33 "Tamil Nadu" ///
	36 "Telangana" ///
	16 "Tripura" ///
	5 "Uttrakhand" ///
	9 "Uttar Pradesh" ///
	19 "West Bengal" ///
	35 "Andaman and Nicobar Islands" ///
	4 "Chandigarh" ///
	25 "Dadra Nagar Haveli & Diu Daman" ///
	1 "Jammu and Kashmir" ///
	37 "Ladakh" ///
	31 "Lakshadweep" ///
	34 "Puducherry" 
	label values state "state"
	
	destring panel, replace
	label define panel ///
	1 "August - October 2022" ///
	2 "September - November 2022" ///
	3 "October - December 2022" ///
	4 "November 2022-January 2023" ///
	5 "December 2022 -February 2023" ///
	6 "January - March 2023" ///
	7 "February - April 2023" ///
	8 "March - May 2023" ///
	9 "April - June 2023" ///
	10 "May - July 2023"
	label values panel "panel"
	
	destring sss, replace
	label define sss ///
	1 "Affluent households" ///
	2 "Middle households" ///
	3 "Remaining households"
	label values sss "sss"
	
	destring ration_purchase, replace
	label define yesno ///
	1 "Yes" ///
	2 "No" 
	label values ration_purchase "yesno"
	
	destring ceremony, replace
	label values ceremony "yesno"
	
	destring meals_nonhh, replace
	
	order hhid
	save "${user}/data/processed/ces/level04_2022.dta", replace

	*************************	
	*  Level 5 - Food (FDQ)
	*************************
	use "${user}/data/raw/ces/2022-23/level05_2022.dta", clear
	tostring *, replace
	
	rename survey_name survey
	rename sub_sample subsample
	rename fod_subregion fod_subsample
	rename b1q1pt7 sample_su
	rename b1q1pt10 sample_subdivision
	rename b1q1pt11 sss
	rename b1q1pt12 hhno
	rename questionaire_no questionnaire
	rename b5pt1q2 item
	rename b5pt1q5 qty_total
	rename b5pt1q6 value_total
	rename b5pt1q3 home_cons_quant
	rename b5pt1q4 home_cons_value
	rename b5pt1q7 source
	
	egen hhid = concat(fsu sss hhno)
		
	destring mult, replace
	gen hhwt = mult/100
	
	label variable hhid "Unique household id"
	label variable hhwt "Household weight"
	
	destring item, replace
			
	destring sector, replace
	label define sector ///
	1 "rural" ///
	2 "urban"
	label values sector "sector"
	
	destring state, replace
	label define state ///
	28 "Andhra Pradesh" ///
	12 "Arunachal Pradesh" ///
	18 "Assam" ///
	10 "Bihar" ///
	22 "Chattisgarh" ///
	7 "Delhi" ///
	30 "Goa" ///
	24 "Gujarat" ///
	6 "Haryana" ///
	2 "Himachal Pradesh" ///
	20 "Jharkhand" ///
	29 "Karnataka" ///
	32 "Kerala" ///
	23 "Madhya Pradesh" ///
	27 "Maharashtra" ///
	14 "Manipur" ///
	17 "Meghalaya" ///
	15 "Mizoram" ///
	13 "Nagaland" ///
	21 "Odisha" ///
	3 "Punjab" ///
	8 "Rajasthan" ///
	11 "Sikkim" ///
	33 "Tamil Nadu" ///
	36 "Telangana" ///
	16 "Tripura" ///
	5 "Uttrakhand" ///
	9 "Uttar Pradesh" ///
	19 "West Bengal" ///
	35 "Andaman and Nicobar Islands" ///
	4 "Chandigarh" ///
	25 "Dadra Nagar Haveli & Diu Daman" ///
	1 "Jammu and Kashmir" ///
	37 "Ladakh" ///
	31 "Lakshadweep" ///
	34 "Puducherry" 
	label values state "state"
	
	destring panel, replace
	label define panel ///
	1 "August - October 2022" ///
	2 "September - November 2022" ///
	3 "October - December 2022" ///
	4 "November 2022-January 2023" ///
	5 "December 2022 -February 2023" ///
	6 "January - March 2023" ///
	7 "February - April 2023" ///
	8 "March - May 2023" ///
	9 "April - June 2023" ///
	10 "May - July 2023"
	label values panel "panel"
	
	destring sss, replace
	label define sss ///
	1 "Affluent households" ///
	2 "Middle households" ///
	3 "Remaining households"
	label values sss "sss"
	
	destring source, replace
	label define source ///
	1 "Only purchase" ///
	2 "Only home grown stock" ///
	3 "Both purchase and home grown stock" ///
	4 "Only free collection" ///
	5 "Only exchange of good and services" ///
	6 "Only gifts/charities" ///
	9 "Others"
	label values source "source"
	
	destring home_cons_quant, replace
	destring home_cons_value, replace
	destring qty_total, replace
	destring value_total, replace
	order hhid item qty_total value_total
	save "${user}/data/processed/ces/level05_2022.dta", replace

	************************	
	*  Level 6 - Food (FDQ)
	************************	
	use "${user}/data/raw/ces/2022-23/level06_2022.dta", clear
	tostring *, replace

	rename survey_name survey
	rename sub_sample subsample
	rename fod_subregion fod_subsample
	rename b1q1pt7 sample_su
	rename b1q1pt10 sample_subdivision
	rename b1q1pt11 sss
	rename b1q1pt12 hhno
	rename questionaire_no questionnaire
	rename b7pt1q2 item
	rename b7pt1q3 qty_total
	rename b7pt1q4 value_total
	rename b7pt1q5 source
		
	egen hhid = concat(fsu sss hhno)
		
	destring mult, replace
	gen hhwt = mult/100

	destring item, replace	
		
	label variable hhid "Unique household id"
	label variable hhwt "Household weight"
			
	destring sector, replace
	label define sector ///
	1 "rural" ///
	2 "urban"
	label values sector "sector"
	
	destring state, replace
	label define state ///
	28 "Andhra Pradesh" ///
	12 "Arunachal Pradesh" ///
	18 "Assam" ///
	10 "Bihar" ///
	22 "Chattisgarh" ///
	7 "Delhi" ///
	30 "Goa" ///
	24 "Gujarat" ///
	6 "Haryana" ///
	2 "Himachal Pradesh" ///
	20 "Jharkhand" ///
	29 "Karnataka" ///
	32 "Kerala" ///
	23 "Madhya Pradesh" ///
	27 "Maharashtra" ///
	14 "Manipur" ///
	17 "Meghalaya" ///
	15 "Mizoram" ///
	13 "Nagaland" ///
	21 "Odisha" ///
	3 "Punjab" ///
	8 "Rajasthan" ///
	11 "Sikkim" ///
	33 "Tamil Nadu" ///
	36 "Telangana" ///
	16 "Tripura" ///
	5 "Uttrakhand" ///
	9 "Uttar Pradesh" ///
	19 "West Bengal" ///
	35 "Andaman and Nicobar Islands" ///
	4 "Chandigarh" ///
	25 "Dadra Nagar Haveli & Diu Daman" ///
	1 "Jammu and Kashmir" ///
	37 "Ladakh" ///
	31 "Lakshadweep" ///
	34 "Puducherry" 
	label values state "state"
	
	destring panel, replace
	label define panel ///
	1 "August - October 2022" ///
	2 "September - November 2022" ///
	3 "October - December 2022" ///
	4 "November 2022-January 2023" ///
	5 "December 2022 -February 2023" ///
	6 "January - March 2023" ///
	7 "February - April 2023" ///
	8 "March - May 2023" ///
	9 "April - June 2023" ///
	10 "May - July 2023"
	label values panel "panel"
	
	destring sss, replace
	label define sss ///
	1 "Affluent households" ///
	2 "Middle households" ///
	3 "Remaining households"
	label values sss "sss"
	
	destring source, replace
	label define source ///
	1 "Only purchase" ///
	2 "Only home grown stock" ///
	3 "Both purchase and home grown stock" ///
	4 "Only free collection" ///
	5 "Only exchange of good and services" ///
	6 "Only gifts/charities" ///
	9 "Others"
	label values source "source"
	
	destring qty_total, replace
	destring value_total, replace
		
	order hhid item qty_total value_total	
	save "${user}/data/processed/ces/level06_2022.dta", replace

	******************************	
	* Level 7 - Consumables (CSQ)
	******************************
	use "${user}/data/raw/ces/2022-23/level07_2022.dta", clear
	tostring *, replace

	rename survey_name survey
	rename sub_sample subsample
	rename fod_subregion fod_subsample
	rename b1q1pt7 sample_su
	rename b1q1pt10 sample_subdivision
	rename b1q1pt11 sss
	rename b1q1pt12 hhno
	rename questionaire_no questionnaire
	rename b4pt2420	kerosene
	rename b4pt2421_1 lpg
	rename b4pt2421_2 num_lpg
	rename b4pt2422	electricity_free
	rename b4pt2423_1 edu_institution
	rename b4pt2423_2 num_govt_institution
	rename b4pt2423_3 num_pvt_institution
	rename b4pt24241_1 books_free
	rename b4pt24241_2 num_books_free
	rename b4pt24242_1 stationary_free
	rename b4pt24242_2 num_stationary_free
	rename b4pt24243_1 schoolbag_free
	rename b4pt24243_2 num_schoolbag_free
	rename b4pt24244_1 other_free
	rename b4pt24244_2 num_other_free
	rename b4pt2426_1 fees_reimbursed
	rename b4pt2426_2 num_fees_reimbursed
	rename b4pt2427_1 pmjay_otherbenefit
	rename b4pt2427_2 num_beneficiaries_pmjay_other
	rename b4pt2428	hospitalization
	rename b4pt2429_1 medical_pmjay_other
	rename b4pt2429_2 num_medical_pmjay_other
	rename b4pt2429_3 amt_medical_pmjay_other
	rename b4pt242101 fuel_light_online
	rename b4pt242102 toilet_consumables_online
	rename b4pt242103 edu_online
	rename b4pt242104 medicine_online
	rename b4pt242105 services_online
	rename b4pt24211 internet_hh

	egen hhid = concat(fsu sss hhno)
	
	destring mult, replace
	gen hhwt = mult/100
	
	label variable hhid "Household id"
	label variable hhwt "Household weight"
	
	destring sector, replace
	label define sector ///
	1 "rural" ///
	2 "urban"
	label values sector "sector"
	
	destring state, replace
	label define state ///
	28 "Andhra Pradesh" ///
	12 "Arunachal Pradesh" ///
	18 "Assam" ///
	10 "Bihar" ///
	22 "Chattisgarh" ///
	7 "Delhi" ///
	30 "Goa" ///
	24 "Gujarat" ///
	6 "Haryana" ///
	2 "Himachal Pradesh" ///
	20 "Jharkhand" ///
	29 "Karnataka" ///
	32 "Kerala" ///
	23 "Madhya Pradesh" ///
	27 "Maharashtra" ///
	14 "Manipur" ///
	17 "Meghalaya" ///
	15 "Mizoram" ///
	13 "Nagaland" ///
	21 "Odisha" ///
	3 "Punjab" ///
	8 "Rajasthan" ///
	11 "Sikkim" ///
	33 "Tamil Nadu" ///
	36 "Telangana" ///
	16 "Tripura" ///
	5 "Uttrakhand" ///
	9 "Uttar Pradesh" ///
	19 "West Bengal" ///
	35 "Andaman and Nicobar Islands" ///
	4 "Chandigarh" ///
	25 "Dadra Nagar Haveli & Diu Daman" ///
	1 "Jammu and Kashmir" ///
	37 "Ladakh" ///
	31 "Lakshadweep" ///
	34 "Puducherry" 
	label values state "state"
	
	destring panel, replace
	label define panel ///
	1 "August - October 2022" ///
	2 "September - November 2022" ///
	3 "October - December 2022" ///
	4 "November 2022-January 2023" ///
	5 "December 2022 -February 2023" ///
	6 "January - March 2023" ///
	7 "February - April 2023" ///
	8 "March - May 2023" ///
	9 "April - June 2023" ///
	10 "May - July 2023"
	label values panel "panel"
	
	destring sss, replace
	label define sss ///
	1 "Affluent households" ///
	2 "Middle households" ///
	3 "Remaining households"
	label values sss "sss"
	
	label define yesno ///
	1 "Yes" 2 "No"
	
	label define yes ///
	1 "Yes"
	
	destring kerosene, replace
	label values kerosene "yesno"
	
	destring lpg, replace
	label values lpg "yesno"
	
	destring num_lpg, replace
	
	destring electricity_free, replace
	label values electricity_free "yesno"
	
	destring edu_institution, replace
	label values edu_institution "yesno"
	
	destring num_govt_institution, replace
	destring num_pvt_institution, replace
	
	destring books_free, replace
	label values books_free "yes"
	
	destring stationary_free, replace
	label values stationary_free "yes"
	
	destring schoolbag_free, replace
	label values schoolbag_free "yes"
	
	destring other_free, replace
	label values other_free "yes"
		
	destring num_books_free, replace
	destring num_stationary_free, replace
	destring num_schoolbag_free, replace
	destring num_other_free, replace
	
	destring fees_reimbursed, replace
	label values fees_reimbursed "yesno"
	
	destring num_fees_reimbursed, replace
	
	destring pmjay_otherbenefit, replace
	label values pmjay_otherbenefit "yesno"
	
	destring num_beneficiaries_pmjay_other, replace
	
	destring hospitalization, replace
	label define hospital ///
	1 "Yes - Government/Public hospital" ///
	2 "Yes - Private (including charitable/trust run) hospital" ///
	3 "Yes - Both government and private" ///
	4 "No"
	label values hospitalization "hospital"
	
	destring medical_pmjay_other, replace
	label values medical_pmjay_other "yesno"
	
	destring num_medical_pmjay_other, replace
	destring amt_medical_pmjay_other, replace
	
	destring fuel_light_online, replace
	label values fuel_light_online "yes"
	
	destring toilet_consumables_online, replace
	label values toilet_consumables_online "yes"
	
	destring edu_online, replace
	label values edu_online "yes"
	
	destring medicine_online, replace
	label values medicine_online "yes"
	
	destring services_online, replace
	label values services_online "yes"
	
	destring internet_hh, replace
	label values internet_hh "yesno"
	
	order hhid
	save "${user}/data/processed/ces/level07_2022.dta", replace

	******************************	
	* Level 8 - Consumables (CSQ)
	******************************
	use "${user}/data/raw/ces/2022-23/level08_2022.dta", clear
	tostring *, replace
	
	rename survey_name survey
	rename sub_sample subsample
	rename fod_subregion fod_subsample
	rename b1q1pt7 sample_su
	rename b1q1pt10 sample_subdivision
	rename b1q1pt11 sss
	rename b1q1pt12 hhno
	rename questionaire_no questionnaire
	rename b8pt1q2 item
	rename b8pt1q5 qty_total
	rename b8pt1q6 value_total
	rename b8pt1q3 home_cons_quant
	rename b8pt1q4 home_cons_value
	rename b8pt1q7 source
	
	egen hhid = concat(fsu sss hhno)
	
	destring mult, replace
	gen hhwt = mult/100
	
	destring item, replace	
	
	label variable hhid "Unique household id"
	label variable hhwt "Household weight"
	
	destring home_cons_quant, replace	
	destring qty_total , replace		
	destring home_cons_value value_total, replace
	
	destring source, replace
	label define source ///
	1 "Only purchase" ///
	2 "Only home grown stock" ///
	3 "Both purchase and home grown stock" ///
	4 "Only free collection" ///
	5 "Only exchange of good and services" ///
	6 "Only gifts/charities" ///
	9 "Others"
	label values source "source"

	order hhid item qty_total value_total
	save "${user}/data/processed/ces/level08_2022.dta", replace

	******************************
	*  Level 9 - Consumable (CSQ)
	******************************	
	use "${user}/data/raw/ces/2022-23/level09_2022.dta", clear
	tostring *, replace

	rename survey_name survey
	rename sub_sample subsample
	rename fod_subregion fod_subsample
	rename b1q1pt7 sample_su
	rename b1q1pt10 sample_subdivision
	rename b1q1pt11 sss
	rename b1q1pt12 hhno
	rename questionaire_no questionnaire
	rename b9pt1q2 item
	rename b9pt1q3 value_total

	egen hhid = concat(fsu sss hhno)
	
	destring mult, replace
	gen hhwt = mult/100
	
	destring item, replace	
	
	label variable hhid "Unique household id"
	label variable hhwt "Household weight"
	
	destring value_total, replace
	
	destring sector, replace
	label define sector ///
	1 "rural" ///
	2 "urban"
	label values sector "sector"
	
	destring state, replace
	label define state ///
	28 "Andhra Pradesh" ///
	12 "Arunachal Pradesh" ///
	18 "Assam" ///
	10 "Bihar" ///
	22 "Chattisgarh" ///
	7 "Delhi" ///
	30 "Goa" ///
	24 "Gujarat" ///
	6 "Haryana" ///
	2 "Himachal Pradesh" ///
	20 "Jharkhand" ///
	29 "Karnataka" ///
	32 "Kerala" ///
	23 "Madhya Pradesh" ///
	27 "Maharashtra" ///
	14 "Manipur" ///
	17 "Meghalaya" ///
	15 "Mizoram" ///
	13 "Nagaland" ///
	21 "Odisha" ///
	3 "Punjab" ///
	8 "Rajasthan" ///
	11 "Sikkim" ///
	33 "Tamil Nadu" ///
	36 "Telangana" ///
	16 "Tripura" ///
	5 "Uttrakhand" ///
	9 "Uttar Pradesh" ///
	19 "West Bengal" ///
	35 "Andaman and Nicobar Islands" ///
	4 "Chandigarh" ///
	25 "Dadra Nagar Haveli & Diu Daman" ///
	1 "Jammu and Kashmir" ///
	37 "Ladakh" ///
	31 "Lakshadweep" ///
	34 "Puducherry" 
	label values state "state"
	
	destring panel, replace
	label define panel ///
	1 "August - October 2022" ///
	2 "September - November 2022" ///
	3 "October - December 2022" ///
	4 "November 2022-January 2023" ///
	5 "December 2022 -February 2023" ///
	6 "January - March 2023" ///
	7 "February - April 2023" ///
	8 "March - May 2023" ///
	9 "April - June 2023" ///
	10 "May - July 2023"
	label values panel "panel"
	
	destring sss, replace
	label define sss ///
	1 "Affluent households" ///
	2 "Middle households" ///
	3 "Remaining households"
	label values sss "sss"
	
	order hhid item value_total
	save "${user}/data/processed/ces/level09_2022", replace

	*******************************
	* Level 10 - Consumables (CSQ)
	*******************************	
	use "${user}/data/raw/ces/2022-23/level10_2022.dta", clear
	tostring *, replace

	rename survey_name survey
	rename sub_sample subsample
	rename fod_subregion fod_subsample
	rename b1q1pt7 sample_su
	rename b1q1pt10 sample_subdivision
	rename b1q1pt11 sss
	rename b1q1pt12 hhno
	rename questionaire_no questionnaire
	rename b12pt1q2 item
	rename b12pt1q3	home_cons_quant
	rename b12pt1q4	home_cons_value
	rename b12pt1q5	qty_total
	rename b12pt1q6	value_total
	rename b12pt1q7	source

	egen hhid = concat(fsu sss hhno)
		
	destring mult, replace
	gen hhwt = mult/100
	
	destring item, replace	
	
	label variable hhid "Unique household id"
	label variable hhwt "Household weight"
	
	destring home_cons_quant qty_total value_total, replace
	destring home_cons_value, replace
	
	destring sector, replace
	label define sector ///
	1 "rural" ///
	2 "urban"
	label values sector "sector"
	
	destring state, replace
	label define state ///
	28 "Andhra Pradesh" ///
	12 "Arunachal Pradesh" ///
	18 "Assam" ///
	10 "Bihar" ///
	22 "Chattisgarh" ///
	7 "Delhi" ///
	30 "Goa" ///
	24 "Gujarat" ///
	6 "Haryana" ///
	2 "Himachal Pradesh" ///
	20 "Jharkhand" ///
	29 "Karnataka" ///
	32 "Kerala" ///
	23 "Madhya Pradesh" ///
	27 "Maharashtra" ///
	14 "Manipur" ///
	17 "Meghalaya" ///
	15 "Mizoram" ///
	13 "Nagaland" ///
	21 "Odisha" ///
	3 "Punjab" ///
	8 "Rajasthan" ///
	11 "Sikkim" ///
	33 "Tamil Nadu" ///
	36 "Telangana" ///
	16 "Tripura" ///
	5 "Uttrakhand" ///
	9 "Uttar Pradesh" ///
	19 "West Bengal" ///
	35 "Andaman and Nicobar Islands" ///
	4 "Chandigarh" ///
	25 "Dadra Nagar Haveli & Diu Daman" ///
	1 "Jammu and Kashmir" ///
	37 "Ladakh" ///
	31 "Lakshadweep" ///
	34 "Puducherry" 
	label values state "state"
	
	destring panel, replace
	label define panel ///
	1 "August - October 2022" ///
	2 "September - November 2022" ///
	3 "October - December 2022" ///
	4 "November 2022-January 2023" ///
	5 "December 2022 -February 2023" ///
	6 "January - March 2023" ///
	7 "February - April 2023" ///
	8 "March - May 2023" ///
	9 "April - June 2023" ///
	10 "May - July 2023"
	label values panel "panel"
	
	destring sss, replace
	label define sss ///
	1 "Affluent households" ///
	2 "Middle households" ///
	3 "Remaining households"
	label values sss "sss"
		
	order hhid item 
	save "${user}/data/processed/ces/level10_2022.dta", replace

	*****************************	
	*  Level 11 - Durables (DGQ)
	*****************************
	use "${user}/data/raw/ces/2022-23/level11_2022.dta", clear
	tostring *, replace

	rename survey_name survey
	rename sub_sample subsample
	rename fod_subregion fod_subsample
	rename b1q1pt7 sample_su
	rename b1q1pt10 sample_subdivision
	rename b1q1pt11 sss
	rename b1q1pt12 hhno
	rename questionaire_no questionnaire
	rename b4pt34311 clothing_online
	rename b4pt34312 footwear_online
	rename b4pt34313 furniture_online
	rename b4pt34314 mobile_online
	rename b4pt34315 personal_goods_online
	rename b4pt34316 recreation_goods_online
	rename b4pt34317 hh_appliances_online
	rename b4pt34318 utensils_online
	rename b4pt34319 sports_good_online
	rename b4pt343110 medical_equipment_online
	rename b4pt343111 bedding_online
	rename b4pt34321_1 laptop_free
	rename b4pt34321_2 num_laptop_free
	rename b4pt34322_1 tablet_free
	rename b4pt34322_2 num_tablet_free
	rename b4pt34323_1 mobile_free
	rename b4pt34323_2 num_mobile_free
	rename b4pt34324_1 bicycle_free
	rename b4pt34324_2 num_bicycle_free
	rename b4pt34325_1 motorcycle_free
	rename b4pt34325_2 num_motorcycle_free
	rename b4pt34326_1 clothing_free
	rename b4pt34326_2 num_clothing_free
	rename b4pt34327_1 footwear_free
	rename b4pt34327_2 num_footwear_free
	rename b4pt34328_1 other_items_free
	rename b4pt34328_2 num_other_items_free
	rename b4pt34331 television
	rename b4pt34332 radio
	rename b4pt34333 laptop
	rename b4pt34334 mobile
	rename b4pt34335 bicycle
	rename b4pt34336 motorcycle
	rename b4pt34337 car
	rename b4pt34338 trucks
	rename b4pt34339 animal_cart
	rename b4pt343310 refrigerator
	rename b4pt343311 washing_machine
	rename b4pt343312 air_conditioner
	rename b4pt3434	multichanel_tv

	egen hhid = concat(fsu sss hhno)
	
	destring mult, replace
	gen hhwt = mult/100
	
	label variable hhid "Unique household id"
	label variable hhwt "Household weight"
		
	destring sector, replace
	label define sector ///
	1 "rural" ///
	2 "urban"
	label values sector "sector"
	
	destring state, replace
	label define state ///
	28 "Andhra Pradesh" ///
	12 "Arunachal Pradesh" ///
	18 "Assam" ///
	10 "Bihar" ///
	22 "Chattisgarh" ///
	7 "Delhi" ///
	30 "Goa" ///
	24 "Gujarat" ///
	6 "Haryana" ///
	2 "Himachal Pradesh" ///
	20 "Jharkhand" ///
	29 "Karnataka" ///
	32 "Kerala" ///
	23 "Madhya Pradesh" ///
	27 "Maharashtra" ///
	14 "Manipur" ///
	17 "Meghalaya" ///
	15 "Mizoram" ///
	13 "Nagaland" ///
	21 "Odisha" ///
	3 "Punjab" ///
	8 "Rajasthan" ///
	11 "Sikkim" ///
	33 "Tamil Nadu" ///
	36 "Telangana" ///
	16 "Tripura" ///
	5 "Uttrakhand" ///
	9 "Uttar Pradesh" ///
	19 "West Bengal" ///
	35 "Andaman and Nicobar Islands" ///
	4 "Chandigarh" ///
	25 "Dadra Nagar Haveli & Diu Daman" ///
	1 "Jammu and Kashmir" ///
	37 "Ladakh" ///
	31 "Lakshadweep" ///
	34 "Puducherry" 
	label values state "state"
	
	destring panel, replace
	label define panel ///
	1 "August - October 2022" ///
	2 "September - November 2022" ///
	3 "October - December 2022" ///
	4 "November 2022-January 2023" ///
	5 "December 2022 -February 2023" ///
	6 "January - March 2023" ///
	7 "February - April 2023" ///
	8 "March - May 2023" ///
	9 "April - June 2023" ///
	10 "May - July 2023"
	label values panel "panel"
	
	destring sss, replace
	label define sss ///
	1 "Affluent households" ///
	2 "Middle households" ///
	3 "Remaining households"
	label values sss "sss"
	
	label define yes ///
	1 "Yes" 
	
	destring clothing_online, replace
	label values clothing_online "yes"
	
	destring footwear_online, replace
	label values footwear_online "yes"
	
	destring furniture_online, replace
	label values furniture_online "yes"
	
	destring mobile_online, replace
	label values mobile_online "yes"
	
	destring personal_goods_online, replace
	label values personal_goods_online "yes"
	
	destring recreation_goods_online, replace
	label values recreation_goods_online "yes"
	
	destring hh_appliances_online, replace
	label values hh_appliances_online "yes"
	
	destring utensils_online, replace
	label values utensils_online "yes"
	
	destring sports_good_online, replace
	label values sports_good_online "yes"
	
	destring medical_equipment_online, replace
	label values medical_equipment_online "yes"
	
	destring bedding_online, replace
	label values bedding_online "yes"
	
	destring laptop_free, replace
	label values laptop_free "yes"
	
	destring tablet_free, replace
	label values tablet_free "yes"
	
	destring mobile_free, replace
	label values mobile_free "yes"
			
	destring bicycle_free, replace
	label values bicycle_free "yes"
	
	destring motorcycle_free, replace
	label values motorcycle_free "yes"
	
	destring clothing_free, replace
	label values clothing_free "yes"
	
	destring footwear_free, replace
	label values footwear_free "yes"
			
	destring other_items_free, replace
	label values other_items_free "yes"
	
	destring num_laptop_free num_tablet_free num_mobile_free num_bicycle_free ///
	num_motorcycle_free num_clothing_free num_footwear_free num_other_items_free, replace
	
	destring television, replace
	label values television "yes"
	
	destring radio, replace
	label values radio "yes"
	
	destring laptop, replace
	label values laptop "yes"
	
	destring mobile, replace
	label values mobile "yes"
	
	destring bicycle, replace
	label values bicycle "yes"
	
	destring motorcycle, replace
	label values motorcycle "yes"
	
	destring car, replace
	label values car "yes"
	
	destring trucks, replace
	label values trucks "yes"
	
	destring animal_cart, replace
	label values animal_cart "yes"
	
	destring refrigerator, replace
	label values refrigerator "yes"
	
	destring washing_machine, replace
	label values washing_machine "yes"
	
	destring air_conditioner, replace
	label values air_conditioner "yes"
	
	destring multichanel_tv, replace
	label values multichanel_tv "yes"
	
	order hhid
	save "${user}/data/processed/ces/level11_2022.dta", replace	

	******************************	
	*  Level 12 - Durables (DGQ)
	******************************
	use "${user}/data/raw/ces/2022-23/level12_2022.dta", clear
	tostring *, replace

	rename survey_name survey
	rename sub_sample subsample
	rename fod_subregion fod_subsample
	rename b1q1pt7 sample_su
	rename b1q1pt10 sample_subdivision
	rename b1q1pt11 sss
	rename b1q1pt12 hhno
	rename questionaire_no questionnaire
	rename b13pt1q2 item
	rename b13pt1q3 qty_total
	rename b13pt1q4 value_total

	egen hhid = concat(fsu sss hhno)

	destring mult, replace
	gen hhwt = mult/100
	
	label variable hhid "Household id"
	label variable hhwt "Household weight"
	
	destring qty_total value_total, replace
	
	destring item, replace	
	
	destring sector, replace
	label define sector ///
	1 "rural" ///
	2 "urban"
	label values sector "sector"
	
	destring state, replace
	label define state ///
	28 "Andhra Pradesh" ///
	12 "Arunachal Pradesh" ///
	18 "Assam" ///
	10 "Bihar" ///
	22 "Chattisgarh" ///
	7 "Delhi" ///
	30 "Goa" ///
	24 "Gujarat" ///
	6 "Haryana" ///
	2 "Himachal Pradesh" ///
	20 "Jharkhand" ///
	29 "Karnataka" ///
	32 "Kerala" ///
	23 "Madhya Pradesh" ///
	27 "Maharashtra" ///
	14 "Manipur" ///
	17 "Meghalaya" ///
	15 "Mizoram" ///
	13 "Nagaland" ///
	21 "Odisha" ///
	3 "Punjab" ///
	8 "Rajasthan" ///
	11 "Sikkim" ///
	33 "Tamil Nadu" ///
	36 "Telangana" ///
	16 "Tripura" ///
	5 "Uttrakhand" ///
	9 "Uttar Pradesh" ///
	19 "West Bengal" ///
	35 "Andaman and Nicobar Islands" ///
	4 "Chandigarh" ///
	25 "Dadra Nagar Haveli & Diu Daman" ///
	1 "Jammu and Kashmir" ///
	37 "Ladakh" ///
	31 "Lakshadweep" ///
	34 "Puducherry" 
	label values state "state"
	
	destring panel, replace
	label define panel ///
	1 "August - October 2022" ///
	2 "September - November 2022" ///
	3 "October - December 2022" ///
	4 "November 2022-January 2023" ///
	5 "December 2022 -February 2023" ///
	6 "January - March 2023" ///
	7 "February - April 2023" ///
	8 "March - May 2023" ///
	9 "April - June 2023" ///
	10 "May - July 2023"
	label values panel "panel"
	
	destring sss, replace
	label define sss ///
	1 "Affluent households" ///
	2 "Middle households" ///
	3 "Remaining households"
	label values sss "sss"
	
	order hhid item qty_total value_total
	save "${user}/data/processed/ces/level12_2022.dta", replace

	****************************	
	* Level 13 - Durables (DGQ)
	****************************	
	use "${user}/data/raw/ces/2022-23/level13_2022.dta", clear
	tostring *, replace

	rename survey_name survey
	rename sub_sample subsample
	rename fod_subregion fod_subsample
	rename b1q1pt7 sample_su
	rename b1q1pt10 sample_subdivision
	rename b1q1pt11 sss
	rename b1q1pt12 hhno
	rename questionaire_no questionnaire
	rename b14pt1q3 first_hand_num
	rename b14pt1q4 hired
	rename b14pt1q5 first_hand_value
	rename b14pt1q6 repair_maint_cost
	rename b14pt1q7 second_hand_num
	rename b14pt1q8 second_hand_value
	rename b14pt1q2 item
	rename b14pt1q9 value_total
	
	egen hhid = concat(fsu sss hhno)
	
	destring mult, replace
	gen hhwt = mult/100
	
	label variable hhid "Household id"
	label variable hhwt "Household weight"
	
	destring first_hand_num first_hand_value repair_maint_cost second_hand_num second_hand_value value_total, replace
	
	destring hired, replace
	label define yesno ///
	1 "Yes" ///
	2 "No" 
	label values hired "yesno"
	
	destring item, replace
		
	destring sector, replace
	label define sector ///
	1 "rural" ///
	2 "urban"
	label values sector "sector"
	
	destring state, replace
	label define state ///
	28 "Andhra Pradesh" ///
	12 "Arunachal Pradesh" ///
	18 "Assam" ///
	10 "Bihar" ///
	22 "Chattisgarh" ///
	7 "Delhi" ///
	30 "Goa" ///
	24 "Gujarat" ///
	6 "Haryana" ///
	2 "Himachal Pradesh" ///
	20 "Jharkhand" ///
	29 "Karnataka" ///
	32 "Kerala" ///
	23 "Madhya Pradesh" ///
	27 "Maharashtra" ///
	14 "Manipur" ///
	17 "Meghalaya" ///
	15 "Mizoram" ///
	13 "Nagaland" ///
	21 "Odisha" ///
	3 "Punjab" ///
	8 "Rajasthan" ///
	11 "Sikkim" ///
	33 "Tamil Nadu" ///
	36 "Telangana" ///
	16 "Tripura" ///
	5 "Uttrakhand" ///
	9 "Uttar Pradesh" ///
	19 "West Bengal" ///
	35 "Andaman and Nicobar Islands" ///
	4 "Chandigarh" ///
	25 "Dadra Nagar Haveli & Diu Daman" ///
	1 "Jammu and Kashmir" ///
	37 "Ladakh" ///
	31 "Lakshadweep" ///
	34 "Puducherry" 
	label values state "state"
	
	destring panel, replace
	label define panel ///
	1 "August - October 2022" ///
	2 "September - November 2022" ///
	3 "October - December 2022" ///
	4 "November 2022-January 2023" ///
	5 "December 2022 -February 2023" ///
	6 "January - March 2023" ///
	7 "February - April 2023" ///
	8 "March - May 2023" ///
	9 "April - June 2023" ///
	10 "May - July 2023"
	label values panel "panel"
	
	destring sss, replace
	label define sss ///
	1 "Affluent households" ///
	2 "Middle households" ///
	3 "Remaining households"
	label values sss "sss"
			
	order hhid item value_total
	save "${user}/data/processed/ces/level13_2022.dta", replace

	****************************************	
	* Level 14 - Item expenditure subtotals
	****************************************
	use "${user}/data/raw/ces/2022-23/level14_2022.dta", clear
	tostring *, replace
	
	rename survey_name survey
	rename sub_sample subsample
	rename fod_subregion fod_subsample
	rename b1q1pt7 sample_su
	rename b1q1pt10 sample_subdivision
	rename b1q1pt11 sss
	rename b1q1pt12 hhno
	rename questionaire_no questionnaire
	rename ba1b1c1_1 section
	rename ba1b1c1_2 item
	rename ba1b1c1_3 value_total
	
	egen hhid = concat(fsu sss hhno)
	
	destring mult, replace
	gen hhwt = mult/100
	
	label variable hhid "Household id"
	label variable hhwt "Household weight"
	
	destring sector, replace
	label define sector ///
	1 "rural" ///
	2 "urban"
	label values sector "sector"
	
	destring state, replace
	label define state ///
	28 "Andhra Pradesh" ///
	12 "Arunachal Pradesh" ///
	18 "Assam" ///
	10 "Bihar" ///
	22 "Chattisgarh" ///
	7 "Delhi" ///
	30 "Goa" ///
	24 "Gujarat" ///
	6 "Haryana" ///
	2 "Himachal Pradesh" ///
	20 "Jharkhand" ///
	29 "Karnataka" ///
	32 "Kerala" ///
	23 "Madhya Pradesh" ///
	27 "Maharashtra" ///
	14 "Manipur" ///
	17 "Meghalaya" ///
	15 "Mizoram" ///
	13 "Nagaland" ///
	21 "Odisha" ///
	3 "Punjab" ///
	8 "Rajasthan" ///
	11 "Sikkim" ///
	33 "Tamil Nadu" ///
	36 "Telangana" ///
	16 "Tripura" ///
	5 "Uttrakhand" ///
	9 "Uttar Pradesh" ///
	19 "West Bengal" ///
	35 "Andaman and Nicobar Islands" ///
	4 "Chandigarh" ///
	25 "Dadra Nagar Haveli & Diu Daman" ///
	1 "Jammu and Kashmir" ///
	37 "Ladakh" ///
	31 "Lakshadweep" ///
	34 "Puducherry" 
	label values state "state"
	
	destring panel, replace
	label define panel ///
	1 "August - October 2022" ///
	2 "September - November 2022" ///
	3 "October - December 2022" ///
	4 "November 2022-January 2023" ///
	5 "December 2022 -February 2023" ///
	6 "January - March 2023" ///
	7 "February - April 2023" ///
	8 "March - May 2023" ///
	9 "April - June 2023" ///
	10 "May - July 2023"
	label values panel "panel"
	
	destring sss, replace
	label define sss ///
	1 "Affluent households" ///
	2 "Middle households" ///
	3 "Remaining households"
	label values sss "sss"
	
	order hhid item value_total 
	
	destring value_total, replace
	destring item, replace
	
	order hhid item value_total	
	save "${user}/data/processed/ces/level14_2022.dta", replace

	****************************************	
	*Level 15 - Total Household Expenditure
	****************************************
	use "${user}/data/raw/ces/2022-23/level15_2022.dta", clear
	tostring *, replace

	rename survey_name survey
	rename sub_sample subsample
	rename fod_subregion fod_subsample
	rename b1q1pt7 sample_su
	rename b1q1pt10 sample_subdivision
	rename b1q1pt11 sss
	rename b1q1pt12 hhno
	rename questionaire_no questionnaire
	rename b1pt1a2b2c2	time_taken
	rename ba2b2c2q7 informant_code
	rename ba2b2c2q5 total_hhcons
	rename ba2b2c2q6 total_online_exp
	rename ba2b2c2q9 hhsize
	rename ba2b2c2q8 response_code
	
	egen hhid = concat(fsu sss hhno)
	
	destring mult, replace
	gen hhwt = mult/100
	
	label variable hhid "Household id"
	label variable hhwt "Household weight"
	
	destring total_hhcons total_online_exp hhsize, replace
	
	destring sector, replace
	label define sector ///
	1 "rural" ///
	2 "urban"
	label values sector "sector"
	
	destring state, replace
	label define state ///
	28 "Andhra Pradesh" ///
	12 "Arunachal Pradesh" ///
	18 "Assam" ///
	10 "Bihar" ///
	22 "Chattisgarh" ///
	7 "Delhi" ///
	30 "Goa" ///
	24 "Gujarat" ///
	6 "Haryana" ///
	2 "Himachal Pradesh" ///
	20 "Jharkhand" ///
	29 "Karnataka" ///
	32 "Kerala" ///
	23 "Madhya Pradesh" ///
	27 "Maharashtra" ///
	14 "Manipur" ///
	17 "Meghalaya" ///
	15 "Mizoram" ///
	13 "Nagaland" ///
	21 "Odisha" ///
	3 "Punjab" ///
	8 "Rajasthan" ///
	11 "Sikkim" ///
	33 "Tamil Nadu" ///
	36 "Telangana" ///
	16 "Tripura" ///
	5 "Uttrakhand" ///
	9 "Uttar Pradesh" ///
	19 "West Bengal" ///
	35 "Andaman and Nicobar Islands" ///
	4 "Chandigarh" ///
	25 "Dadra Nagar Haveli & Diu Daman" ///
	1 "Jammu and Kashmir" ///
	37 "Ladakh" ///
	31 "Lakshadweep" ///
	34 "Puducherry" 
	label values state "state"
	
	destring panel, replace
	label define panel ///
	1 "August - October 2022" ///
	2 "September - November 2022" ///
	3 "October - December 2022" ///
	4 "November 2022-January 2023" ///
	5 "December 2022 -February 2023" ///
	6 "January - March 2023" ///
	7 "February - April 2023" ///
	8 "March - May 2023" ///
	9 "April - June 2023" ///
	10 "May - July 2023"
	label values panel "panel"
	
	destring sss, replace
	label define sss ///
	1 "Affluent households" ///
	2 "Middle households" ///
	3 "Remaining households"
	label values sss "sss"
	
	encode section, gen(section_new)
	destring section_new, replace
	label define sect ///
	1 "Household characteristics" ///
	2 "Food expenditure" ///
	3 "Consumables and services expenditure" ///
	4 "Durable goods expenditure" 
	label values section_new "sect"
		
	destring response_code, replace
	label define response ///
	1 "Informant co-operative and capable" /// 
	2 "Informant co-operative but not capable" ///
	3 "Informant busy" ///
	4 "Informant reluctant" ///
	9 "Others"
	label values response_code "response"	
	
	order hhid section_new total_hhcons total_online_exp hhsize response_code
	unique hhid section
	save "${user}/data/processed/ces/level15_2022.dta", replace

	* ==========================================================================*
	di in red "THE END OF 01_ces_clean"
	* ==========================================================================*

	cap log close
	exit
	
	
