
	loc date: display %tdCCYY-NN-DD =daily("`c(current_date)'", "DMY")
	cap log close
	log using "${user}/output/log/01a_cpi_clean_`date'", replace

	/* =============================================================================
		Project			: India poverty estimates - 2011-12 & 2022-23 
		Dofile			: 01a_cpi_clean.do
		Last modified	: 25th March 2025
		Inputs			: "${user}/data/raw/other"											
		Outputs			: "${user}/data/processed/other"
		File purpose	: Create CPI sub-group and group level averages at state-sector- 
						  month level for 2011 and 2022. This output will be used 
						  for intra-temporal adjustments. 
	============================================================================= */

	/*******************************************************************************
		Additional notes - 
			(1) These states have only CPI group level information:
				- Andaman and Nicobar, Chandigarh, Dadra & Nagar Haveli, Daman 
				   & Diu, Lakshadweep
				- Arunachal Pradesh (also missing housing 4.0.00)
				- Goa, Manipur, Meghalaya, Mizoram, Nagaland, Puducherry, 
				Sikkim, Tripura
			(2) For the states above, where subgroup level CPI is not available use 
				CPI at group level
			(3) Ladakh is part of J&K in the orginial data downloaded from MoSPI, 
				Ladakh created separately using J&K numbers	
	*******************************************************************************/

	*Import subgroup level data from excel and save a temp file (Follow instructions in README to download CPI data from MoSPI)
	import excel "${user}/data/raw/other/CPI_R_U_subgroups_Jan11_May24.xlsx", sheet("subgroup") firstrow clear
	unique year month state sector subgroup
	ren group cpi_group_code
	ren subgroup scode_1
	ren subgroup_description cpi_description
	ren cpi_subgroup cpi
	
	tempfile cpi_subgroup
	save `cpi_subgroup', replace
	
	*Import group level data from excel and save a temp file (Follow instructions in README to download CPI data from MoSPI)
	import excel "${user}/data/raw/other/CPI_R_U_subgroups_Jan11_May24.xlsx", sheet("group") firstrow clear
	replace group = 7 if group_description == "General Index (All Groups)"
	replace group = 8 if group_description == "Consumer Food Price Index"
	unique year month state sector group
	ren group cpi_group_code
	ren group_description cpi_description
	gen scode_1 = string(cpi_group_code) + ".0" + ".00"
	ren cpi_group cpi
	
	append using `cpi_subgroup'

	*Create month numbers
	gen month_no = "01" if month=="January"
	replace month_no = "02" if month=="February"
	replace month_no = "03" if month=="March"
	replace month_no = "04" if month=="April"
	replace month_no = "05" if month=="May"
	replace month_no = "06" if month=="June"
	replace month_no = "07" if month=="July"
	replace month_no = "08" if month=="August"
	replace month_no = "09" if month=="September"
	replace month_no = "10" if month=="October"
	replace month_no = "11" if month=="November"
	replace month_no = "12" if month=="December"

	egen year_month = concat(year month_no)
	destring year_month, replace

	*Keep only survey year data for both years - Jul'11-Jun'12 and Aug'22-Jul'23
	keep if inrange(year_month, 201107, 201206) | inrange(year_month, 202208, 202307 )
	
	destring year month_no, replace
	
	gen survey_month = ym(year, month_no)
	format survey_month %tm
	
	* Create numeric IDs for states	same as in NSS Surveys
	gen state_new = . 
	replace state_new = 1 if state=="Jammu and Kashmir"
	replace state_new = 2 if state=="Himachal Pradesh"
	replace state_new = 3 if state=="Punjab"
	replace state_new = 4 if state=="Chandigarh"
	replace state_new = 5 if state=="Uttarakhand"
	replace state_new = 6 if state=="Haryana"
	replace state_new = 7 if state=="Delhi"
	replace state_new = 8 if state=="Rajasthan"
	replace state_new = 9 if state=="Uttar Pradesh"
	replace state_new = 10 if state=="Bihar"
	replace state_new = 11 if state=="Sikkim"
	replace state_new = 12 if state=="Arunachal Pradesh"
	replace state_new = 13 if state=="Nagaland"
	replace state_new = 14 if state=="Manipur"
	replace state_new = 15 if state=="Mizoram"
	replace state_new = 16 if state=="Tripura"
	replace state_new = 17 if state=="Meghalaya"
	replace state_new = 18 if state=="Assam"
	replace state_new = 19 if state=="West Bengal"
	replace state_new = 20 if state=="Jharkhand"
	replace state_new = 21 if state=="Odisha"
	replace state_new = 22 if state=="Chhattisgarh"
	replace state_new = 23 if state=="Madhya Pradesh"
	replace state_new = 24 if state=="Gujarat"
	replace state_new = 25 if state=="Daman and Diu"
	replace state_new = 26 if state=="Dadra and Nagar Haveli"
	replace state_new = 27 if state=="Maharashtra"
	replace state_new = 28 if state=="Andhra Pradesh"
	replace state_new = 29 if state=="Karnataka"
	replace state_new = 30 if state=="Goa"
	replace state_new = 31 if state=="Lakshadweep"
	replace state_new = 32 if state=="Kerala"
	replace state_new = 33 if state=="Tamil Nadu"
	replace state_new = 34 if state=="Puducherry"
	replace state_new = 35 if state=="Andaman and Nicobar Islands"
	replace state_new = 36 if state=="Telangana"
	replace state_new = 37 if state=="Ladakh"
	replace state_new = 38 if state=="ALL India"
	
	label define state_lab 1 "Jammu & Kashmir" 2 "Himachal Pradesh" 3 "Punjab" 4 "Chandigarh" 5 "Uttrakhand" 6 "Haryana" 7 "Delhi" 8 "Rajasthan" 9 "Uttar Pradesh" 10 "Bihar" 11 "Sikkim" 12 "Arunachal Pradesh" 13 "Nagaland" 14 "Manipur" 15 "Mizoram" 16 "Tripura" 17 "Meghalaya" 18 "Assam" 19 "West Bengal" 20 "Jharkhand" 21 "Odisha" 22 "Chhattisgarh" 23 "Madhya Pradesh" 24 "Gujarat" 25 "Daman & Diu" 26 "D & N Haveli" 27 "Maharashtra" 28 "Andhra Pradesh" 29 "Karnataka" 30 "Goa" 31 "Lakshadweep" 32 "Kerala" 33 "Tamil Nadu" 34 "Puducherry" 35 "A & N Island" 36 "Telangana" 37 "Ladakh" 38 "All India"
label values state_new state_lab 
	
	drop state
	rename state_new state
	
	order state

	*Create unique sub-group codes (scode)
	split scode_1, p(".") gen(temp)
	gen scode = temp1+temp2+temp3
	destring scode, replace
	drop temp1-temp3 scode_1 cpi_group_code	
	drop if scode==8000
	drop cpi_description
	format cpi %10.2f

	*Reshape so that each state sector and month has 27 scodes
	reshape wide cpi, i(state sector survey_month) j(scode)
	reshape long cpi, i(state sector survey_month) j(scode)

	*Generate CPI group codes
	gen cpi_group_code = 1 if inrange(scode, 1000, 1211) //food
	replace cpi_group_code = 2 if scode==2000 //pan
	replace cpi_group_code = 3 if inrange(scode, 3000, 3102) //clothing & footwear
	replace cpi_group_code = 4 if scode==4000 //housing
	replace cpi_group_code = 5 if scode==5000 //fuel and light
	replace cpi_group_code = 6 if inrange(scode, 6000, 6106) //misc
	replace cpi_group_code = 7 if scode==7000 //general index
	
	*Check
 	table state sector, stat(count cpi)
	table state cpi_group_code if sector==1, stat(count cpi) nototal
	table state cpi_group_code if sector==2, stat(count cpi) nototal
	
	*Average for rural-urban to fill for missing sector
	bys scode state survey_month : egen cpi_temp = mean(cpi)
	
	*Replace missing values in rural housing with urban housing
	replace cpi = cpi_temp if cpi==. & scode==4000 
	
	*Replace missing values in urban AP with rural AP
	replace cpi = cpi_temp if cpi==. & state==12
	drop cpi_temp
	
	*Replace missing housing data in Arunachal Pradesh with Nagaland		
	bys survey_month : egen cpi_new = mean(cpi) if scode==4000 & inlist(state, 12, 13)
	replace cpi = cpi_new if cpi==. & scode==4000
	drop cpi_new
		
	*Check for missing values
 	table scode state if state<10, stat(mean cpi) nototal
 	table scode state if state>=10 & state<22, stat(mean cpi) nototal
 	table scode state if state>=22 & state<32, stat(mean cpi) nototal
 	table scode state if state>=32, stat(mean cpi) nototal

	*Replace missing sub-group with group level data at state sector month level 
	bys state sector survey_month cpi_group_code : egen cpi_new = mean(cpi)
	replace cpi = cpi_new if cpi==. 
	drop cpi_new
	
	*Assign J&K CPI values to Ladakh 	
	preserve
	keep if state==1
	replace state=37
	tempfile ladakh
	save `ladakh'
	restore
	
	append using `ladakh'

	*Calculate yearly CPI averages at state sector scode level
	drop year
	gen year = 2011 if inrange(survey_month, tm(2011m7), tm(2012m6))
	replace year = 2022 if inrange(survey_month, tm(2022m8), tm(2023m7))
	
	bys state sector scode year : egen cpi_avg = mean(cpi)
	
	keep state sector scode survey_month year cpi cpi_avg
	
	label variable survey_month "CPI month that matches to survey data"
	label variable cpi "monthly CPIs"
	label variable cpi_avg "yearly average CPIs"
	label variable year "survey year"
	label variable scode "sub-group code"
	label variable state "states"

	drop if sector==3
	
	*Save clean CPI data in processed folder
	save "${user}/data/processed/other/cpi_master_monthly", replace	
	
	* ==========================================================================*
	di in red "THE END OF 01a_cpi_clean" 
	* ==========================================================================*
	cap log close
	exit
	
	

