	
	loc date: display %tdCCYY-NN-DD =daily("`c(current_date)'", "DMY")
	cap log close
	log using "${user}/output/log/02_master_datasets_create_`date'", replace

	/* =============================================================================
		Project	        : India poverty estimates - 2011-12 & 2022-23 
		Dofile  		: 02_master_datasets_create
		Last modified	: 27th March, 2025
		
		Inputs 2011		: "${user}/data/processed/ces/block0102_2011_mmrp.dta"
						  "${user}/data/processed/ces/block03a_2011_mmrp.dta"	
						  "${user}/data/processed/ces/block0506_2011_mmrp.dta"
						  "${user}/data/processed/ces/blocks0708_2011_mmrp.dta"
						  "${user}/data/processed/ces/block09_2011_mmrp.dta"
						  "${user}/data/processed/ces/block10_2011_mmrp.dta"
						  "${user}/data/processed/ces/block11_2011_mmrp.dta"
						  "${user}/data/processed/other/item_list_2011.xlsx"
						  
		Inputs 2022		: "${user}/data/processed/ces/level01_2022.dta"  
						  "${user}/data/processed/ces/level15_2022.dta"
						  "${user}/data/processed/ces/level05_2022.dta"
						  "${user}/data/processed/ces/level06_2022.dta"
						  "${user}/data/processed/ces/level08_2022.dta"
						  "${user}/data/processed/ces/level09_2022.dta"
						  "${user}/data/processed/ces/level10_2022.dta"
						  "${user}/data/processed/ces/level12_2022.dta"
						  "${user}/data/processed/ces/level13_2022.dta"
						  "${user}/data/processed/other/item_list_2022.xlsx"
						
		Outputs			: "${user}/data/processed/ces/master_hh_2011.dta"
						  "${user}/data/processed/ces/master_hh_2022.dta"
						  "${user}/data/processed/ces/master_item_list_2011.dta"
						  "${user}/data/processed/ces/master_item_list_2022.dta"
						  "${user}/data/processed/ces/master_consumption_2022.dta"	
						  "${user}/data/processed/ces/master_consumption_2011.dta"	
										
		Auxiliary dofiles: 	"${user}/code/01b_match_survey_cpi_items_2011.do"
							"${user}/code/01c_match_survey_cpi_items_2022.do"

		Steps			: * 1. CREATE MASTER DATASETS - 2011
						  * 2. CREATE MASTER DATASETS - 2022
						
	============================================================================= */

	*===========================================================================
	* 1. CREATE MASTER DATASETS - 2011
	*===========================================================================
	
	****************
	* 01. MASTER OF HHs
	****************
	
	*Start with processed data
	use "${user}/data/processed/ces/block0102_2011_mmrp.dta", clear 
	merge 1:1 hhid using "${user}/data/processed/ces/block03a_2011_mmrp.dta", keepusing(hhwt hhsize pwt) keep(3) nogen 

	isid state sector sss fsu hamlet hhserial district
	g year = 2011
	
	gen month = substr(date_of_survey, 3,2)
	gen year1 = substr(date_of_survey, -2,2)
	destring month, replace

	clonevar month_temp =month
	replace month_temp = 0 if mi(month)		
 	bys state sector fsu hamlet (month_temp): gen temp = month_temp[_N] 
	bys state sector fsu (month_temp): replace temp = month_temp[_N]  if temp==0

	bys state sector fsu hamlet (month_temp): gen temp2 = year1[_N] 
	bys state sector fsu (month_temp): replace temp2 = year1[_N] if mi(year1)

	replace month = temp if mi(month)
	replace year1 = temp2 if mi(year1)
	
	drop month_temp temp temp2
		
	replace year1 = "2012" if year1=="12"
	replace year1 = "2011" if year1=="11"	
	
	destring year1, replace
	
	gen survey_month = ym(year1, month)
	format survey_month %tm

	
	
	* Matching State/UTs in 2011-12 with 2022-23
		clonevar district_new 	= district
		clonevar state_new 		= state
		
	*Combining Daman & Diu and Dadra & Nagar Haveli
		recode district_new (1=3) 	if state==26
		replace state_new = 25 		if district_new==3 & state==26
			
	*Splitting J&K and Ladakh. Districts 7 (Leh) & 8 (Kargil) were taken from J&K to create Ladakh
		replace state_new 	= 37 		if (district_new==7|district_new==8) & state==1
		recode district_new (7=1) (8=2) if state_new==37	

	*Splitting Andhra and Telangana. Districts 1-10 were taken from Andhra to create Telangana
	replace state_new = 36 if (inrange(district_new,1,10) & state==28)
	recode district_new (11=1) (12=2) (13=3) (14=4) (15=5) (16=6) (17=7) (18=8) (19=9) (20=10) (21=11) (22=12) (23=13) if state_new==28
	
	*Label state variables
	#delimit; 
	lab define state_lab 	1 "Jammu & Kashmir" 
							2 "Himachal Pradesh" 
							3 "Punjab" 
							4 "Chandigarh" 
							5 "Uttrakhand" 
							6 "Haryana" 
							7 "Delhi" 
							8 "Rajasthan" 
							9 "Uttar Pradesh" 
							10 "Bihar" 
							11 "Sikkim" 
							12 "Arunachal Pradesh" 
							13 "Nagaland" 
							14 "Manipur" 
							15 "Mizoram" 
							16 "Tripura"
							17 "Meghalaya" 
							18 "Assam" 
							19 "West Bengal" 
							20 "Jharkhand" 
							21 "Odisha" 
							22 "Chhattisgarh" 
							23 "Madhya Pradesh" 
							24 "Gujarat" 
							25 "Daman & Diu & D & N Haveli" 
							27 "Maharashtra" 
							28 "Andhra Pradesh" 
							29 "Karnataka" 
							30 "Goa" 
							31 "Lakshadweep" 
							32 "Kerala" 
							33 "Tamil Nadu" 
							34 "Puducherry" 
							35 "A & N Island" 
							36 "Telangana" 
							37 "Ladakh";
	#delimit cr
	lab val state_new state_lab

	*Change variable names to match with 2022-23 
	ren state state_2011
	ren district district_2011
	ren state_new state
	ren district_new district
	ren Sub_Stratum_No sub_stratum
	
	lab var state "States matching 2022"
	
	tostring fsu, replace 
	tostring district stratum, replace 

	*Generate empty variables panel and survey sequence in 2011 to consistent with 2022-23
	g panel = .
	g survey_seq = ""
	destring sss, replace
		
	keep year hhid state sector district stratum sub_stratum sss fsu  round hamlet  hhsize hhwt pwt panel survey_seq survey_month 
	
	*Save master_hh_2011 in processed data
	save "${user}/data/processed/ces/master_hh_2011.dta", replace 
	
	************************
	*02. MASTER OF ITEMS
	************************
	
	*Item list is an excel of all items created by WB team 	
	import excel "${user}/data/raw/other/item_list.xlsx", sheet(2011-12) firstrow clear
	g year=2011
	ren recallperiod recall_period
	ren list item_desc
	
	cap drop J K L M N 

	*Create subgroups
	g subgroup = "."
		replace subgroup = "Cereals" 	if inrange(item, 101,139)
		replace subgroup = "Pulses" 	if inrange(item, 140,159)
		replace subgroup = "Milk& milk products" if inrange(item, 160,169)
		replace subgroup = "Salt & sugar" 		if inrange(item, 170,179)
		replace subgroup = "Edible oil" 		if inrange(item, 180,189)
		replace subgroup = "Egg, fish, & meat" 	if inrange(item, 190,199)
		replace subgroup = "Vegetables"			if inrange(item, 200,219)
		replace subgroup = "Fruits fresh" 		if inrange(item, 220,239)
		replace subgroup = "Fruits dry" 		if inrange(item, 240,249)
		replace subgroup = "Spices" 			if inrange(item, 250,269)
		replace subgroup = "Beverages" 			if inrange(item, 270,279)
		replace subgroup = "Processed food" 	if inrange(item, 280,289)
		replace subgroup = "Packaged food" 		if inrange(item, 290,299)
		replace subgroup = "Pan" 				if inrange(item, 300,309)
		replace subgroup = "Tobacco" 			if inrange(item, 310,319)
		replace subgroup = "Intoxicants" 		if inrange(item, 320,329)
		replace subgroup = "Fuel and light" 	if inrange(item, 330,349)
		
		replace subgroup = "Clothing" 	if inrange(item, 350,379)
		replace subgroup = "Bedding" 	if inrange(item, 380,389)
		replace subgroup = "Footwear" 	if inrange(item, 390,399)

		replace subgroup = "Education" 				if inrange(item, 400,409)
		replace subgroup = "Medical Institutional" 	if inrange(item, 410,419)

		replace subgroup = "Medical Non-Institutional" 	if inrange(item, 420,429)
		replace subgroup = "Entertainment"				if inrange(item, 430,439)
		replace subgroup = "Minor durable goods" 		if inrange(item, 440,449)
		replace subgroup = "Toilet articles" 			if inrange(item, 450,459)
		replace subgroup = "Other household consumables" if inrange(item, 460,479)
		replace subgroup = "Consumer services" 			if inrange(item, 480,499)
		replace subgroup = "Conveyance" 				if inrange(item, 500,519)
		replace subgroup = "Rent" 						if inrange(item, 520,529)
		replace subgroup = "Rent imputed (Urban only)" 	if inrange(item, 539,539)
		replace subgroup = "Consumer taxes and cesses" 	if inrange(item, 540,549)

		replace subgroup = "Furniture" 				if inrange(item, 550,559)
		replace subgroup = "Recreational goods" 	if inrange(item, 560,569)
		replace subgroup = "Utensils" 				if inrange(item, 570,579)
		replace subgroup = "Household appliances" 	if inrange(item, 580,599)
		replace subgroup = "Transport equipment" 	if inrange(item, 600,609)
		replace subgroup = "Therapeutic appliances" if inrange(item, 610,619)
		replace subgroup = "Other personal goods" 	if inrange(item, 620,629)
		replace subgroup = "Residential building & repairs" if inrange(item, 630,639)
		replace subgroup = "Jewellery" 				if inrange(item, 640,649)
		replace subgroup = "Durables" 				if item==659


	*Create commodity groups
	g commodity_group = .
		replace commodity_group = 1 if inrange(item, 101,139)
		replace commodity_group = 2 if inrange(item, 140,159)
		replace commodity_group = 3 if inrange(item, 160,169)
		replace commodity_group = 9 if inrange(item, 170,179)
		replace commodity_group = 4 if inrange(item, 180,189)
		replace commodity_group = 5 if inrange(item, 190,199)
		replace commodity_group = 6 if inrange(item, 200,219)
		replace commodity_group = 7 if inrange(item, 220,239)
		replace commodity_group = 8 if inrange(item, 240,249)
		replace commodity_group = 10 if inrange(item, 250,269)
		replace commodity_group = 11 if inrange(item, 270,279)	// Beverages
		replace commodity_group = 11 if inrange(item, 280,289)	// processed food
		replace commodity_group = 11 if inrange(item, 290,299)	// packaged food
		replace commodity_group = 12 if inrange(item, 300,309)	// Pan
		replace commodity_group = 12 if inrange(item, 310,319)	// Tobacco
		replace commodity_group = 12 if inrange(item, 320,329)	// Intoxicants
		replace commodity_group = 13 if inrange(item, 330,349)	// 
		replace commodity_group = 14 if inrange(item, 350,379)	// clothing
		replace commodity_group = 14 if inrange(item, 380,389)	// bedding
		replace commodity_group = 15 if inrange(item, 390,399) 	// Footwear
		replace commodity_group = 16 if inrange(item, 400,409)	// Education
		replace commodity_group = 17 if inrange(item, 420,429)	// Medical (Non-institutional)
		replace commodity_group = 18 if inrange(item, 410,419)	// Medical (Institutional)
		replace commodity_group = 24 if inrange(item, 620,629)	// Other personal goods
		replace commodity_group = 20 if inrange(item, 600,609)	// Transport equipment
		replace commodity_group = 22 if inrange(item, 580,599) 	// Household appliances
		replace commodity_group = 22 if inrange(item, 460,479)	// Other consumables
		replace commodity_group = 22 if inrange(item, 480,499) 	// Consumer services (excl. conveyance)
		replace commodity_group = 22 if inrange(item, 610,619)	// Medical equipment
		replace commodity_group = 22 if inrange(item, 570,579)	// Utensils
		replace commodity_group = 22 if inrange(item, 550,559)	// Furniture
		replace commodity_group = 22 if inrange(item, 630,639)	// Land and buildings
		replace commodity_group = 23 if inrange(item, 430,439)	// Entertainment
		replace commodity_group = 23 if inrange(item, 560,569)	// Recreation
		replace commodity_group = 24 if inrange(item, 440,449)	// Minor durable goods
		replace commodity_group = 24 if inrange(item, 450,459)	// Toilet articles
		replace commodity_group = 24 if inrange(item, 640,659)	// Jewellary
		replace commodity_group = 990 if inrange(item, 520,539)	// Rent
		replace commodity_group = 991 if inrange(item, 540,549)	// Cess and taxes
		replace commodity_group = 992 if inrange(item, 500,519)	// Conveyance

	*Label commodity groups
	#delimit; 
	lab def commodity_group 	1 "Cereals" 
								2 "Pulses" 
								3 "Milk" 
								4 "Oil" 
								5 "Egg,fish, meat" 
								6 "Vegetables" 
								7 "Fresh fruits" 
								8 "Dry fruits" 
								9 "Salt and sugar" 
								10 "Spices" 
								11 "Other food" 
								12 "Intoxicants" 
								13 "Fuel and light" 
								14 "Clothing" 
								15 "Footwear" 
								16 "Education" 
								17 "Health (Non-institutional)" 
								18 "Health (Institutional)" 
								20 "Transports" 
								22 "Household good and services" 
								23 "Recreation" 
								24 "Personal care and effects" 
								990 "Rent" 
								991 "Cess and taxes" 
								992 "Conveyance" , modify;
	#delimit cr
	lab val commodity_group commodity_group
		
	g food_item = inrange(commodity_group, 1, 11)

	*Create product codes
	g product_code = item
		replace product_code = 1000 if inlist(item, 101, 102) //Rice 
		replace product_code = 2000 if inlist(item, 107, 108) // Wheat
		replace product_code = 4000 if inlist(item, 140, 141,143,144,145,148) //Pulses
		replace product_code = 5000 if inlist(item, 142) //Gram
		replace product_code = 6000 if inlist(item, 170) //Salt
		replace product_code = 7000 if inlist(item, 171,172) // Sugar
		replace product_code = 8000 if inlist(item, 181,182,183,184)  //Edible oil [excl. other edible oil and vanaspati]
		replace product_code = 9000 if inlist(item, 334, 335)  //Kerosene
		replace product_code = 9001 if inlist(item, 356, 357) //School uniform
		replace product_code = 9002 if inlist(item, 390, 394) //School shoes

	*Create dummies for pds, subtotal and item_139
	g pds 		= inlist(item, 101, 107, 171, 334)
	g subtotal 	= inlist(item, 129, 159, 169, 179, 189, 199, 219, 239, 249, 269, 279, 289, 299, 309, 319, 329, 349, 379, 389, 399, 409, 419, 429, 439, 449, 459, 479, 499, 519, 529, 539, 549, 559, 569, 579, 599, 609, 619, 629, 639, 649, 659)
	g item_139 = item==139 //Cereal substitutes is an individual item but is not included in any of the sub-totals. Keep or drop as needed.
	
	g no_qty = missing(unit)
		replace no_qty = 1 if item==302
				
		lab var subgroup 	"item subgroup"
		lab var pds 		"dummy for PDS items"
		lab var subtotal 	"dummy for item sub-totals"
		lab var no_qty 		"dummy for items with no unit or quantity information"
		lab var year 		"durvey year"
		*lab var cpi_description "cpi sub-group description"
		lab var commodity_group "commodity groups (based on Tendulkar committee report)"
		lab var product_code 	"pds + market items as one product"
		*lab var scode 			"cpi sub-groups"	
		lab var item_139 		"dummy for item 139"

	*Create missing variables in 2011 to be consistent with 2022-23
	g survey_type 	= .
	g free 			= 0
	g free_nf 		= 0
	g agg_item 		= .
	g sub_grains 	= . 
		
	keep item item_desc recall_period unit commodity_group food_item survey_type product_code pds free free_nf subtotal item_139 no_qty
	
	*Save master_item_list_2011 in processed data 
	save "${user}/data/processed/ces/master_item_list_2011.dta", replace
		
	************************
	*03. MASTER OF CONSUMPTION 
	************************
	
	*Create master for quantities and values for every item	
	*Output: hhid, item, item_group, unit, recall_period, qty_total, value_total
	
	*Food & Energy (Items 101 - 349)
	use "${user}/data/processed/ces/block0506_2011_mmrp.dta", clear 
		keep  hhid item source qty_total value_total 
		sort  hhid item
		g item_group = "Food and Energy" 
		tempfile food
	save `food'

	*Clothing and footwear (Items 350 - 399)
	use  "${user}/data/processed/ces/blocks0708_2011_mmrp.dta", clear 
		keep  hhid item qty_total value_total  
		destring qty_total, replace
		sort  hhid item
		g item_group = "Clothing and Footwear" 
		tempfile clothing
	save `clothing'
		
	*Education and medical (Items 400 - 419)
	use  "${user}/data/processed/ces/block09_2011_mmrp.dta", clear 
		keep  hhid item value_total
		sort  hhid item
		g item_group = "Education and Medical"
		tempfile educ_med
	save `educ_med'
	
	*Miscellaneous (Items 420 - 549)
	use  "${user}/data/processed/ces/block10_2011_mmrp.dta", clear 
		keep  hhid item value_total
		sort  hhid item
		g item_group = "Miscellaneous"
	tempfile misc
	save `misc'
	
	*Durables (Items 550 - 659)
	use  "${user}/data/processed/ces/block11_2011_mmrp.dta", clear 
		keep  hhid item value_total 
		sort  hhid item
		g item_group = "Durables"
	tempfile durables
	save `durables'
		
	*Append all
	use `food' 
		append using `clothing'
		append using `educ_med'
		append using `misc'
		append using `durables'	
		g year = 2011
		tostring hhid, replace

	*Merge with master hh and master item list datasets created above
	merge m:1 hhid using "${user}/data/processed/ces/master_hh_2011.dta", keep(3) keepusing(state sector survey_month) nogen	
	merge m:1 item using  "${user}/data/processed/ces/master_item_list_2011.dta", keepusing(unit recall_period)  keep(3) nogen
	
	*Adjust units
	g double qty_new = qty_total 
		replace qty_new = qty_total/1000 if  (unit=="kg" | unit=="litre" | unit=="gm")
		replace qty_new = qty_total/1000 if  (unit=="metre") 
	
	*Generate value_total_30d	
	g double value_total_30d = value_total if recall_period==30
		replace value_total_30d = value_total*30/7 if recall_period==7
		replace value_total_30d = value_total*30/365 if recall_period==365
		
	keep year survey_month hhid item source qty_total qty_new value_total value_total_30d
	
	*Save master raw consumption in processed data
	save "${user}/data/processed/ces/master_consumption_2011.dta", replace
	
	*===========================================================================
	*===========================================================================
	* 2. CREATE MASTER DATASETS - 2022
	*===========================================================================
	*===========================================================================

	*******************
	*01. MASTER OF HHs
	*******************
	
	*Include only more frequently used variables, e.g. hhid, sector, state, hhwt, hhsize, pwt
	use "${user}/data/processed/ces/level01_2022.dta", clear 
	destring hhno year, replace
	
	*Generate survey sequence
		bys fsu sss: g survey_seq= "1-2-3" if inlist(hhno, 1, 4, 7, 10, 13, 16) & subsample=="1"
		bys fsu sss: replace survey_seq= "1-3-2" if inlist(hhno, 2,5,8,11,14,17) & subsample=="1"
		bys fsu sss: replace survey_seq= "2-1-3" if inlist(hhno, 3,6,9,12,15,18) & subsample=="1"
		bys fsu sss: replace survey_seq= "2-3-1" if inlist(hhno, 1, 4, 7, 10, 13, 16) & subsample=="2"
		bys fsu sss: replace survey_seq= "3-1-2" if inlist(hhno, 2,5,8,11,14,17) & subsample=="2"
		bys fsu sss: replace survey_seq= "3-2-1" if inlist(hhno, 3,6,9,12,15,18) & subsample=="2"
		lab var survey_seq "1: FDQ 2:CSQ 3:DGQ"

	*Keep household weights from FDQ
	preserve 
	use "${user}/data/processed/ces/level15_2022.dta", clear
		keep if section_new==2 // keep FDQ data
		g double pwt = hhwt*hhsize
		keep pwt hhwt hhsize hhid
		tempfile weights
		save `weights'
	restore
	
	merge 1:1 hhid using `weights' 
	
	g round = ""
	g hamlet = ""
	
	
	keep year hhid sector state district stratum sub_stratum sss fsu round hamlet hhwt hhsize pwt survey_seq panel sss
	save "${user}/data/processed/ces/hh_2022_old.dta", replace 

	************************
	*MASTER OF ITEMS
	************************
	
	*Item list is an excel of all items created by WB team 	
	import excel "${user}/data/raw/other/item_list.xlsx", sheet(2022-23) firstrow clear	
	g year=2022
		ren recallperiod recall_period
		ren list item_desc

	*Create subgroup 
	g subgroup = .
		replace subgroup = 1	if inlist(item, 61,62,70,101,102,103,105,106,107,108,110,111,112,114,1,2,122,129,139) // Cereals
		replace subgroup = 1	if inlist(item, 55,56,57,58,59,60,63,64,65,66,67,68,115,116,117,118,119,120,121) // Cereals
		replace subgroup = 2	if inlist(item, 140,143,144,145,141,142,146,148,150,158,152,071,072,159) // Pulses
		replace subgroup = 2	if inlist(item, 71,72)
		replace subgroup = 3	if inlist(item, 73,74,178,170,171,172,173,174,175,179) // Salt & Sugar
		replace subgroup = 4	if inlist(item, 160,162,164,163,165,166,3,4,5,92,169) // Milk & milk products
		replace subgroup = 4	if inlist(item, 6,7,167)
		replace subgroup = 5	if inlist(item, 201,200,202,206,203,208,207,211,213,212,210,215,214,205,204,216,217, 219) // Vegetables
		replace subgroup = 6	if inlist(item, 220,236,224,231,237,225,226,230,228,222,232,93,239) // Fresh fruits
		replace subgroup = 6	if inlist(item, 221,223,227,234,233,235,238)
		replace subgroup = 7	if inlist(item, 240,241,243,242,245,246,94,249) // Dry fruits
		replace subgroup = 7	if inlist(item, 8,10,247)

		replace subgroup = 8	if inlist(item, 190,195,191,192,193,194,196, 199) // Egg, fish, & meat
		replace subgroup = 9	if inlist(item, 181,184,182,183,188,95,75, 189) // Edible oil
		replace subgroup = 9	if inlist(item, 180,185)

		replace subgroup = 10	if inlist(item, 256,254,252,253,251,250,258,255,257,260,263,261, 269) // spices
		replace subgroup = 11	if inlist(item, 270,271,272,273,274,11,275,276,278, 279) // Beverages
		replace subgroup = 12	if inlist(item, 76,280,281,282,283,284, 289) // processed food
		replace subgroup = 13	if inlist(item, 12,161,290,013,291,292,293,294,295,113,14,15,296, 299) // Packaged food

		replace subgroup = 14	if inlist(item, 332,338,331,334,335,96, 349) // Fuel & light
		replace subgroup = 14	if inlist(item, 341, 343, 337, 333, 344, 345, 340, 336, 342, 346)

		replace subgroup = 15	if inlist(item, 450,16,451,453,17,18,452,20,21,456,22,454,455,457,459) // Toilet items
		replace subgroup = 16	if inlist(item, 466,467,465,471,464,468,470,23,460,462,461,463,472,479) // Other household consumables
		replace subgroup = 17	if inlist(item, 405,406,400,401,404,408,409) // Education
		replace subgroup = 18	if inlist(item, 410,412,411,413,414,419) // Medical (Institutional)
		replace subgroup = 19	if inlist(item, 420,422,421,423,424,429)  // Medical (Non-Institutional)
		replace subgroup = 20	if inlist(item, 24,504,25,506,505,500,508,501,510,26,511,503,512,513,514,519) // Conveyance

		replace subgroup = 21	if inlist(item, 488,487,496,540,483,480,484,482,481,27,485,486,492,495,494,493,490,497,499) // Consumer services exl. conveyance
		replace subgroup = 22  	if inlist(item, 437,430,402,435,433,28,438,439) // Entertainment
		replace subgroup = 23	if inlist(item, 520,521,522,523,529) // Rent - Actual
		replace subgroup = 24	if item==539	// Rent - imputed
		replace subgroup = 25	if item==899	// Taxes and cesses

		replace subgroup = 26	if inlist(item, 300,301,302,309) // Pan
		replace subgroup = 27	if inlist(item, 310,311,316,312,314,315,313,317,319) // Tobacco
		replace subgroup = 28	if inlist(item, 322,324,323,321,320,325,329) // Intoxicants

		replace subgroup = 29	if inlist(item, 351,352,353,30,363,31,364,354,32,358,360,356,357,33,361,362,365,34,368,355,366,367,370,350,371,373,372,374,375,379, 900) // Clothing
		replace subgroup = 30	if inlist(item, 393,390,391,392,394,395,399, 901) // Footwear
		replace subgroup = 31	if inlist(item, 380,381,383,382,385,384,386,389) // Bedding
		replace subgroup = 32	if inlist(item, 440,441,442,623,624,622,620,554,35,621,625,629) // Other personal goods
		replace subgroup = 33	if inlist(item, 601,602,600,603,604,609) // Personal transport equipment 
		replace subgroup = 34	if inlist(item, 36,37,432,97,99) // Sports goods
		replace subgroup = 35	if inlist(item, 40,41,610,42,611,619) // Medical equipment

		replace subgroup = 36	if inlist(item, 580,43,581,44,45,588,585,582,46,586,590,47,48,587,591,584,583,592,599) // Household appliances
		replace subgroup = 37	if inlist(item, 570,571,572,50,573,579) // Utensils
		replace subgroup = 38	if inlist(item, 550,551,552,553,555,556,557,559) // Furniture
		replace subgroup = 39	if inlist(item, 560,561,562,563,564,569) // Recreational goods
		replace subgroup = 40	if inlist(item, 632,630,631,633,639) // Building & repairs
		replace subgroup = 41	if inlist(item, 640,641,642,643,649) // Jewellary

	#delimit ;
	lab def subgroup 	1 "Cereals" 
						2 "Pulses" 
						3 "Salt and sugar" 
						4 "Milk"
						5 "Vegetables" 
						6 "Fresh fruits" 
						7 "Dry fruits" 
						8 "Egg, fish, meat" 
						9 "Edible oil" 
						10 "Spices" 
						11 "Beverages" 
						12 "Processed food" 
						13 "Packaged food" 
						14 "Fuel and light" 
						15 "Toilet items" 
						16 "Other household goods" 
						17 "Education" 
						18 "Medical (Institutional)" 
						19 "Medical (Non-Institutional)" 
						20 "Conveyance" 
						21 "Consumer services exl. conveyance" 
						22 "Entertainment" 
						23 "Rent - Actual" 
						24 "Rent - imputed" 
						25 "Cesses and taxes" 
						26 "Pan" 
						27 "Tobacco"
						28 "Intoxicants" 
						29 "Clothing" 
						30 "Footwear" 
						31 "Beddings" 
						32 "Other personal goods" 
						33 "Transport equipment" 
						34 "Sports goods" 
						35 "Medical equipment" 
						36 "Household appliances" 
						37 "Utensils"
						38 "Furniture" 
						39 "Recreational goods" 
						40 "Building and repairs" 
						41 "Jewellary";
		#delimit cr
		lab val subgroup subgroup

	* Commodity groups	
		g commodity_group = .
		replace commodity_group = 1 if subgroup == 1 // cereals
		replace commodity_group = 2 if subgroup == 2 // Pulses
		replace commodity_group = 3 if subgroup == 4 // Milk
		replace commodity_group = 4 if subgroup == 9 // Edible oil
		replace commodity_group = 5 if subgroup == 8 // "Egg, fish, meat"
		replace commodity_group = 6 if subgroup == 5 // "Vegetables"
		replace commodity_group = 7 if subgroup == 6 // "Fruits fresh"
		replace commodity_group = 8 if subgroup == 7 // "Fruits dry"
		replace commodity_group = 9 if subgroup == 3 // "Salt & Sugar"  //Tendulkar: only Sugar
		replace commodity_group = 10 if subgroup == 10 // "Spices" //Tendulkar:  Salt-Spices
		replace commodity_group = 11 if inlist(subgroup, 11, 12, 13) // "Processed food", "Packaged food", "Beverages" //2011: other food
		replace commodity_group = 12 if inlist(subgroup, 26, 27, 28) //  "Pan", "Tobacco", "Intoxicants"  //Tendulkar: Intoxicants
		replace commodity_group = 13 if inlist(subgroup, 14) // "Fuel and light")
		replace commodity_group = 14 if inlist(subgroup, 29, 31) //  "Clothing", "Bedding" //Tendulkar: Clothing
		replace commodity_group = 15 if inlist(subgroup, 30) // "Footwear"	
		replace commodity_group = 16 if inlist(item, 405, 406, 400, 401, 404, 408, 409)	// Education
		replace commodity_group = 17 if inrange(item, 420,429)	// Medical (Non-institutional)
		replace commodity_group = 18 if inrange(item, 410,419)	// Medical (Institutional)
		replace commodity_group = 24 if inlist(item, 440,441,442,623,624,622,620,554,35,621,625,629)	// Other personal goods
		replace commodity_group = 20 if inlist(item, 601,602,600,603,604,609)	// Transport equipment
		replace commodity_group = 22 if inlist(item, 580,43,581,44,45,588,585,582,46,586,590,47,48,587,591,584,583,592,599) // Household appliances
		replace commodity_group = 22 if inlist(item, 466, 467, 465, 471, 464, 468, 470, 23, 460, 462, 461, 463, 472, 479)	// Other consumables
		replace commodity_group = 22 if inlist(item, 488, 487, 496, 540, 483, 480, 484, 482, 481, 27, 485, 486, 492, 495, 494, 493, 490, 497, 499) 	// Consumer services (excl. conveyance)
		replace commodity_group = 22 if inlist(item, 40, 41, 610, 42, 611, 619)		// Medical equipment
		replace commodity_group = 22 if inlist(item, 570, 571, 572, 50, 573, 579)	// Utensils
		replace commodity_group = 22 if inlist(item, 550, 551, 552, 553, 555, 556, 557, 559)	// Furniture
		replace commodity_group = 22 if inlist(item, 632, 630, 631, 633, 639)		// Land and buildings
		replace commodity_group = 23 if inlist(item, 437, 430, 402, 435, 433, 28, 438, 439)	// Entertainment
		replace commodity_group = 23 if inlist(item, 560, 561, 562, 563, 564, 569)	// Recreation
		replace commodity_group = 23 if inlist(item, 36, 37, 432, 97, 99)		// Sports goods
		replace commodity_group = 24 if inlist(item, 450,16,451,453,17,18,452,20,21,456,22,454,455,457,459)	// Toilet articles
		replace commodity_group = 24 if inlist(item, 640,641,642,643,649)	// Jewellary
		replace commodity_group = 990 if inlist(item, 520,521,522,523,529,539)	// Rent
		replace commodity_group = 991 if item==899	// Cess and taxes
		replace commodity_group = 992 if inlist(item, 24,504,25,506,505,500,508,501,510,26,511,503,512,513,514,519)	// Conveyance
	
	#delimit ;
	
	lab def commodity_group 1 "Cereals" 
							2 "Pulses" 
							3 "Milk" 
							4 "Oil" 
							5 "Egg,fish, meat" 
							6 "Vegetables" 
							7 "Fresh fruits" 
							8 "Dry fruits" 
							9 "Salt and sugar" 
							10 "Spices" 
							11 "Other food" 
							12 "Intoxicants" 
							13 "Fuel and light"
							14 "Clothing" 
							15 "Footwear" 
							16 "Education" 
							17 "Health (Non-institutional)" 
							18 "Health (Institutional)" 
							20 "Transports" 
							22 "Household good and services" 
							23 "Recreation" 
							24 "Personal care and effects" 
							990 "Rent" 
							991 "Cess and taxes" 
							992 "Conveyance" , modify;
	#delimit cr
	lab val commodity_group commodity_group	
		
	g food_item = inrange(commodity_group, 1, 11)
	g survey_type = 1 if inrange(subgroup, 1, 13)
	replace survey_type = 2 if inrange(subgroup, 14, 28)
	replace survey_type = 3 if inrange(subgroup, 29, 41)
	lab def survey_type 1 "FDQ" 2 "CSQ" 3 "DGQ"
	lab val survey_type survey_type


	*Create product codes
	g product_code = item
		replace product_code = 1000 if inlist(item, 61, 101, 102) //Rice 
		replace product_code = 2000 if inlist(item, 62, 107, 108) // Wheat
		replace product_code = 3000 if inlist(item, 70, 1, 2) //Coarse grains
		replace product_code = 4000 if inlist(item, 71, 158, 140, 141, 143,144,145,148) //Pulses
		replace product_code = 5000 if inlist(item, 72, 142) //Gram
		replace product_code = 6000 if inlist(item, 73, 178,170) //Salt
		replace product_code = 7000 if inlist(item, 74,171,172) // Sugar
		replace product_code = 8000 if inlist(item, 75,188,181,182,183,184)  //Edible oil
		replace product_code = 9000 if inlist(item, 334, 335)  //Kerosene
		replace product_code = 9001 if inlist(item, 356, 357, 900) //School uniform
		replace product_code = 9002 if inlist(item, 390, 394, 901) //School shoes
		
	g pds 			= inlist(item, 101, 107, 1, 55, 56, 57, 58, 59, 60, 158, 178, 171, 188, 334)	
	g free 			= inlist(item, 61, 62, 70, 63, 64, 65, 66, 67, 68, 71, 72, 73, 74, 75) 
	g free_nf  		= inlist(item, 900, 901)
	
	* items 139 and 899 are standalone and are included in the MPCE, so do not drop using subtotal flag.
	g subtotal 	= inlist(item, 99, 129, 159, 169, 179, 189, 199, 219, 239, 249, 269, 279, 289, 299, 309, 319, 329, 349, 379, 389, 399, 409, 419, 429, 439, 459, 479, 499, 519, 529, 539, 559, 569, 579, 599, 609, 619, 629, 639, 649) 
		
	g item_139 = item==139 //Cereal substitutes is an individual item but is not included in any of the sub-totals. Keep or drop as needed.
	

/*PLEASE READ COMMENTS CAREFULLY. 
Items below include sub-items and is reported as a total of these items. If working at individual item level, drop agg_item to avoid double counting.
		Other milk products(92) = Lassi(6) + Butter milk(7) + Others(167)
		Other fruits(93) 		= Litchi(235) + Pear(233) + Singara(227) + Jackfruit(221) + Berries(234) + Pineapple(223) + Others(238)
		Other dry fruits(94)	= Apricot(8) + Dry fig(10) + Others(247)
		Other edible oil(95) 	= Vanaspati, margarine(180) + Others(185)
		Other fuel(96) 			= Charcoal(341) + Biogas, gobar gas(343) + Coal(337) + Dung cake(333) + Petrol(litre)[excl. conveyance(344)] + Diesel(litre)[excl. conveyance](345) + Other natural gas(CNG, etc.)(340) + Matches(box)(336) + Candle(no.)(342) + Others(346)
Information on coarse grains is collected at item level in some of the states - Rajasthan, Punjab, Haryana, Gujarat, Andhra Pradesh, Tamil Nadu, Kerala, Karnataka, Telangana & Uttar Pradesh. If working with coarse grains (1,2,70), drop agg_grains to avoid double counting in these states.  */
		
	g agg_item = inlist(item, 92, 93, 94, 95, 96)		
	g sub_grains = inlist(item, 55, 56, 57, 58, 59 ,60, 115, 116, 117, 118, 121, 120, 63, 64, 65, 66, 67, 68) 
	
	g no_qty = missing(unit)
		replace no_qty = 1 if inlist(item, 6, 7, 167, 92)
		
		lab var subgroup "item subgroup"
		lab var pds "dummy for PDS items"
		lab var subtotal "dummy for item sub-totals"
		lab var no_qty "dummy for items with no unit or quantity information"
		lab var year "survey year"
		*lab var cpi_description "cpi sub-group description"
		lab var commodity_group "commodity groups (based on Tendulkar committee report)"
		lab var product_code "pds + market items as one product"
		*lab var scode "cpi sub-groups"	
		lab var survey_type "survey type - FDQ, CSQ, DGQ"
		lab var free "dummy for free food items"
		lab var item_139 "dummy for item 139"
		lab var agg_item "dummy for aggregated items"
		lab var sub_grains "dummy for grains that are aggregated"
		
		
	keep item item_desc recall_period unit commodity_group food_item survey_type product_code pds free subtotal sub_grains item_139 no_qty free* agg_item


	*Save master_item_list_2022 in processed folder
	save "${user}/data/processed/ces/master_item_list_2022.dta", replace
			
	***************************
	*02. MASTER OF CONSUMPTION 
	****************************
	
	*Create master for quantities and values for every item	
	*Output: hhid, item, item_grpup_2022, unit, recall_period, qty_total, value_total
	
	*Food 
	use "${user}/data/processed/ces/level05_2022.dta", clear 
		keep year hhid item source qty_total value_total 
		sort year hhid item	
		g item_group = "Food"	
		tempfile food_1
	save `food_1'
	
	use  "${user}/data/processed/ces/level06_2022.dta", clear 	
		keep year hhid item source qty_total value_total
		sort year hhid item	
		g item_group = "Food"	
		tempfile food_2
	save `food_2'

	*50 households not reporting any food expenditure. Need to be dropped
	use `food_1'
	append using `food_2'
	collapse value_total, by (hhid)
	merge 1:1 hhid using "${user}/data/processed/ces/hh_2022_old.dta"	
	unique hhid if _m==2	
	di in red "50 households not reporting any food expenditure saved as temp data"
	keep if _m==2 
	tostring(hhid), replace
	drop _m
	tempfile hh_nofood
	save `hh_nofood'
	
	*Create master household after dropping these 50 households
	use "${user}/data/processed/ces/hh_2022_old.dta", clear
	merge 1:1 hhid using "`hh_nofood'"
	keep if _m==1
	drop _m
	save "${user}/data/processed/ces/master_hh_2022.dta", replace

	*CONSUMABLES
	use  "${user}/data/processed/ces/level08_2022.dta", clear 
		keep year hhid item source qty_total value_total
		sort year hhid item
		g item_group = "Consumable"
		tempfile consumable_1
	save `consumable_1'
	
	use  "${user}/data/processed/ces/level09_2022.dta", clear 
		keep year hhid item  value_total
		sort year hhid item	
		g qty_total = .	
		g item_group = "Consumable"	
		tempfile consumable_2
	save `consumable_2'
	
	use  "${user}/data/processed/ces/level10_2022.dta", clear 	
		keep year hhid item source qty_total value_total
		sort year hhid item
		destring source, replace
		g item_group = "Consumable"
		tempfile consumable_3
	save `consumable_3'
	
	*FREE NON-FOOD (SCHOOL UNIFORMS AND SHOES)
	use "${user}/data/processed/ces/level11_2022.dta", clear

	*Create sub-dataset for free uniforms. Assign item code "900" to free uniforms
		preserve
		keep hhid clothing_free num_clothing_free 
		keep if clothing_free==1
		gen item = . 
		replace item = 900 
		rename num_clothing_free qty_total
		drop clothing_free
		
		tempfile uniforms_free
		save `uniforms_free', replace
		restore
		
	*Create sub-dataset for free shoes. Assign item code "901" to free shoes
		preserve
		keep hhid footwear_free num_footwear_free 
		keep if footwear_free==1	
		gen item = . 
		replace item = 901		
		rename num_footwear_free qty_total
		drop footwear_free
		
		tempfile footwear_free
		save `footwear_free', replace
		restore
		
	*Append both sub-datasets to create a non-food free dataset
		use `uniforms_free', clear
		append using `footwear_free'
		
		gen value_total = 0
		sort hhid item qty_total value_total
	
		tempfile nonfood_free
		save `nonfood_free', replace
	
	*Keep only households that receive free uniforms/shoes AND go to government schools
		use "${user}/data/processed/ces/level07_2022.dta", clear
		keep if ~inlist(num_govt_institution, 0, .)
		keep hhid num_govt_institution	
		merge 1:m hhid using `nonfood_free'
		di in red "18671 households receive free uniforms/shoes AND go to govt. schools"
		keep if _m==3 
		drop _m
		tempfile nonfood_free_govt
		save `nonfood_free_govt', replace
			
	*Durables
	use  "${user}/data/processed/ces/level12_2022.dta", clear 	
		keep year hhid item qty_total value_total
		sort year hhid item
		g item_group = "Durables"	
		tempfile durables_1
	save `durables_1'
	
	use  "${user}/data/processed/ces/level13_2022.dta", clear 
		g qty_total = .
		keep year hhid item value_total
		sort year hhid item	
		g item_group = "Durables"	
		tempfile durables_2
	save `durables_2'
	
	*Append all 
	use `food_1' 
		append using `food_2'
		append using `consumable_1'
		append using `consumable_2'
		append using `consumable_3'
		append using `nonfood_free_govt'
		append using `durables_1'
		append using `durables_2'

	drop if mi(hhid) | mi(item)	
	replace year = "2022" if missing(year)
	replace item_group = "Durables" if inlist(item, 900, 901)

	*Merge with master household and item list constructed above
	merge m:1 hhid using "${user}/data/processed/ces/master_hh_2022.dta", keepusing(survey_seq panel) keep(3) nogen //Note that 50 households reporting no food consumption would be dropped in this merge
	merge m:1 item using "${user}/data/processed/ces/master_item_list_2022.dta", keepusing( survey_type unit recall_period) keep(3) nogen
	
	destring year, replace
	merge m:1 hhid using `hh_nofood'
	drop if _m ==2
	
	*Create survey month
	split survey_seq, p("-") 
 	destring survey_seq1 survey_seq2 survey_seq3, replace
 	g seq = .
 	foreach j of numlist 1(1)3{
 			replace seq = 1 if  survey_seq1==`j' & survey_type==`j'
 			replace seq = 2 if  survey_seq2==`j' & survey_type==`j'
			replace seq = 3 if  survey_seq3==`j' & survey_type==`j'		
		}
 	g temp_month = .
 	foreach p of numlist 1(1)10{
 		replace temp_month = 6 + `p' + seq if panel==`p' 
 	}
 	g survey_month = .
 	foreach m of numlist 8(1)19 {
		replace survey_month = tm(2022m8) - 8 + `m' if temp_month==`m'
 	}
 	format survey_month %tm
	destring year, replace

	*Make units homogenous for comparability of unit prices
	g double qty_new = qty_total
		replace qty_new= qty_total/1000 if unit=="gm"	
		
	g double value_total_30d = value_total if recall_period==30
		replace value_total_30d= value_total*30/7 if recall_period==7
		replace value_total_30d = value_total*30/365 if recall_period==365
		
	keep year survey_month hhid item source qty_total qty_new value_total value_total_30d
	
	*Save master consumption in the processed data
	save "${user}/data/processed/ces/master_consumption_2022.dta", replace
	
	*Sanity check for households dropped
	use "${user}/data/processed/ces/hh_2022_old.dta", clear
	merge 1:1 hhid using "${user}/data/processed/ces/master_hh_2022.dta" 
	unique hhid if _m==1 

	* ==========================================================================*
	di in red "THE END OF 02_master_datasets_create" 
	* ==========================================================================*
	cap log close
	exit