	
	loc date: display %tdCCYY-NN-DD =daily("`c(current_date)'", "DMY")
	cap log close
	log using "${user}/output/log/02a_match_survey_cpi_items_2011_`date'", replace

	/* =============================================================================
		Project			: India poverty estimates - 2011-12 & 2022-23 
		Dofile			: 02a_match_survey_cpi_items_2011.do
		Last modified	: 25th March 2025
		File purpose	: This is an auxiliary dofile which will be used in 
						  02_master_datasets_create.dofile. The codes match the 
						  sub-goup CPIs with the 2011-12 survey items for intra-temporal
						  deflation				  
	============================================================================= */

	/*******************************************************************************
		Additional notes - 
		*Each item is classified in one of the six groups - 
			1. Food and beverages
			2. Pan, tobacco, and intoxicants
			3. Clothing and footwear
			4. Housing
			5. Fuel and light
			6. Miscellaneous
		*Sub-totals identified as 111 in the sub-scode category.
	*******************************************************************************/

	***********
	*2011
	***********
	use "${user}/data/processed/ces/master_item_list_2011.dta", clear 
	
	gen scode = .
	gen cpi_description = "."
	
	***********
	*Group 1: Consumption of cereals, pulses, milk and milk products, sugar and salt during the last 30 days 
	***********

	*Section 5.1:Consumption of cereals during the last 30 days

	*Cereals and cereal substitutes
	replace scode = 1101 if inlist(item,  101, 102, 103, 104, 105, 106, 107, 108, 110, 111, 112, 113, 114, 115, 116, 117, 118, 120, 121, 122, 129, 139, 486)
	replace cpi_description = "Cereals and products" if inlist(item,  101, 102, 103, 104, 105, 106, 107, 108, 110, 111, 112, 113, 114, 115, 116, 117, 118, 120, 121, 122, 129, 139, 486)

	*Pulses
	replace scode = 1108 if inlist(item, 140, 141, 142, 143, 144, 145, 146, 147, 148, 150, 151, 152, 159)
	replace cpi_description = "Pulses and products" if inlist(item, 140, 141, 142, 143, 144, 145, 146, 147, 148, 150, 151, 152, 159)

	*Sugar and confectionery
	replace scode = 1109 if inlist(item, 166, 171, 172, 173, 174, 175, 179)
	replace cpi_description = "Sugar and confectionery"  if inlist(item, 166, 170, 171, 172, 173, 174, 175, 179)	
	
	***********
	*Group 1: Consumption of milk & milk products, vegetables, fruits, egg, fish & meat, edible oil, spices, beverages during the last 7 days
	***********

	* Milk and milk products 
	replace scode = 1104 if inlist(item, 160, 161, 162, 163, 164, 163, 165, 167, 169)
	replace cpi_description = "Milk and products" if inlist(item, 160, 161, 162, 163, 164, 163, 165, 167, 169) 

	* Vegetables
	replace scode = 1107 if inlist(item, 200, 201, 202, 203, 204,  205, 206, 207, 208, 210, 211, 212, 213, 214, 215, 216, 217, 219)
	replace cpi_description = "Vegetables" if inlist(item, 200, 201, 202, 203, 204,  205, 206, 207, 208, 210, 211, 212, 213, 214, 215, 216, 217, 219)
	 
	*Fruits (fresh)
	replace scode = 1106 if inlist(item, 220, 221, 222, 223, 224, 225, 226, 227,  228, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239)
	replace cpi_description = "Fruits" if inlist(item, 220, 221, 222, 223, 224, 225, 226, 227,  228, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239)
	 	 
	*Fruits (dry)
	replace scode = 1106 if inlist(item, 240, 241, 242, 243, 244, 245, 246, 247, 249)
	replace cpi_description = "Fruits"  if inlist(item, 240, 241, 242, 243, 244, 245, 246, 247, 249)

	* Eggs, fish and meat 
	replace scode = 1103 if inlist(item, 190)
	replace cpi_description = "Egg"  if inlist(item, 190)

	replace scode = 1102 if inlist(item, 195, 191, 192, 193, 194,  196, 199)  
	replace cpi_description = "Meat and fish" if inlist(item, 195, 191, 192, 193, 194,  196, 199)  

	*Edible oils
	replace scode = 1105 if inlist(item, 180, 181, 182, 183, 184, 185, 189)
	replace cpi_description = "Oils and fats" if inlist(item, 180, 181, 182, 183, 184, 185, 189)

	*Spices
	replace scode = 1110 if inlist(item, 170, 250, 251, 252, 253, 254, 255, 256, 257, 258, 260, 261, 269)
	replace cpi_description = "Spices" if inlist(item, 170, 250, 251, 252, 253, 254, 255, 256, 257, 258, 260, 261, 269)

	*Non-alcoholic beverages
	replace scode = 1211 if inlist(item, 270, 271, 272, 273, 274,  275, 276, 277, 279)
	replace cpi_description = "Non-alcoholic beverages"  if inlist(item, 270, 271, 272, 273, 274,  275, 276, 277, 279)

	***********
	*Group 1 : Consumption of processed food during the last 7 days
	***********

	*Served processed food 
	replace scode = 1112 if inlist(item,280, 281, 282, 283, 284, 289)
	replace cpi_description = "Prepared meals; snacks; sweets etc." if inlist(item,280, 281, 282, 283, 284, 289)

	*Packaged processed food 
	replace scode = 1112 if inlist(item, 290, 291, 292, 293, 294, 295, 296, 299)
	replace cpi_description = "Prepared meals; snacks; sweets etc." if inlist(item, 290, 291, 292, 293, 294, 295, 296, 299)

	
	***********
	*Group 2: Consumption of pan, tobacco and intoxicants during the last 7 days
	***********
	
	*Pan, tobacco and intoxicants s.t. 
	replace scode     =  2000    if inrange(item, 300, 329)
	replace cpi_description = "Pan; tobacco; and intoxicants" if scode==2000
	
	***********
	*Group 3: Consumption of clothing, bedding, etc. during the last 365 days
	***********	
	
	*Clothing
	replace scode = 3101 if inrange(item, 350, 379)
	replace scode = 3101 if inlist(item, 484, 485) //washerman and tailoring
	replace cpi_description = "Clothing" if inrange(item, 350, 379)
	replace cpi_description = "Clothing" if inlist(item, 484, 485)

	*Footwear
	replace scode = 3102 if inrange(item, 390, 399)
	replace cpi_description = "Footwear" if inrange(item, 390, 399)
	
	***********
	*Group 4: Expenditure on housing in the last 30 days
	***********		
	
	*Housing s.t. 
	
	replace scode = 4000 if inlist(item, 520, 521, 522, 523, 529, 539, 540, 541, 549, 632)
	replace scode = 4000 if inlist(item, 520, 521, 522, 523, 529, 539, 540, 541, 549, 632)
	replace cpi_description = "Housing" if inlist(item, 520, 521, 522, 523, 529, 539, 540, 541, 549, 632)
	replace cpi_description = "Housing" if scode==4000
	
	***********
	*Section 5: Consumption of energy during the last 30 days
	***********

	*Fuel and light s.t.
	replace scode = 5000 if inrange(item, 330, 349)
	replace cpi_description = "Fuel and light" if scode==5000
	
	***********
	*Section 6: Consumption of miscellaneous items in the last 365 days
	***********	
	
	*Household goods and services
	replace scode = 6101 if inrange(item, 380, 389) //Bedding
	replace scode = 6101 if inlist(item, 480, 481, 482, 491, 492, 493, 494, 495, 497, 499) //Consumer services excluding conveyance
	replace scode = 6101 if inrange(item, 550, 559) //Furniture and fixtures
	replace scode = 6101 if inrange(item, 580, 599) //Cooking and other household appliances
	replace scode = 6101 if inrange(item, 570, 579) //Crockery and utensils
	replace scode = 6101 if inrange(item, 460, 479) //Other household consumables
	replace scode = 6101 if inlist(item, 441, 442) //Torch and lock
	replace scode = 6101 if inlist(item, 621) //Other machines for household work
	replace scode = 6101 if inlist(item, 630, 631, 633, 639, 610, 611, 619, 659) //Other machines for household work; electrical fittings; other durables
	replace cpi_description = "Household goods and services" if scode==6101
		
	*Health
	replace scode = 6102 if inrange(item, 410, 429) //Institutional and non-institutional medical expenses
	replace scode = 6102 if item==440 //Spectacles
	replace cpi_description = "Health" if scode== 6102
	
	*Transport and communication
	replace scode = 6103 if inrange(item, 600, 609) //Personal transport equipment
	replace scode = 6103 if inlist(item, 623, 624) //Mobile and telephone
	replace scode = 6103 if inlist(item, 487, 488, 490, 496) //Telephone; telegram; internet charges 
	replace scode = 6103 if inrange(item, 500, 519) //Conveyance
	replace cpi_description = "Transport and communication" if scode==6103
	
	*Recreation and amusement
	replace scode = 6104 if inrange(item, 430, 439) //Entertainment
	replace scode = 6104 if inrange(item, 560, 569) //Goods for recreation
	replace scode = 6104 if inlist(item, 622 ) //PC/Laptop
	replace scode = 6104 if inlist(item, 402, 403) //Newspaper and library charges
	replace cpi_description = "Recreation and amusement" if scode==6104
	
	*Education
	replace scode = 6105 if inlist(item, 400, 401, 404, 405, 406, 407, 408, 409) //Education expenses 
	replace cpi_description = "Education" if scode==6105
	
	*Personal care and effects
	replace scode = 6106 if inlist(item, 443, 444, 445, 449) //Minor durable-type goods
	replace scode = 6106 if inrange(item, 450, 459) //Toilet articles
	replace scode = 6106 if inlist(item, 620) //Clock, other machines for household work
	replace scode = 6106 if inlist(item, 625, 629) //Other personal goods
	replace scode = 6106 if inrange(item, 640, 649) //Jewellery and ornaments
	replace scode = 6106 if inlist(item, 483) //Barber; beautician
	replace cpi_description = "Personal care and effects" if scode==6106
	
	save "${user}/data/processed/ces/master_item_list_2011.dta", replace
	
	* ==========================================================================*
	di in red "THE END OF 02a_match_survey_cpi_items_2011" 
	* ==========================================================================*

	cap log close
	exit