
	loc date: display %tdCCYY-NN-DD =daily("`c(current_date)'", "DMY")
	cap log close
	log using "${user}/output/log/02b_match_survey_cpi_items_2022_`date'", replace

	/* =============================================================================
		Project			: India poverty estimates - 2011-12 & 2022-23 
		Dofile			: 02b_match_survey_cpi_items_2022.do
		Last modified	: 25th March 2025
		File purpose	: This is an auxiliary dofile which will be used in 
						  02_master_datasets_create.dofile. The codes match the 
						  sub-goup CPIs with the 2022-23 survey items for intra-temporal
						  deflation				  
	============================================================================= */

	/*******************************************************************************
		Additional notes - 
		*Each item is classified in one of the six groups - 
			1. Food and beverages
			2. Pan, tobacco, and intoxicants
			3. Clothing and footwear
			4. Housing
			5. Fuel and light
			6. Miscellaneous
		*Sub-totals identified as 111 in the sub-scode category.
	*******************************************************************************/

	***********
	*2022
	***********
	use  "${user}/data/processed/ces/master_item_list_2022.dta", clear

	gen scode = .
	gen cpi_description = "."

	***********
	*Group 1: Consumption of cereals, pulses, milk and milk products, sugar and salt during the last 30 days 
	***********
	
	* Cereals and cereal substitutes
	replace scode = 1101 if inrange(item, 55, 70)
	replace scode = 1101 if inrange(item, 101,122)		
	replace scode = 1101 if item==139	// Cereals substitute
	replace scode = 1101 if inlist(item, 1, 2, 129) //subtotals
	replace scode = 1101 if inlist(item, 13, 291) //biscuits and chocolates
	replace scode = 1101 if item==113	// Bread
	replace scode = 1101 if item==486	// Grinding charges
	replace cpi_description = "Cereals and products" if scode == 1101
	
	* Pulses and products
	replace scode = 1108	if inrange(item, 140,159)
	replace scode = 1108	if inlist(item, 71,72)
	replace cpi_description = "Pulses and products" if scode == 1108
	
	* Sugar and confectionery
	replace scode = 1109 if inlist(item, 74, 171, 172, 173, 174, 175, 179)
	replace scode = 1109 if item==166 //icecream
	replace scode = 1109 if item==295 //sauce, jam, jelly
	replace cpi_description = "Sugar and confectionery" if scode == 1109
	
	* Milk and mik products
	replace scode = 1104 if inlist(item, 160, 162, 161, 164, 163, 165, 167, 169, 3, 5, 6, 7, 92)
	replace cpi_description = "Milk and products" if scode == 1104
	
	* Spices
	replace scode = 1110 if inlist(item, 73, 170, 178) //salt
	replace scode = 1110 if inlist(item, 256, 254, 252, 253, 258, 255, 257, 260, 263, 261, 269)
	replace cpi_description = "Spices" if scode == 1110
		
	* Prepared meals; snacks; sweets etc.
	replace scode = 1112 if item==4 //prepared sweets
	replace scode = 1112 if inlist(item, 12, 290, 292, 293, 14, 15, 296, 299) //packaged processed food
	replace scode = 1112 if inlist(item, 76, 280, 281, 282, 283, 284, 289, 290) //served processed food
	replace scode = 1112 if inlist(item, 270, 272) //Tea and coffee cups	
	replace cpi_description = "Prepared meals; snacks; sweets etc." if scode == 1112
	
	* Vegetables
	replace scode = 1107 if inrange(item, 200, 219)
	replace scode = 1107 if inlist(item, 250, 251) //garlic, ginger
	replace scode = 1107 if item==294 //pickles
	replace cpi_description = "Vegetables" if scode == 1107

	* Fruits (fresh)
	replace scode = 1106 if inrange(item, 220, 239)
	replace scode = 1106 if item==93	
	replace cpi_description = "Fruits" if scode == 1106
	
	* Fruits (dry)
	replace scode = 1106 if inrange(item,240,249)
	replace scode = 1106 if inlist(item,8,10,94)
	replace cpi_description = "Fruits" if scode == 1106
	
	* Egg
	replace scode = 1103 if item==190
	replace cpi_description = "Egg" if scode == 1103
	
	* Meat and fish
	replace scode = 1102 if inrange(item, 191, 199)
	replace cpi_description = "Meat and fish" if scode == 1102
	
	* Edible oils
	replace scode = 1105 if inrange(item,180,189)
	replace scode = 1105 if inlist(item,95,75)
	replace cpi_description = "Oils and fats" if scode == 1105

	* Non-alcoholic beverages
	replace scode = 1211 if inlist(item,271, 273, 274, 275, 276, 278, 279) 
	replace scode = 1211 if item==11
	replace cpi_description = "Non-alcoholic beverages"  if scode == 1211
	
	***********
	*Group 2: Consumption of pan, tobacco and intoxicants during the last 7 days
	***********
	
	*Pan, tobacco and intoxicants s.t. 
	replace scode =  2000  if inrange(item,300,309) //pan
	replace scode =  2000  if inrange(item, 310,319) //tobacco
	replace scode =  2000  if inrange(item,320,329) //intoxitants
	replace cpi_description = "Pan; tobacco; and intoxicants" if scode==2000
	
	***********
	*Group 3: Consumption of clothing, bedding, etc. during the last 365 days
	***********	
	
	*Clothing
	replace scode = 3101 if inlist(item, 351, 352, 353, 30, 363, 31, 364, 354, 32, 358, 360, ///
	356, 357, 33, 361, 362, 365, 34, 368, 355, 366, 367, 370, 350, 371, 372, 373, 374, 375, 379, 900)	
	replace scode = 3101 if inlist(item, 484, 485) //washerman, tailoring
	replace cpi_description = "Clothing" if scode == 3101
	
	*Footwear
	replace scode = 3102 if inrange(item,390,399)
	replace scode = 3102 if item==901
	replace cpi_description = "Footwear" if scode == 3102
	
	
	***********
	*Group 4: Expenditure on housing in the last 30 days
	***********		
	
	*Housing s.t. 
	replace scode = 4000 if inlist(item, 520, 521, 522, 523, 529, 539, 899, 632) 
	replace scode = 4000 if inlist(item, 540) //water charges 
	replace scode = 4000 if inlist(item, 27) //watchman, driver charges 
	replace cpi_description= "Housing" if scode==4000
	
	***********
	*Section 5: Consumption of energy during the last 30 days
	***********

	*Fuel and light s.t.
	replace scode = 5000 if inlist(item, 332, 338, 331, 334, 335, 96, 349, 341, 343, 337, 333, 344, 345, 340, 336, 342, 346, 349)
	replace cpi_description= "Fuel and light" if scode==5000
	
	***********
	*Section 6: Consumption of miscellaneous items in the last 365 days
	***********	
	
	*Household goods and services
	replace scode = 6101 if inlist(item, 550, 551, 552, 553, 555, 556, 557, 559) //Furniture and fixtures
	replace scode = 6101 if inlist(item, 480, 482, 481, 492, 495, 494, 493, 497, 499) //Consumer services excluding conveyance
	replace scode = 6101 if inlist(item, 380, 381, 383, 382, 385, 384, 386, 389) //Bedding	
	replace scode = 6101 if inlist(item, 580, 43, 581, 44, 45, 588, 585, 582, 46, 586, 590, 47, 48, 587, 591, 584, 583, 592, 599) //Cooking and other household appliances
	replace scode = 6101 if inlist(item, 570, 571, 572, 50, 573, 579) //Crockery and utensils
	replace scode = 6101 if inlist(item, 466, 467, 465, 471, 464, 468, 470, 23, 460, 462, 461, 463, 472, 479) //Other household consumables
	replace scode = 6101 if inlist(item, 630, 631, 633, 639) //Other durables and sanitary ware
	replace scode = 6101 if inlist(item, 40, 41, 610, 42, 611, 619) //Medical equipment
	replace cpi_description= "Household goods and services" if scode==6101
		
	*Health
	replace scode = 6102 if inlist(item, 410, 412, 411, 413, 414, 419, 420, 422, 421, 423, 424, 429) //Institutional and non-institutional medical expenses
	replace scode = 6102 if item==440 //Spectacles
	replace cpi_description= "Health" if scode==6102
	
	*Transport and communication
	replace scode = 6103 if inlist(item, 601, 602, 600, 603, 604, 609) //Personal transport equipment
	replace scode = 6103  if inlist(item, 623, 624) //Mobile and telephone
	replace scode = 6103  if inlist(item, 487, 488, 496) //Telephone; telegram; internet charges 
	replace scode = 6103  if inlist(item, 490) //Postage, couriers, fax and money order 
	replace scode = 6103  if inlist(item, 24, 504, 25, 506, 505, 500, 508, 501, 510, 26, 511, 503, 512, 513, 514, 519) //Conveyance
	replace cpi_description= "Transport and communication" if scode==6103 
	
	*Recreation and amusement
	replace scode = 6104 if inlist(item, 437, 430, 402, 435, 433, 28, 438, 439) //Entertainment
	replace scode = 6104 if inlist(item, 560, 561, 562, 563, 564, 569) //Goods for recreation
	replace scode = 6104 if inlist(item, 622) //PC/Laptop
	replace scode = 6104 if inlist(item, 36, 37, 432, 97, 99) //Sports goods
	replace cpi_description= "Recreation and amusement" if scode==6104
	
	*Education
	replace scode = 6105 if inlist(item, 405, 406, 400, 401, 404, 408, 409) //Education expenses 
	replace cpi_description= "Education" if scode==6105
	
	*Personal care and effects
	replace scode = 6106 if inlist(item, 441, 442) //Minor durable-type goods
	replace scode = 6106 if inlist(item, 450, 16, 451, 453, 17, 18, 452, 20, 21, 456, 22, 454, 455, 457, 459) //Toilet articles
	replace scode = 6106 if inlist(item, 620, 554, 35, 621, 625, 629) //Clock; handbags; headphones; other machines for household work; other personal goods
	replace scode = 6106 if inlist(item, 640, 641, 642, 643, 649) //Jewellery and ornaments
	replace scode = 6106 if inlist(item, 483) //Barber; beautician
	replace cpi_description= "Personal care and effects" if scode==6106
		
	save  "${user}/data/processed/ces/master_item_list_2022.dta", replace
		
	* ==========================================================================*
	di in red "THE END OF 02b_match_survey_cpi_items_2022" 
	* ==========================================================================*
	cap log close
	exit