
	loc date: display %tdCCYY-NN-DD =daily("`c(current_date)'", "DMY")
	cap log close
	log using "${user}/output/log/02d_PDS_imputation_2022_`date'.log", replace

	/* =============================================================================
		Project			: India poverty estimates - 2011-12 & 2022-23 
		Dofile			: 02d_PDS_imputation_2022
		Last modified	: 25th March, 2025

		Inputs			: "${user}/data/processed/ces/master_consumption_2022.dta"
						  "${user}/data/processed/ces/master_item_list_2022.dta"
						  "${user}/data/processed/ces/master_hh_2022.dta"
						
		Outputs			: "${user}/data/processed/ces/all_pds_items_2022.dta",
						  "${user}/data/processed/ces/temp/temp_all_pds_items_2022_mkt_med"
						  "${user}/data/processed/ces/pds_imputed_uv_vector_2022.dta"
										
		Steps			: * 0. Set up
						  * 1. Merge data and create survey month
						  * 2. Create PDS variables and correspondance
						  * 3: Calculate median and sample size
						  * 4: Identify and invalidate negative subsidies
						  * 5: Deal with issues of small (coarse) grains
						  * 6: Generate most-Local scenario (7)
						  * 7: Vector of imputed prices 			
	============================================================================= */

	*============================================================================*
	 di in red "STEP 0: Set up" 
	*============================================================================*
	loc time month 	// Substitute for name of time variable

	* Define hierarchy of aggregation
	loc aggr1 = "products `time' state sector sss" 
	loc aggr2 = "products `time' state sector"  
	loc aggr3 = "products `time' state"  		
	loc aggr4 = "products `time' sector"  		
	loc aggr5 = "products `time' "  		
	loc aggr6 = "products "  			

	*============================================================================*
	di in red "STEP 1: Merge data on PDS items" 
	*============================================================================*

	use "${user}/data/processed/ces/master_consumption_2022.dta", replace
	merge m:1 item using "${user}/data/processed/ces/master_item_list_2022.dta", keepusing(commodity_group unit item_desc recall_period survey_type product_code) keep(3) nogen
	merge m:1 hhid using "${user}/data/processed/ces/master_hh_2022.dta", keepusing(state sector district hhsize pwt hhw sss) keep(3) nogen	

	order hhid item source recall_period qty_total value_total state sector survey_month commodity_group
	keep hhid item source recall_period qty_total value_total state sector item_desc sss pwt hhw hhsize survey_month commodity_group product_code
	keep if (item == 334 | item==335) | commodity_group<12  // keeping only kerosene or food
		
	*============================================================================*
	di in red "STEP 2: Create PDS variables and correspondance" 
	*============================================================================*
	*2.1 Label main items
	/* The HCES classifies "Other sources" as Market. They can be either
	purchased (source==1) or from other source (e.g. gifted, etc.)*/
	#delimit ;
	lab define item 
		61	"61 Rice - Free"
		101	"101 Rice - PDS	Subs"
		102	"102 Rice - Other"
		62	"62 Wheat/Atta - Free"
		107	"107 Wheat/Atta - PDS Subs"
		108	"108 Wheat/Atta - Other"
		70	"70 Coarse Grains - Free"
		1	"1 Coarse Grains - PDS Subs"
		2	"2 Coarse Grains - Other"
		71	"71 Pulses - Free"
		158	"158 Pulses - PDS Subs"
		140	"140 Arhar, Tur	- Other [PULSE]"
		141	"141 Gram Split	- Other [PULSE]"
		143	"143 Moong - Other [PULSE]"
		144	"144 Masur - Other [PULSE]" 
		145	"145 Urd - Other [PULSE]" 
		148	"148 Othr Pulses - Mkt [PULSE]"
		72	"72 Gram - Free"
		142	"142 Gram Whole - Other"
		73	"73 Salt - Free"
		178	"178 Salt - PDS	Subs"
		170	"170 Salt – Other"
		74	"74 Sugar - Free"
		171	"171 Sugar - PDS Subs"
		172	"172 Sugar - Other"
		75	"75 Edible Oil - Free"
		188	"188 Edible Oil - PDS"
		181	"181 Mustard Oil - Other"
		182	"182 Groundnut Oil - Other"
		183	"183 Coconut Oil - Other"
		184	"184 Refined Oil - Other"
		55 "55 Jowar - PDS [GRAIN]"
		56 "56 Bajra - PDS Subs [GRAIN]"
		57 "57 Maize - PDS Subs [GRAIN]"
		58 "58 Barley - PDS Subs [GRAIN]"
		59 "59 Ragi - PDS Subs [GRAIN]"
		60 "60 Small Millets - PDS Subs [GRAIN]"
		63 "63 Jowar - Free [GRAIN]"
		64 "64 Bajra - Free [GRAIN]"
		65 "65 Maize - Free [GRAIN]"
		66 "66 Barley - Free [GRAIN]"
		67 "67 Ragi - Free [GRAIN]"
		68 "68 Small Millets - Free [GRAIN]"
		115 "115 Jowar - Other [GRAIN]"
		116 "116 Bajra - Other [GRAIN]"
		117 "117 Maize - Other [GRAIN]"
		118 "118 Barley - Other [GRAIN]"
		120 "120 Small Millets - Other [GRAIN]"
		121 "121 Ragi - Other [GRAIN]" 
		334 "334 Kerosene – PDS Subs" 
		335 "335 Kerosene – Other"	;
	#delimit cr
	lab val item item	
			
	*2.2 - PDS // Items purchased @ subsidized PDS price OR free.
	cap drop pds
	g pds=0
	replace pds=1 if inrange(item, 55, 75)
	replace pds = 1 if inlist(item, 101, 107, 158, 171, 178, 188, 1, 334)
	
	lab define pds 0 "Not received from PDS (free/subs)" 1 "Received from PDS (free/subs)"
	lab val pds pds
	lab var pds "PDS Item (Free or Subsidized)"
	
	*2.3 - Price
	g price = 0
		replace price=1 if inrange(item, 61, 75)
		replace price=2 if inlist(item, 101, 107, 158, 171, 178, 188, 1, 334)
		replace  price=2 if inrange(item, 55, 60)
		
  		replace price=3 if inlist(item, 102, 108, 2,170, 172, 335, 140, 141, 142, 143, 144, 145, 148, 181, 182, 183, 184, 115, 116, 117, 118, 120, 121) & source==1
		
	lab define price ///
		1 "Free Price" ///
		2 "Subsidized Price" ///
		3 "Market purchased Price, PDS-related items" ///
		0 "Other Item, unrelated to PDS" 
	lab values price price
	
	di in red "Droping any PDS-unrelated items"
	drop if price==0
				
	*2.4 - Unitary value - Defined for purchases only (source==1)
	
	/*First adjust by householdsize variation
	g double value_adj1 		= value_total 						if survey_type==1 
			replace value_adj1 	= value_total *(hhsize2/hhsize3) 	if survey_type==2
			replace value_adj1 	= value_total *(hhsize2/hhsize4) 	if survey_type==3
	// PROBLEM: REVIEW METHOD IN GENERAL WITH CORE TEAM. IGNORED FOR NOW!!*/
		
	g double uv_mkt 		= value_total/qty_total 	if (pds==0 & source==1) // Same recall period
	g double uv_pds_subs 	= value_total/qty_total  	if (pds==1 & source==1) // Same recall period
		la var uv_mkt 		"Unitary value for ietms purchased in market"
		la var uv_pds_subs 	"Unitary value for items purchased from PDS"
	
	di in red "Unitary values paid @ mrt price and @ subsidized price"
		tabstat uv_mkt uv_pds_subs [w=pwt], by(pds) stats(mean min median max) notot
		tabstat uv_mkt uv_pds_subs [w=pwt], by(price) stats(mean min median max) notot

	*2.5 - Products // Correspondance of PDS and Market items
	g products = 0
		replace products=1000 if item==61 | item==101 | item==102
		replace products=2000 if item==62 | item==107 | item==108
		replace products=3000 if item==70 | item==1 | item==2 
			replace products=3001 if item==63 | item==115 | item==55 
			replace products=3002 if item==64 | item==116 | item== 56
			replace products=3003 if item==65 | item==117 | item== 57
			replace products=3004 if item==66| item==118 | item== 58
			replace products=3005 if item==67 | item==121 | item== 59
			replace products=3006 if item==68 | item==120 | item==60 
		replace products=4000 if item==71 | item==158 | item==140 | /// 
				item==143 | item==144 | item==145 | item==148 | item==141 
		replace products=5000 if item==72 | item==142 
		replace products=6000 if item==73 | item==178 | item==170
		replace products=7000 if item==74 | item==171 | item==172
		replace products=8000 if item==75 | item==188 | item==181 | item==184 | item==182 | item==183
		replace products=9000 if item==334 | item==335
	
	#delimit ;
	lab define products 
			1000 "Rice" 
			2000 "Wheat"
			3000 "Grains" 
				3001 "Jowar" 
				3002 "Bajra" 
				3003 "Maize" 
				3004 "Barley" 
				3005 "Ragi" 
				3006 "Small millets" 
			4000 "Pulses" 
			5000 "Gram" 
			6000 "Salt" 
			7000 "Sugar" 
			8000 "Oil" 
			9000 "Kerosene"
			0 "Non-PDS";
	#delimit cr
		lab val products products
		lab var products "Unique PDS-related products" 
	
	// Only difference vs. master_item_list is for small grains
	tab products if product_code!=products
	tab product_code if product_code!=products
	//drop product_code
		
	*2.6 - Correct mistake in source reported for 14 obs
		/*Assuming that if products are obtained through PDS (free or subsidized) 
		should be source=1 (purchased) as defined in Questionaire. 14 cases 
		of PDS-items that dont have source==1. Assume this is a mistake 
		in the raw data and over-write. */
		replace source=1 if pds==1
	
	/*2.7 - Identify HH's who purchase from different Prices	
		g price_pds= .
		bys hhid products: egen aux_price_products = mean(price) 
			replace price_pds= 1 if aux_price_products ==1
			replace price_pds= 2 if aux_price_products ==2
			replace price_pds= 3 if aux_price_products ==3
			replace price_pds= 4 if price_pds==. & pds!=0
		lab var price_pds "PDS price faced by HH"			
		lab define price_pds ///
			1 "Free Price" ///
			2 "PDS Subsidized Price" ///
			3 "Market purchased Price, PDS-related items" ///
			4 "PDS Multiple Prices (Free AND Subsidized)" ///
			0 "Unrelated to PDS" 
		lab val price_pds price_pds
		tab products price_pds, m */ 
			
	* 2.9 - Create additional auxiliary variables  
	g double uv_mkt2 =uv_mkt // Only auxiliary variable.
		clonevar month = survey_month //For shorter name.

	* 2.10 - Variable for regrouping grains  
	g item_gr = item 
		replace item_gr	=3100 if inlist(item, 63, 64, 65, 66, 67, 68) // FREE
		replace item_gr	=3200 if inlist(item, 55, 56, 57, 58, 59, 60) // SUBSIDIZED
	lab define item 3100 "3100 Coarse Grains - Free (63-68)" 3200 "3200 Coarse Grains - PDS Subs (55-60)" , add
	lab val item_gr item
	lab var item_gr "Item, grouping individual Coarse Grains"
					
save "${user}/data/processed/ces/all_pds_items_2022.dta", replace 

	*============================================================================*
	 di in red "STEP 3: Calculate median and sample size for market products"
	*============================================================================*
	* 3.1 - Keep only PDS substitutes purchased in mkt, as basis for imputation. 
	use "${user}/data/processed/ces/all_pds_items_2022.dta", clear 
		drop if pds==1 		// Drop items receieved from PDS (free/subsidized).
		keep if source==1 	// Keep only purchased at market price. 
		
	di in red "If it stops, there are market values at zero"
		assert uv_mkt!=0 
		count if uv_mkt==.
	tab item products // Several items are taken into account for each product
	
	* 3.2 - Calculate weighted medians and sample size for each scenario
	/* POTENTIAL ISSUE: For products containing >1 PDS substitute item (oils, pulses), 
	HHID could potentially consume >1 item. Hence, same HHID would be 
	considered twice (double weighted) for	finding median. */
	forval y=1/6 {
		di in red "* Estimate weighted median within aggr`y' = `aggr`y'' *"
		set type double
		preserve
			collapse (median) uv_mkt_med`y' = uv_mkt (count) uv_mkt_freq`y'=uv_mkt [aw=pwt], by(`aggr`y'')
			assert uv_mkt_freq`y'!=. if  uv_mkt_med`y'!=.
			tempfile uv`y'
			save `uv`y'' 
		restore
		}
		
	*============================================================================*
	 di in red "STEP 4: Merge medians into PDS consumed items"
	*============================================================================*
	* 4.1 - Merge imputed prices into whole dataset
	use "${user}/data/processed/ces/all_pds_items_2022.dta", clear 
	forval y=1/6 {
		merge m:1 `aggr`y'' using `uv`y'' 
		drop if _merge==2 
		drop _merge
	/*  Missing values are for products-state-sector-sss where there are valid  
	market purchases but no PDS free/subsidiced items. MERGE is OK! */
		}
		
	preserve
		drop if pds==1 		// Drop items receieved from PDS (free/subsidized).
		keep if source==1 	// Keep only purchased at market price. 
	save "${user}/data/processed/ces/temp/temp_all_pds_items_2022_mkt_med.dta", replace
	restore

	*============================================================================*
	di in red "STEP 5: Invalidate negative subsidies"
	*============================================================================*
	* 5.1 - Clean value total and quantities.
	keep if pds==1 // Keep only PDS (free/subsidized) items 
// PDS-free items (and subtotals on PDS-items) have value_total MISSING. Change to 0.
		replace value_total=0 if value_total==.
	
	* 5.2 - Recalculate Values for PDS consumption and PDS subsidy 
	di in red "If it stops, there are items with missing quantity"
		assert qty_total!=. 	// Note that all items and values are kept in their original reference period. 

	* 5.3. Identify cases of implicit negative subsidy ==> And invalidate imputed price!
	g uv_orig = value_total/qty_total
		replace uv_orig = . if value_total==0
		compare uv_orig uv_mkt
		
	forval y=1/6 {
	foreach var in  med {
		g neg_origsubs_`var'`y' = (uv_orig >  uv_mkt_`var'`y') & uv_orig!=.
		di in red "Count of (originally) negative subsidies under `var'`y' "
		count if neg_origsubs_`var'`y' ==1
		replace uv_mkt_`var'`y'	=. 	if neg_origsubs_`var'`y' ==1
		replace uv_mkt_freq`y'	=. 	if neg_origsubs_`var'`y' ==1
	}
	}

	* 5.4. Identify cases of invalid imputation (either negative subs or not found)
	forval y=1/6 {
	foreach var in  med {
	di in red "Count of invalid imputaions (either no mkt equivalent or negative subs) under `var'`y' "
		count if uv_mkt_`var'`y'==.
		g pds_imputed_valid_`var'`y'=(uv_mkt_`var'`y'!=.)
		di in red "If it stops, there are imputed prices at zero"
		assert 	uv_mkt_`var'`y'!=0
		tab pds_imputed_valid_`var'`y'
	}
	}

	*============================================================================*
	 di in red "STEP 6: Deal with issues of small (coarse) grains"
	*============================================================================*
	/* Important considerations for trating grains:
	(1) Most PDS HHs report grains individually, but there are 228 HHs 
	that report only PDS consumption in "Coarse Grains" (See above).
	(2) The MPCE process can only identify grains at product-level (3000), as
	the dissagregation into individual grains is not available for all states.
	Hence, we must aggregate into one product for "Coarse Grains".
	(3) Moreover, HH's can consume more than one item within the same PRODUCT of grains. 
	Those cases are problematic because the imputation would give diferent UV's 
	at the item level. We will find a weighted average UV for those cases.
	(4) However, we must be careful in calculating average UV. It is possible 
	for the same HH to receive valid imputation for 1 GRAINS
	item and invalid imputation for another GRAINS item. In this case, the
	average UV	should not be calculated (the missing would distort) */	

	* 6.1 - Motivation for working with the more dissagregated GRAINS imputations 
	tab products item_gr, m
	tab item_gr products if products==3000, m
	tab item_gr products if item_gr==3200 | item_gr==3100, m
	forval y=1/6 {
	foreach var in med {
	di in red "Working at the dissagreagted grain level provides >9x more valid grain UV imputations" 
		tab pds_imputed_valid_`var'`y' if products==3000, m
		// Strictest scenario: only 7.61% of aggregated grains have a valid imputation (products==3000) (out of obs:  2,865)
		tab pds_imputed_valid_`var'`y' if item_gr==3200 | item_gr==3100, m
		// Strictest scenario: 94.52% of dissagreagted grains have a valid imputation (item_gr==3200 | item_gr==3100) (out of obs: 2,645)
	}
	}
	/*g grains_dissagr = .
		replace grains_dissagr 	= 1 if item_gr==3200 | item_gr==3100 
		replace grains_dissagr 	= 0 if products==3000 
	lab define grains_dissagr 0 "Grain, only aggregate (3000)" 1 "Grains individually (3100,3200)"
		lab val grains_dissagr grains_dissagr
	tab grains_dissagr*/

	* 6.2 - Identify HH's that consume more than one individual grain
	duplicates tag hhid item_gr if item_gr==3200 | item_gr==3100, gen(multiple_gr_3100_3200)
		tab multiple_gr_3100_3200 	// Problem affects only 16 HH's in the entire DTA (32 obs)
		sort multiple_gr_3100_3200
		
	* 6.3 - Create total quantity by all_grains (independent of scenario)
	bys hhid item_gr: egen double qty_total_item_gr = total(qty_total), m // In practice, only adds quantity for those 16 households
		
	* 6.4 - Identify invalid imputation to grain items within the HH.
	forval y=1/6 {
	foreach var in med {
	di in red "Observations that are multiple within grains and have invalid imputation under `var'`y'"
	tab pds_imputed_valid_`var'`y'  multiple_gr_3100_3200, m
	
	* 6.5 - Calculate total quantity and market value, ADDING together ALL INDIVIDUAL GRAINS for each HH
	g double value_total_pds_`var'`y' = qty_total * uv_mkt_`var'`y'
	bys hhid item_gr: egen double value_total_pds_`var'`y'_item_gr = total(value_total_pds_`var'`y'), m // In practice, only adds quantity for those 16 households
		
	* 6.6 - Calculate adjusted UV = average (weighted by quantity) if HH consumes multiple individual grains
	g double uv_mkt_`var'`y'_adj = value_total_pds_`var'`y'_item_gr / qty_total_item_gr // Already going to missing if numerator missing.
		di in red "If it stops, problem with adjusted UV. Must be the SAME for all cases without multiple grains"
		assert abs(uv_mkt_`var'`y' - uv_mkt_`var'`y'_adj)<0.01 if multiple_gr_3100_3200==0 & uv_mkt_`var'`y'!=.
	
	* 6.7 - Taking weighted average of sample size (weighted by quantities)
	g double freq_total_`var'`y' = qty_total * uv_mkt_freq`y'
		bys hhid item_gr: egen double freq_total_`var'`y'_item_gr = total(freq_total_`var'`y'), m // In practice, only adds quantity for those 16 households
	g double uv_mkt_freq`y'_adj = freq_total_`var'`y'_item_gr / qty_total_item_gr // Already going to missing if numerator missing.
		
	di in red "Number of changes in frequency"
	count if uv_mkt_freq`y'_adj != uv_mkt_freq`y'
		
	* 6.8 - Test missings and make sure no invalid imputation is considered 
	g mi_uv_mkt_`var'`y' 		= (uv_mkt_`var'`y' ==.)
		bys hhid item_gr: egen hh_mi_uv_mkt_`var'`y' =max(mi_uv_mkt_`var'`y')
		tab hh_mi_uv_mkt_`var'`y' 
		tab hh_mi_uv_mkt_`var'`y' if multiple_gr_3100_3200==1
	
	codebook hhid if hh_mi_uv_mkt_`var'`y'==1 
	codebook hhid if hh_mi_uv_mkt_`var'`y'==1 & multiple_gr_3100_3200==1
	// For example, 8 of the multiple_garins households had at least one missing in scenaario med1
	replace uv_mkt_`var'`y'_adj = . if hh_mi_uv_mkt_`var'`y'==1
	replace uv_mkt_freq`y'_adj = . if hh_mi_uv_mkt_`var'`y'==1
	}
	}

	* 6.9 - Collapse individual grains to item_gr
	tab item_gr products
	// Trick for keeping labels after collapse
	foreach v of var * { 
		loc l`v' : variable label `v' 
		if `"`l`v''"' == "" { 
			loc l`v' "`v'" 
		} 
		} 
	loc keepother state sector /*panel*/ sss hhwt hhsize pwt `time' pds //grains_dissagr
		
	tab item_gr 
	tab item 
	tab item_gr products
	// Adjusted UV, quant, values, and frequencies are already at the level of item_gr. Use mean not sum. 
	collapse /*(mean)*/ (max) uv_mkt_*adj /*qty_total value* (max) price_pds*/ source  multiple_gr_3100_3200  `keepother', by(hhid item_gr )
	// Will only provide one imputation per grains at the household level.
	foreach v of var * { 
    lab var `v' "`l`v''" 
	} 
	decode item_gr, gen(item_description) 
	g note = "Post adjustment. If multiple grains, UV weighted avg by quant. Neg subs force imputation to MISS. DTA includes aggregate & indivdiual grains."
	
// Prove that this is an improvement
	forval y=1/6 {
	foreach var in med {
	ren uv_mkt_`var'`y'_adj  uv_mkt_`var'`y'
	ren uv_mkt_freq`y'_adj  uv_mkt_freq`y'
	g pds_imputed_valid_`var'`y' = (uv_mkt_`var'`y'!=.)
	di in red "Invalid imputation from `var'`y' by item"
	tab item_gr pds_imputed_valid_`var'`y', m
	}
	}
	// At most, 8 imputations are lost when going from individual to aggreagate grains.

	*==========================================================================*
	 di in red "STEP 7: Generate Most-Local scenario (7)"
	*==========================================================================*
	* 7.1 - Use most local (lowest number) scenario,  st. sample size >50
	g double uv_mkt_med = .
	g double uv_mkt_freq = .
	g loc_lev = .
	g loc_lev_var = ""
	g pds_imputed_valid = 0
		
forval y=1/6 {
	replace loc_lev 		= `y' 				if (uv_mkt_freq`y'>50 & uv_mkt_freq`y'<.) & uv_mkt_med==.
	replace loc_lev_var 	= "`aggr`y''" 		if (uv_mkt_freq`y'>50 & uv_mkt_freq`y'<.) & uv_mkt_med==.
	replace uv_mkt_med 		= uv_mkt_med`y' 	if (uv_mkt_freq`y'>50 & uv_mkt_freq`y'<.) & uv_mkt_med==.
	replace uv_mkt_freq 	= uv_mkt_freq`y'	if (uv_mkt_freq`y'>50 & uv_mkt_freq`y'<.) & uv_mkt_freq!=. // Modified feb 2025
	replace pds_imputed_valid 	= 1 			if uv_mkt_med!=. 
	la var uv_mkt_med`y'  	"Median mkt price, @ `aggr`y''"
	la var uv_mkt_freq`y'  	"Sample size of mkt price, @ `aggr`y''"
	}
	la var uv_mkt_med 	"Median mkt price, most local, >50 obs"
	la var loc_lev 		"Local level used, >50 obs"
	lab define loc_lev 1 "`aggr1'" 2 "`aggr2'" 3 "`aggr3'" 4 "`aggr4'" 5 "`aggr5'" 6 "`aggr6'" 99 "Invalid imputation" 
	replace loc_lev =99 if !inlist(loc_lev, 1, 2, 3, 4, 5, 6)
	lab val loc_lev loc_lev
	
	assert uv_mkt_freq==. if uv_mkt_med==. // Make sure frequencies are well captured

	di in red "Items with invalid imputation"
	// Invalid come from not enough observations
	tab pds_imputed_valid // 489 invalid  imputations. 
	tab item_gr pds_imputed_valid 
	tab loc_lev

	* ==========================================================================*
	 di in red "STEP 8: Keep only imputation for all-aggregate grains"
	*============================================================================*
	* 8.1 - Identify duplication of grains information within the same household and item_gr
	/* Note: Households consuming grains may have duplicated imputation, at the aggregated and dissagreagegated level */
	
	g grains_free_dissagr 				= 1 if (item_gr==3100)
		replace grains_free_dissagr 	= 0 if (item_gr==70) & 	pds_imputed_valid  ==1 // CONSIDER RESTICTING TO VALID 
	g grains_free_agr 					= 1 if (item_gr==70) 
		replace grains_free_agr 		= 0 if (item_gr==3100) & pds_imputed_valid  ==1	// CONSIDER RESTICTING TO VALID 
	
	g grains_sub_dissagr 				= 1 if (item_gr==3200)
		replace grains_sub_dissagr 		= 0 if (item_gr==1) & 	pds_imputed_valid  ==1	// CONSIDER RESTICTING TO VALID 
	g grains_sub_agr 					= 1 if (item_gr==1) 
		replace grains_sub_agr 			= 0 if (item_gr==3200) & 	pds_imputed_valid  ==1 	// CONSIDER RESTICTING TO VALID
		
	by hhid: egen hh_grains_free_dissagr = max(grains_free_dissagr)
	by hhid: egen hh_grains_free_agr 	= max(grains_free_agr)	
	by hhid: egen hh_grains_sub_dissagr = max(grains_sub_dissagr)
	by hhid: egen hh_grains_sub_agr 	= max(grains_sub_agr)	
	
	preserve
	duplicates drop hhid, force
		di in red "Overlaping FREE GRAINS by household"
	tab hh_grains_free_dissagr hh_grains_free_agr, m
		di in red "Overlaping SUBSIDIZED GRAINS by household"
	tab hh_grains_sub_dissagr hh_grains_sub_agr, m
	restore
	
	* 8.2 - Drop less prefered imputation
		/* We prioritize dissagregation by item (individual grain) and keep those 
		cases only for each household buying grains*/
	di in red "Drop suboptimal imputaion for free grains, whenever there is a better imputation"
		drop if item_gr == 70 & hh_grains_free_dissagr ==1
	di in red "Drop suboptimal imputaion for subsidized grains, whenever there is a better imputation"
		drop if item_gr == 1 & hh_grains_sub_dissagr ==1
	isid hhid item_gr 
	tab item_gr
	
	* 8.3 - Recode item variable to match master_consumption_2022 only at the aggregate grains
	clonevar item = item_gr
		replace item = 70 	if item==3100 // Free Coarse Grains
		replace item = 1 	if item==3200 // PDS Subsidized Coarse Grains

	* 8.4 - Check for invalid imputations (final version)
	di in red "Items with invalid imputation after grains selection"
	tab pds_imputed_valid // After selection, 385 invalid imputations, mostly from sugar and wheat.  
	tab item_gr pds_imputed_valid 
	codebook hhid if pds_imputed_valid!=1	
	
	*============================================================================*
	di in red "STEP 9: Clean and save vector"
	*============================================================================*
	* 9.1 Define variables for sharing based on preferred scenario 	
	g uv_imputed_pds = uv_mkt_med
		replace uv_imputed_pds = . if pds_imputed_valid==0 // Note we lose many observations. 
	g pds_imputed_lev = loc_lev

	codebook hhid
	// Losing 385 invalid imputations (or 384 households)  
	keep if pds==1 & pds_imputed_valid==1
	codebook hhid
	
	keep hhid item item_description  uv_imputed_pds pds pds_imputed_lev pds_imputed_valid source //products
	g stamp ="$S_DATE $S_TIME"
	g scenario = "7 - Most local >50 obs"
	g note = "after adjusting grains and omitting imputations if SUBS<0"
	save "${user}/data/processed/ces/pds_imputed_uv_vector_2022.dta", replace
	
	*===========================================================================
	di in red "THE END of 02d_PDS_imputation_2022"
	*===========================================================================
	cap log close
	exit