
	loc date: display %tdCCYY-NN-DD =daily("`c(current_date)'", "DMY")
	cap log close
	log using "${user}/output/log/03_consumption_adjustments_${s}_`date'", replace

	/* =============================================================================
	Project			: India poverty estimates - 2011-12 & 2022-23 
	Dofile			: 03_consumption_adjustments.do
	Last modified	: 25th March 2025

	Inputs			: "${user}/data/processed/ces/master_consumption_2011.dta"
					  "${user}/data/processed/ces/master_consumption_2022.dta"				  
					  "${user}/data/processed/ces/pds_imputed_uv_vector_2011.dta"
					  "${user}/data/processed/ces/pds_imputed_uv_vector_2022.dta"
					  
	Outputs			: "${user}/data/processed/ces/master_consumption_2011_pds.dta"
					  "${user}/data/processed/ces/master_consumption_2011_rent.dta"
					  "${user}/data/processed/ces/master_consumption_2011_lumpexp.dta"
					  "${user}/data/processed/ces/master_consumption_2011_hosp.dta"
					  "${user}/data/processed/ces/master_consumption_2011_all.dta"
					  "${user}/data/processed/ces/master_consumption_2022_pds.dta"
					  "${user}/data/processed/ces/master_consumption_2022_rent.dta"
					  "${user}/data/processed/ces/master_consumption_2022_lumpexp.dta"
					  "${user}/data/processed/ces/master_consumption_2022_hosp.dta"
					  "${user}/data/processed/ces/master_consumption_2022_all.dta"
					
	Steps			: * 1. ADJUSTMENTS TO MASTER DATASET - 2011
					  * 2. ADJUSTMENTS TO MASTER DATASET - 2022									
	============================================================================= */

	*===========================================================================
	* 1. ADJUSTMENTS TO MASTER DATASET - 2011
	*===========================================================================
	use "${user}/data/processed/ces/master_consumption_2011.dta", clear

	********************************
	* MERGE PDS IMPUTATION OF PRICES  
	********************************
	if "${s}" == "_pds" {
	di in red "Merge in PDS imputation"
		merge m:1 hhid item using "${user}/data/processed/ces/pds_imputed_uv_vector_2011.dta" //, keepusing(pds uv_imputed_pds pds_imputed_lev pds_imputed_valid)
			di in red "If stops, imputed price could not be matched"
		assert _merge!=2 
		drop if _merge==2
		drop _merge
	g double uv_raw = value_total / qty_total/1000  
		tabstat uv_imputed_pds uv_raw if pds_imputed_valid==1, by(item)
		tabstat uv_imputed_pds uv_raw if pds==1, by(item)
	clonevar value_total${s} = value_total
		replace value_total${s} = uv_imputed${s} *  qty_total/1000 if pds_imputed_valid==1
	
	* Include shoes and uniforms. // No school uniforms or shoes for free in 2011
	
	*Tidy up
	replace qty_new = . if qty_new==0
	replace qty_total = . if qty_total==0
	loc keepextra pds pds_imputed_valid 
	keep year hhid item survey_month value_total${s} qty_total qty_new source `keepextra' 
	order year hhid item survey_month value_total${s} qty_total qty_new source `keepextra' 
	save "${user}/data/processed/ces/master_consumption_2011${s}.dta", replace
		}
		
	********************************
	* ACTUAL RENT 
	********************************
	if "${s}" == "_rent" {
	di in red "Scenario ${s}: Marginally Adjusting for actual rent"

	clonevar value_total${s} = value_total
	gen actual_rent = 0
	
	* Actual rent 
	replace value_total${s} = . if  item == 520	
	replace actual_rent = 1 	if item == 520		
		
	lab var actual_rent "Flag for actual housing rent"	
	loc keepextra actual_rent
	
	keep hhid /* state sector district stratum pwt */ item survey_month value_total${s} qty_total qty_new source /*value_deflated${s}*/  year `keepextra' 
	order hhid /* state sector district stratum */ survey_month year item qty_total qty_new value_total${s} source /*value_deflated${s}*/  `keepextra'  
	save "${user}/data/processed/ces/master_consumption_2011${s}.dta", replace
	}
			
	************************
	*Durables & NON-FOOD ADJUSTMENT
	************************
	if "${s}" == "_lumpexp" {
	di in red "Scenario ${s}: Marginally Adjusting institutional durables & Non-Food"
	
 		clonevar value_total${s} = value_total
		gen lumpexp = 0
		
	* Jewelry 643
		foreach i of numlist 640/642 649 {
			replace value_total${s} = . if  item == `i'	
			replace lumpexp = 1 		if item == `i'	
		}	
	* goods for recreational use - tv, radio, etc.
		foreach i of numlist 560/563 565/569 {
			replace value_total${s} = . if  item == `i'	
			replace lumpexp = 1 		if item == `i'	
		}	
	* furniture
		foreach i of numlist 550/559 {
			replace value_total${s} = . if  item == `i'	
			replace lumpexp = 1 		if item == `i'	
		}	

	* transport equipment
		foreach i of numlist 600/609 {
			replace value_total${s} = . if  item == `i'	
			replace lumpexp = 1 		if item == `i'	
		}	
		
	* mobile phone/laptop/phone  
		foreach i of numlist 621/624 626/629 {
			replace value_total${s} = . if  item == `i'	
			replace lumpexp = 1 		if item == `i'	
		}	
	* lumpy watches - may appreciate
			foreach i of numlist 620 {
			replace value_total${s} = . if  item == `i'	
			replace lumpexp = 1 		if item == `i'	
		}		
	* cooking and household appliances - pressure cooker , water purifier, fan, AC, washing machine, sewing machine, etc.
		foreach i of numlist 580/588 590/592 599 {
			replace value_total${s} = . if  item == `i'	
			replace lumpexp = 1 		if item == `i'	
		}	
	
	* Other taxes and cesses
		replace value_total${s} = . if item==541
		replace lumpexp = 1 		if item == 541	
		
	lab var lumpexp "Flag for lumpy expenditures"	
	loc keepextra lumpexp
	keep hhid /* state sector district pwt */ item survey_month value_total${s} qty_total qty_new source /*value_deflated${s}*/ year `keepextra' 
	order hhid /* state sector district */ survey_month year item qty_total qty_new value_total${s} source /*value_deflated${s}*/  `keepextra' 
	save "${user}/data/processed/ces/master_consumption_2011${s}.dta", replace
		}
		
	************************
	* HEALTH ADJUSTMENT 
	************************
	if "${s}" == "_hosp" {
	di in red "Scenario ${s}: Marginally Adjusting Institutional Health Expenses"
	gen hospital = 0
	clonevar value_total${s} = value_total
	foreach i of numlist 410/419 {
		replace value_total${s} = . if  item == `i'	
		replace hospital = 1 	if  item == `i'	
	}
	
	lab var hospital "Flag for institutional health expenditure"
	loc keepextra hospital
	keep hhid /* state sector district pwt */ item survey_month value_total${s} qty_total qty_new source /*value_deflated${s}*/  year `keepextra' 
	order hhid /* state sector district */ survey_month year item qty_total qty_new value_total${s} source /*value_deflated${s}*/  `keepextra' 
	save "${user}/data/processed/ces/master_consumption_2011${s}.dta", replace
	}
	
	********************************
	* IF ALL AJUSTMENTS 
	********************************
	if "${s}" == "_all" {
	di in red "Scenario ${s}: All Adjustments Simultaneously"
	
	use "${user}/data/processed/ces/master_consumption_2011_pds", clear
	clonevar value_total${s} = value_total_pds
	
	merge 1:1 hhid item using "${user}/data/processed/ces/master_consumption_2011_lumpexp.dta", keepusing(lumpexp)
	keep if inlist(_merge, 1, 3)
	drop _merge
	merge 1:1 hhid item using "${user}/data/processed/ces/master_consumption_2011_hosp.dta", keepusing(hospital)
	keep if inlist(_merge, 1, 3)
	drop _merge
	merge 1:1 hhid item using "${user}/data/processed/ces/master_consumption_2011_rent.dta", keepusing(actual_rent)
	keep if inlist(_merge, 1, 3)
	drop _merge
			
	replace value_total${s} = . if lumpexp==1
	replace value_total${s} = . if hospital==1
	replace value_total${s} = . if actual_rent==1
	
	loc keepextra pds_imputed_valid lumpexp hospital value_total_pds
	keep hhid /* state sector district pwt */ item survey_month value_total${s} qty_total qty_new source /*value_deflated${s}*/  year `keepextra' 
	order hhid /* state sector district */ survey_month year item qty_total qty_new value_total${s} source /*value_deflated${s}*/  `keepextra' 
	save "${user}/data/processed/ces/master_consumption_2011${s}.dta", replace
	}	
		
	
	*===========================================================================
	* 2b. ADJUSTMENTS TO MASTER DATASET - 2022
	*===========================================================================
	use "${user}/data/processed/ces/master_consumption_2022.dta", clear
			
	********************************
	* MERGE PDS IMPUTATION OF PRICES  
	********************************
if "${s}" == "_pds" {
     di in red "Scenario ${s}: Marginally Adjusting by Imputing Market Equivalent Prices for PDS and free school uniform and shoes"
	* PDS items
    merge m:1 hhid item using "${user}/data/processed/ces/pds_imputed_uv_vector_2022.dta"
	
        assert _merge!=2
        drop _merge
		g double uv_raw = value_total / qty_total  
        clonevar value_total${s}   = value_total
        replace value_total${s}    = uv_imputed${s} * qty_total if pds_imputed_valid==1
		clonevar qty_new${s} = qty_new
		
	 
	* Shoes and uniforms received from free
		merge m:1 hhid item using "${user}/data/processed/ces/nonfood_school_imputed_2022.dta"
        
		drop if _m==2 //dropping HHs that have uniforms but not food
		assert _merge!=2
        drop _merge
		replace uv_raw 			= value_total / qty_total  if nf_imputed_valid ==1
		di in red "If it stops, market value paid for free items is not zero"
		assert value_total 		== 0  if nf_imputed_valid==1
		replace value_total${s}    = value_imputed_nf if nf_imputed_valid ==1
	
	loc keepextra pds pds_imputed_valid nf_imputed_valid 
	keep hhid  item survey_month source value_total${s} qty_total qty_new  year `keepextra' 
	order hhid survey_month year item qty_total qty_new value_total${s}  `keepextra' 
	save "${user}/data/processed/ces/master_consumption_2022${s}.dta", replace 
	 }	
		
	********************************
	* Actual Rent
	********************************
	if "${s}" == "_rent" {
	di in red "Scenario ${s}: Marginally Adjusting for actual rent"

	clonevar value_total${s} = value_total
	gen actual_rent = 0
	
	* Actual rent 
	replace value_total${s} = . if  item == 520	
	replace actual_rent = 1 	if item == 520	
		
	lab var actual_rent "Flag for actual housing rent"	
	loc keepextra actual_rent
	
	keep hhid /* state sector district stratum pwt */ item survey_month value_total${s} qty_total qty_new source /*value_deflated${s}*/  year `keepextra' 
	order hhid /* state sector district stratum */ survey_month year item qty_total qty_new value_total${s} source /*value_deflated${s}*/  `keepextra'  
	save "${user}/data/processed/ces/master_consumption_2022${s}.dta", replace
		}
	
	************************
	*Durables & NON-FOOD ADJUSTMENT
	************************
	if "${s}" == "_lumpexp" {
	di in red "Scenario ${s}: Marginally Adjusting Durables & No-Food"
		clonevar value_total${s} = value_total
		gen lumpexp = 0
	* lumpy + appreciate in value : Jewelry - 643
		foreach i of numlist 640/642 649 {
			replace value_total${s} = . if  item == `i'	
			replace lumpexp = 1 		if item == `i'	
		}	
	* goods for recreational use - tv, radio, etc. 562 not dropped as expenditure is more frequent 
		foreach i of numlist 560 561 563 564 569 {
			replace value_total${s} = . if  item == `i'	
			replace lumpexp = 1 		if item == `i'	
		}	
	* furniture
		foreach i of numlist 550/559 {
			replace value_total${s} = . if  item == `i'	
			replace lumpexp = 1 		if item == `i'	
		}		
	* transport equipment 
		foreach i of numlist 600/609 {
			replace value_total${s} = . if  item == `i'	
			replace lumpexp = 1 		if item == `i'	
		}	
	* lumpy : sports goods 37 432 97	
		foreach i of numlist 36 99 {
			replace value_total${s} = . if  item == `i'	
			replace lumpexp = 1 		if item == `i'	
		}	
	* mobile phone/laptop/phone //625???
	* 625 - DO NOT DROP!! Expenditure is more frequent 
		foreach i of numlist 621/624 626/629 {
			replace value_total${s} = . if  item == `i'	
			replace lumpexp = 1 		if item == `i'	
		}
	* lumpy watches - may appreciate
		foreach i of numlist 620 {
			replace value_total${s} = . if  item == `i'	
			replace lumpexp = 1 		if item == `i'	
		}
	* cooking and household appliances - pressure cooker , water purifier, fan, AC, washing machine, sewing machine, etc.
		foreach i of numlist 43/48 580/582 584/588 590/592 599 {
			replace value_total${s} = . if  item == `i'	
			replace lumpexp = 1 		if item == `i'	
		}	
		
	* Other taxes and cesses
		replace value_total${s} = . if  item ==899
		replace lumpexp = 1 		if 	item ==899
		
	lab var lumpexp "Flag for lumpy expenditures"
	loc keepextra lumpexp
	keep hhid /* state sector district stratum pwt */ item survey_month value_total${s} qty_total qty_new source /*value_deflated${s}*/  year `keepextra' 
	order hhid /* state sector district stratum */ survey_month year item qty_total qty_new value_total${s} source /*value_deflated${s}*/  `keepextra' 
	save "${user}/data/processed/ces//master_consumption_2022${s}.dta", replace
		}
		
	************************
	* HEALTH ADJUSTMENT
	************************
	if "${s}" == "_hosp" {
	di in red "Scenario ${s}: Marginally Adjusting Health Expenses"
		clonevar value_total${s} = value_total
		gen hospital = 0
		
		foreach i of numlist 410/419 {
			replace value_total${s} = . if  item == `i'	
			replace hospital = 1 		if  item == `i'
		}
		
	lab var hospital "Flag for institutional health expenditure"
	
	loc keepextra hospital
	keep hhid /* state sector district stratum pwt */ item survey_month value_total${s} qty_total qty_new source /*value_deflated${s}*/  year `keepextra'  
	order hhid /* state sector district stratum */ survey_month year item qty_total qty_new value_total${s} source /*value_deflated${s}*/  `keepextra'  
	save "${user}/data/processed/ces/master_consumption_2022${s}.dta", replace
		}	
		
	********************************
	* IF ALL AJUSTMENTS
	********************************
	if "${s}" == "_all" {
	di in red "Scenario ${s}: All Adjustments Simultaneously"
	
	 use "${user}/data/processed/ces/master_consumption_2022_pds.dta", clear
		clonevar value_total${s} = value_total_pds
	
	merge 1:1 hhid item using "${user}/data/processed/ces/master_consumption_2022_lumpexp", keepusing(lumpexp) 
	keep if inlist(_merge, 1, 3)
	drop _merge
	merge 1:1 hhid item using "${user}/data/processed/ces/master_consumption_2022_hosp", keepusing(hospital)  
	keep if inlist(_merge, 1, 3)
	drop _merge
	merge 1:1 hhid item using "${user}/data/processed/ces/master_consumption_2022_rent", keepusing(actual_rent) 
	keep if inlist(_merge, 1, 3)
	drop _merge
	
	* Imputed vector
	replace value_total${s} = . if lumpexp==1 
	replace value_total${s} = . if hospital==1
	replace value_total${s} = . if actual_rent==1
		
	loc keepextra pds_imputed_valid nf_imputed_valid lumpexp hospital value_total_pds
	keep hhid /* state sector district stratum pwt */ item survey_month value_total${s} qty_total qty_new source /*value_deflated${s}*/ year `keepextra'  
	order hhid /*state sector district stratum */ survey_month year item qty_total qty_new value_total${s} source /*value_deflated${s}*/  `keepextra'  
	save "${user}/data/processed/ces/master_consumption_2022${s}.dta", replace
	}	
		
	* ==========================================================================*
	di in red "THE END OF 03_consumption_adjustments${s}" 
	* ==========================================================================*
	cap log close
	exit