
	loc date: display %tdCCYY-NN-DD =daily("`c(current_date)'", "DMY")
	cap log close
	log using "${user}/output/log/04_deflators_wy${s}_`date'", replace

	/* =============================================================================
		Project				: India poverty estimates - 2011-12 & 2022-23 
		Dofile				: 04_deflators_wy
		Last modified		: 26th March 2025

		Inputs				: "${user}/data/processed/ces/master_item_list_2011.dta"	
							  "${user}/data/processed/ces/master_item_list_2022.dta"
							  "${user}/data/processed/other/cpi_master_monthly"
							  "${user}/data/processed/ces/master_consumption_2011${s}.dta"	
							  "${user}/data/processed/ces/master_consumption_2022${s}.dta"	
						
		Outputs				: "${user}/data/processed/ces/master_consumption_wy_2011${s}.dta"	
							  "${user}/data/processed/ces/master_consumption_wy_2022${s}.dta"		
						
		Steps				: * 1. TEMPORAL DEFLATION - 2011
							  * 2. TEMPORAL DEFLATION - 2022
	============================================================================= */

	*===========================================================================
		* 1. INTRA-TEMPORAL DEFLATION - 2011
	*===========================================================================

	use "${user}/data/processed/ces/master_consumption_2011${s}.dta", clear
	merge m:1 hhid using "${user}/data/processed/ces/master_hh_2011.dta", keepusing(state sector)
	drop _m
	merge m:1 item using "${user}/data/processed/ces/master_item_list_2011.dta", keepusing(scode) keep(3)
	drop _m
	merge m:1 state sector survey_month scode year using "${user}/data/processed/other/cpi_master_monthly.dta", keepusing(cpi cpi_avg) keep(3)
	drop _m
		
		g double value_deflated${s} = value_total${s} / (cpi/cpi_avg)
		
			lab var value_deflated${s} 	"Temporally deflated consumption value"
			lab var value_total${s} 	"Nominal consumption value"
			lab var survey_month 		"Month of the survey"
			lab var year 				"Year of the survey"
	loc keepextra
	if "${s}" == "_pds" {
		loc keepextra `keepextra' pds_imputed_valid 
	}
	
	keep year hhid item survey_month source value_total${s} qty_total qty_new value_deflated${s} `keepextra'
	order year hhid item survey_month source year qty_total value_total${s} qty_new value_deflated${s} 
	save "${user}/data/processed/ces/master_consumption_wy_2011${s}.dta", replace
		
	*===========================================================================
		* 2. INTRA-TEMPORAL DEFLATION - 2022
	*===========================================================================
	use "${user}/data/processed/ces/master_consumption_2022${s}.dta", replace
	merge m:1 hhid using "${user}/data/processed/ces/master_hh_2022.dta", keepusing(state sector)
	drop _m
	merge m:1 item using "${user}/data/processed/ces/master_item_list_2022.dta", keepusing(scode) keep(3)
	drop _m
	merge m:1 state sector  survey_month scode year using "${user}/data/processed/other/cpi_master_monthly.dta", keepusing(cpi cpi_avg) keep(3)
	drop _m
	
	g value_deflated${s} = value_total${s} / (cpi/cpi_avg) 
			
			la var value_deflated${s} 	"Temporally deflated consumption value ${s}"
			la var value_total${s} 		"Nominal consumption value ${s}"
			la var survey_month 		"Month of survey"
			la var year 				"Year of survey"
	
	loc keepextra
	if "${s}" == "_pds" {
		loc keepextra `keepextra' pds_imputed_valid nf_imputed_valid
	}
	
	
	keep year hhid item source survey_month value_total${s} qty_total qty_new value_deflated${s} `keepextra'
	order year hhid item source survey_month value_total${s} qty_total qty_new value_deflated${s} 
	save "${user}/data/processed/ces/master_consumption_wy_2022${s}.dta", replace

	* ==========================================================================*
		di in red "THE END OF 04_deflators_wy${s}" 
	* ==========================================================================*
	cap log close
	exit