
	loc date: display %tdCCYY-NN-DD =daily("`c(current_date)'", "DMY")
	cap log close
	log using "${user}/output/log/05_deflators_spatial_`date'", replace

	/* =============================================================================
		Project			: India poverty estimates - 2011-12 & 2022-23  
		Dofile			: 05_deflators_spatial.do
		Last modified	: 26th March 2025

		Inputs			: "${user}/data/processed/ces/master_consumption_wy_2011.dta" 
						  "${user}/data/processed/ces/master_consumption_wy_2022.dta"
						  "${user}/data/processed/ces/master_item_list_2011.dta"
						  "${user}/data/processed/ces/master_item_list_2022.dta"
						  "${user}/data/processed/ces/master_hh_2011.dta"
						  "${user}/data/processed/ces/master_hh_2022.dta"
						  "${user}/data/processed/other/population_MoH.dta"

		Intermediate	: "${user}/data/processed/ces/2011_item_level_mmrp.dta"
						  "${user}/data/processed/ces/2022_item_level_mmrp.dta"
						  "${user}/data/processed/ces/temp/2011_items_long_clean_p`x'.dta"
						  "${user}/data/processed/ces/temp/2022_items_long_clean_p`x'.dta"
						  "${user}/data/processed/ces/temp/2011_non_zero_obs_p`x'.dta"
						  "${user}/data/processed/ces/temp/2022_non_zero_obs_p`x'.dta"
						  "${user}/data/processed/ces/temp/2011_med_price_avg_qty_p`x'"
						  "${user}/data/processed/ces/temp/2022_med_price_avg_qty_p`x'"
						  "${user}/data/processed/ces/2011_med_price_avg_qty.dta"
						  "${user}/data/processed/ces/2022_med_price_avg_qty.dta"
						  "${user}/data/processed/ces/2011_bundles_indices.dta"
						  "${user}/data/processed/ces/2022_bundles_indices.dta"
			
		Outputs			: "${user}/data/processed/ces/2011_spatial_deflators.dta"
						  "${user}/data/processed/ces/2022_spatial_deflators.dta"
						  "${user}/data/processed/ces/2011_non_zero_obs.dta"
						  "${user}/data/processed/ces/2022_non_zero_obs.dta"	
						
		Steps			: * 1. Data prep
						  * 2. Convert into long and split in parts
						  * 3. Retrieve Median price and Quanitities
						  * 4. Combine Price and Quantity
						  * 5. Calculation of Fisher Indices 
						  * 6. Combine non-zero observations
						
	============================================================================= */
	glo svy_yr 2011 2022

	*===============================================================================
	* 1. Data prep - 2011-12
	*===============================================================================

	use "${user}/data/processed/ces/master_consumption_wy_2011.dta", clear
	merge m:1 hhid using "${user}/data/processed/ces/master_hh_2011.dta", keepusing(state sector)
	drop _m
	merge m:1 item using "${user}/data/processed/ces/master_item_list_2011.dta", keepusing(commodity_group product_code subtotal no_qty)  // Merge with names and units file (created by WB INDPOV)
	drop _m

	* keep items with quantity
		keep if  inrange(commodity_group, 1, 15)
		* Drop subtotals
			drop if subtotal==1  
			drop if no_qty==1  
	
	collapse (sum) qty_total qty_new value_total value_deflated, by(year hhid product_code commodity_group state sector)
	
	g data_grp =  .
		replace data_grp = 1  if inrange(commodity_group, 1, 5)
		replace data_grp = 2  if inlist(commodity_group, 6) 
		replace data_grp = 3  if inlist(commodity_group, 7,8, 9)
		replace data_grp = 4  if inlist(commodity_group, 10)
		replace data_grp = 5  if inlist(commodity_group, 11, 12, 13)
		replace data_grp = 6  if inlist(commodity_group, 14, 15)
		
	keep year hhid product_code qty_new qty_total value_total value_deflated data_grp 
	
	save "${user}/data/processed/ces/2011_item_level_mmrp.dta", replace

	*===============================================================================
	* 2. Data prep - 2022-23
	*===============================================================================

	use "${user}/data/processed/ces/master_consumption_wy_2022.dta", clear
	merge m:1 hhid using "${user}/data/processed/ces/master_hh_2022.dta", keepusing(state sector)
	drop _m
	merge m:1 item using "${user}/data/processed/ces/master_item_list_2022.dta", keepusing(commodity_group product_code subtotal sub_grains no_qty free* agg_item) keep(3)  // Merge with names and units file (created by WB INDPOV)
	drop _m

	keep if  inrange(commodity_group, 1, 15)
	* Drop subtotals
	drop if subtotal == 1 | sub_grains ==1
	drop if agg_item==1	
	*Drop those items without quantities
	drop if no_qty==1  
		
	/* NOTE - Drop free school uniforms
	Free school uniforms need to be dropped manually because it has units info. 
	unlike uniforms purchased at market price. We DO NOT include free uniforms 
	in the spatial deflator calculation.
	*/
	drop if item==900 //Free school uniform
		
	*For free items without PDS imputation: create "notional value" of 1 Rs

	replace value_deflated = 1 if free==1 	| free_nf ==1 
	
	collapse (sum) qty_total qty_new value_total value_deflated, by(year hhid product_code commodity_group state sector) 
	
	*Create data groups
	g data_grp =  .
		replace data_grp = 1  if inrange(commodity_group, 1, 5)
		replace data_grp = 2  if inlist(commodity_group, 6) 
		replace data_grp = 3  if inlist(commodity_group, 7,8, 9)
		replace data_grp = 4  if inlist(commodity_group, 10)
		replace data_grp = 5  if inlist(commodity_group, 11, 12, 13)
		replace data_grp = 6  if inlist(commodity_group, 14, 15)
	keep year state sector hhid product_code qty_new qty_total value_total value_deflated data_grp 
	
	save "${user}/data/processed/ces/2022_item_level_mmrp.dta", replace

	/*=======================================================================*/
	* 3. Convert into long and split in parts
	/*=======================================================================*/	
	foreach y of glo svy_yr {
		use "${user}/data/processed/ces/master_item_list_`y'.dta", clear
		keep product_code commodity_group 
		collapse commodity_group , by(product_code)
	tempfile product_info
	save `product_info'
	
	use "${user}/data/processed/ces/`y'_item_level_mmrp.dta", clear
	su data_grp
			local n_max = r(max)
			di "number of parts: `n_max'"
	
	forval x=1/`n_max' {
	preserve
			keep if data_grp== `x'
		* reshape to have all items for all HHIDs	
			fastreshape wide qty_new qty_total value_deflated, i(hhid) j(product_code)
				
		* merge to have all HHs in sample
			merge 1:1 hhid using "${user}/data/processed/ces/master_hh_`y'.dta", nogen keepusing(year state sector hhid pwt hhsize)
			
		* convert back to long - Each hh should have 185 items 
		fastreshape long qty_new qty_total value_deflated, i(hhid) j(product_code)
		
		merge m:1 product_code using `product_info', keepusing(commodity_group) nogen keep(3)
		
		keep year hhid product_code state sector qty_new qty_total value_deflated pwt hhsize commodity_group
		
	save "${user}/data/processed/ces/temp/`y'_items_long_clean_p`x'.dta", replace
	restore	
	}
	} 

	/*=======================================================================*/
	*  3. Retrieve Median Price and Quanitities
	/*=======================================================================*/
	foreach y of glo svy_yr {
	di in red "Start retrieving Median Price and Quanitities for `y' "

	foreach x of numlist 1(1)6 {
		use "${user}/data/processed/ces/temp/`y'_items_long_clean_p`x'.dta", clear
		di in red "No. of households in `y' - part `x'"
		unique hhid
	
	*Quantities and values for median price calculation	
		replace qty_new = . if qty_new == 0
		replace value_deflated = . if value_deflated == 0 //0 changes made
		g miss_qty = mi(qty_new)
		g miss_value = mi(value_deflated)

	*Quantities and values for average quantity calculation	
		g qty_new_recode = qty_new
		replace qty_new_recode = 0 if qty_new==.

	*Average quantity per capita includes ALL HHs 
		g qty_pc = qty_new/hhsize //average quantity consumed per hhid
		g qty_pc_recode   = qty_new_recode/hhsize
		g double price = value_deflated/qty_new 
	
	preserve
		drop if mi(qty_new) | mi(value_deflated) 
		g non_zero_obs = 1
		collapse (sum) non_zero_obs, by(state sector product_code commodity_group ) 
		order state sector product_code non_zero_obs, first
		save "${user}/data/processed/ces/temp/`y'_non_zero_obs_p`x'.dta", replace
	restore
		
	merge m:1 state sector product_code using "${user}/data/processed/ces/temp/`y'_non_zero_obs_p`x'.dta" 

	preserve
		collapse qty_avg = qty_pc  qty_avg_recode = qty_pc_recode (p50) price_st_sec = price [aw=pwt], by(state sector product_code)
		tempfile median_price_avg_qty
		save `median_price_avg_qty'
	restore

	merge m:1 state sector product_code using `median_price_avg_qty', nogen
		replace price_st_sec =. if non_zero_obs<6 // Note criteria of minimum 6 obs

	* data at State-Sector-Item level
	collapse price_st_sec qty_avg_recode qty_avg non_zero_obs, by(year state sector product_code  commodity_group)
		merge m:1 year state sector using "${user}/data/processed/other/population_MoH.dta", nogen keep(3)
		g missing_item = mi(qty_avg) // Actually missing by product_code
			replace missing_item = 1 if non_zero_obs<6
	 
	* replace quantity missing if non_zero_obs<6
		replace qty_avg_recode = . if missing_item==1  
		
	* Drop UTs 
		drop if inlist(state, 4, 25, 31, 35)
				
	** All India price and quantity per capita
	*Population by sector
		preserve
			keep population state sector
			collapse population, by(state sector)
			bys sector: egen pop_sec = total(population)
			collapse pop_sector  = pop_sec, by(sector)
			egen pop_india = total(pop_sector)
			tempfile pop
			save `pop'
		restore
	merge m:1 sector using `pop', keepusing(pop_sector pop_india ) nogen keep(3)

	* All India-Sector value and quantities by PRODUCT 
	bys sector product_code: egen double total_value_sec 	= total(qty_avg_recode*price_st_sec*population), m
	bys sector product_code: egen double total_qty_sec 		= total(qty_avg_recode*population), m
					
	g double qty_pc_sec 	= total_qty_sec/pop_sector  //Two quantities
		replace qty_pc_sec 	= . if missing_item==1  	// replace qty as missing for states not consuming that item
			
	g double price_sec = total_value_sec/total_qty_sec
		replace price_sec = . if missing_item==1 
	
	* All INDIA value and quantities price by PRODUCT
		bys product_code: egen double total_value_ind 	= total(qty_avg_recode*price_st_sec*population), m
		bys product_code: egen double total_qty_ind 	= total(qty_avg_recode*population), m

		g double price_ind = total_value_ind/total_qty_ind 
			replace price_ind = . if missing_item==1 
				
	* National quantity by sector-item
		g double qty_pc_ind = total_qty_ind/pop_india //One quantity
			replace qty_pc_ind = . if missing_item==1  // replace qty as missing for states not consuming that item			
	
	drop pop_sec pop_india total_value_ind total_qty_ind total_value_sec total_qty_sec
		sort sector commodity_group  product_code state
		
	save "${user}/data/processed/ces/temp/`y'_med_price_avg_qty_p`x'.dta" , replace
	}
	di in red "End of retrieving Median Price and Quanitities for `y' "
	}
	
	/*Sanity checks (standard deviation)
	foreach y of glo years {
	use "${output}/temp/`y'_med_price_avg_qty_p1.dta" , clear
		append using "${output}/temp/`y'_med_price_avg_qty_p2.dta" 
		append using "${output}/temp/`y'_med_price_avg_qty_p3.dta" 	
		append using "${output}/temp/`y'_med_price_avg_qty_p4.dta" 	
		append using "${output}/temp/`y'_med_price_avg_qty_p5.dta" 			
		append using "${output}/temp/`y'_med_price_avg_qty_p6.dta" 	
	table product_code sector, stat(sd qty_pc_ind)
	table product_code sector, stat(sd price_ind)
	table product_code sector, stat(sd qty_pc_sec)
	table product_code sector, stat(sd price_sec) 
	} */

	/*=======================================================================*/
	* 4. Combine Price and Quantity
	/*=======================================================================*/
foreach y of glo svy_yr { 
	use  "${user}/data/processed/ces/temp/`y'_med_price_avg_qty_p1.dta" , clear
	foreach x of numlist 2(1)6 {
		append using "${user}/data/processed/ces/temp/`y'_med_price_avg_qty_p`x'.dta"
		}
	save "${user}/data/processed/ces/`y'_med_price_avg_qty.dta", replace	
	}	
	
	/*============================================================================*/
	* 5. Calculation of Fisher Indices 
	/*============================================================================*/
foreach y of glo svy_yr { 
	di in red "Start calculating Fisher Indices for `y' "

	use  "${user}/data/processed/ces/`y'_med_price_avg_qty.dta" , clear
	
	*********************		
	*BUNDLE PRICING
	*********************
		* STATE-SECTOR bundles
		*a) Value of state bundle at state prices
			bys state sector commodity_group: egen double st_bundle_st_price = total(qty_avg_recode*price_st_sec), m
			
		*b) Value of state bundle at All india-Sector prices
			bys state sector commodity_group: egen double st_bundle_sec_price = total(qty_avg_recode*price_sec), m
			
		*c) Value of state bundle at India prices
			bys state sector commodity_group: egen double st_bundle_ind_price = total(qty_avg_recode*price_ind), m 
			
	**********************		
	*SECTOR-ALL INDIA bundles
	**********************		
		*a) Value of sector bundle at state prices
			bys state sector commodity_group: egen double sec_bundle_st_price = total(qty_pc_sec*price_st_sec), m 
			
		*b) Value of sector bundle at sector prices
			bys state sector commodity_group: egen double sec_bundle_sec_price = total(qty_pc_sec*price_sec), m 
	
	**********************		
	* ALL INDIA bundles
	**********************		
		*a) Value of India bundle at state prices
			bys state sector commodity_group: egen double ind_bundle_st_price = total(qty_pc_ind*price_st_sec), m	
			
		*b)  Value of India bundle at India prices
			bys state sector commodity_group: egen double ind_bundle_ind_price = total(qty_pc_ind*price_ind), m

	**************************
	* CONSTRUCTION on INDICES
	**************************
	
		*Using All India-sector as base
			g double p_index_sec = st_bundle_st_price/st_bundle_sec_price
			g double l_index_sec = sec_bundle_st_price/sec_bundle_sec_price
			g double f_index_sec = (p_index_sec*l_index_sec)^0.5
			
		*Using All India as base
			g double p_index_ind = st_bundle_st_price/st_bundle_ind_price
			g double l_index_ind = ind_bundle_st_price/ind_bundle_ind_price
			g double f_index_ind = (p_index_ind*l_index_ind)^0.5
			
		la var st_bundle_st_price	"Value of state bundle at state prices"
		la var st_bundle_ind_price	"Value of state bundle at India prices"
		la var ind_bundle_st_price	"Value of India bundle at state prices"
		la var ind_bundle_ind_price "Value of India bundle at India prices"
		la var st_bundle_sec_price	"Value of state bundle at sector prices"
		la var sec_bundle_st_price  "Value of sector bundle at state prices"
		la var sec_bundle_sec_price "Value of sector bundle at sector prices"
		la var f_index_ind 			"Fisher Index relative to India"
		la var f_index_sec 			"Fisher Index relative to sector"
			
	collapse st_bundle_st_price st_bundle_ind_price ind_bundle_st_price ///
		ind_bundle_ind_price st_bundle_sec_price sec_bundle_st_price ///
		sec_bundle_sec_price p_index_ind l_index_ind f_index_ind p_index_sec ///
		l_index_sec f_index_sec, by(state sector commodity_group) 
			
	save "${user}/data/processed/ces/`y'_bundles_indices.dta", replace
		ren f_index_ind sp_def_ind_`y'
		ren f_index_sec sp_def_sec_`y'
	keep state sector commodity_group sp_def_sec_`y' sp_def_ind_`y'
	save "${user}/data/processed/ces/`y'_spatial_deflators.dta", replace
	
	di in red "End of calculating Fisher Indices for `y' "

	//Assign spatial deflators to UTs
	cap drop if inlist(state, 4, 25, 31, 35)
	
	preserve
		keep if inlist(state, 3, 30, 32, 33)
		keep state sector commodity_group sp_def_ind_`y' sp_def_sec_`y'
		replace state = 4 if state==3
		replace state = 25 if state==30
		replace state = 31 if state==32
		replace state = 35 if state==33
		tempfile ut_data
		save `ut_data', replace
	restore
	
	append using `ut_data'
	sort state sector commodity_group

	save "${user}/data/processed/ces/`y'_spatial_deflators.dta", replace	
	}

	*Check
	foreach y of numlist 2011 2022 { 
			foreach j of numlist 1 2 {	
				foreach d in sec ind {
					di in red "`d'" `j' `y'
					use "${user}/data/processed/ces/`y'_spatial_deflators.dta", clear
					table commodity_group state if inlist(state,3,4) & sector==`j', stat(mean sp_def_`d'_`y')
					table commodity_group state if inlist(state,30,25) & sector==`j', stat(mean sp_def_`d'_`y')
					table commodity_group state if inlist(state,32,31) & sector==`j', stat(mean sp_def_`d'_`y')
					table commodity_group state if inlist(state,33,35) & sector==`j', stat(mean sp_def_`d'_`y')
				}
			}
	}
	
	/*============================================================================*/
	* 6. Combine non-zero observations
	/*============================================================================*/

	foreach y of glo svy_yr { 
		use  "${user}/data/processed/ces/temp/`y'_non_zero_obs_p1.dta" , clear
	foreach x of numlist 2(1)6 {
		append using "${user}/data/processed/ces/temp/`y'_non_zero_obs_p`x'.dta"
		}
	save "${user}/data/processed/ces/`y'_non_zero_obs.dta", replace	
	}
	
	* ==========================================================================*
	di in red "THE END OF 05_spatial_deflators" 
	* ==========================================================================*
	cap log close
	exit