
	loc date: display %tdCCYY-NN-DD =daily("`c(current_date)'", "DMY")
	cap log close
	log using "${user}/output/log/08_tables_`date'", replace

	/* =============================================================================
			Project			: India poverty estimates - 2011-12 & 2022-23 
			Dofile			: 08_tables.do
			Last modified	: 27th March 2025
			Inputs			: "${user}/data/processed/ces"											
			Outputs			: "${user}/output/excel/tables.xlsx
			File purpose	: Codes for creating tables in the methodological note
	==============================================================================*/

	glo 	povlines17 	215 365 685 
	scalar	ppp17	= 	19.46903992    // https://databank.worldbank.org/source/icp-2017#
	scalar 	ppp21 	= 	19.4689502716064  // https://databank.worldbank.org/source/icp-2021#
	
	*Step 0. Define macros & scalars
	glo  	svy_yr 		2022 2011
	glo 	ppp_yr		21 17 
	glo 	povlines17 	21500 36500 68500 
	glo 	povlines21 	25984 30000 33984 37984 42000 44112 48112 52112 56112 82786 83000 86786 90786 94786
	
	//Note: 2.5985 is the equivalent to 2.15 in real terms and we want to replicate that
	//rate approximately (in the technical note, this lines are rounded)
		
	glo cpi_2011 = 113.606952605421    //avg monthly cpi survey year (Jul-11 to June-12) IFS
	glo cpi_2017 = 159.181198120117    //avg monthly cpi calendar year (jan-17 to dec-17)  IFS
	glo cpi_2021 = 192.378723144531    //avg monthly cpi calendar year (jan-21 to dec-21)  IFS
	glo cpi_2022 =  211.9832504895     //avg monthly cpi survey year (Ago-22 to July-23) IFS
		
	*Sector=1 -->Rural
	*Sector=2 -->Urban

	/*==============================================================================
		*TABLE 6: Incidence of free clothing and footwear - 2022-23
	==============================================================================*/

	use "${user}/data/processed/ces/master_free_nonfood_school_2022.dta", clear
	
	gen any_govt = (~inlist(num_govt_institution, 0, .))
	gen any_govt_perc = any_govt*100
	
	* Share of HHs with anyone attending/attended govt institutions
	table sector [aw=hhwt], stat(mean any_govt_perc) nformat(%9.1f) sformat("%s%%")
	collect label levels result mean ///
	"Share of HHs with anyone attending/attended government institution", modify	
	collect export "${user}/output/excel/tables.xlsx", sheet("Table 6", replace) cell(A1) modify

	replace dummy_free = 0 if dummy_free == .
	gen dummy_free_perc = dummy_free*100
	
	*% received free clothing out of those attending govt institutions
	table sector [aw=hhwt] if product == 2 & any_govt==1, stat(mean dummy_free_perc) nformat(%9.1f) sformat("%s%%") 
	collect label levels result mean ///
	"Among these HHs, % HHs received clothing (school uniforms) free of cost", modify	
	collect export "${user}/output/excel/tables.xlsx", sheet("Table 6") cell(D1) modify
	
	*% received free footwear out of those attending govt institutions
	table sector [aw=hhwt] if product == 1 & any_govt==1, stat(mean dummy_free_perc) nformat(%9.1f) sformat("%s%%") 
	collect label levels result mean ///
	"Among these HHs, % HHs received footwear (school shoes) free of cost", modify	
	collect export "${user}/output/excel/tables.xlsx", sheet("Table 6") cell(G1) modify

	putexcel set "${user}/output/excel/tables.xlsx", sheet("Table 6") modify
	putexcel A5=(" national") D5=(" national") G5=(" national") ///

	
	/*==============================================================================
		*Table 10. Marginal effects of adjustments to the real welfare aggregate
	==============================================================================*/
			
	*For tables 10-14

	use "${user}/data/processed/ces/master_hh_2022", clear
	append using "${user}/data/processed/ces/master_hh_2011"
	keep hhid year fsu stratum sub_stratum sss
	tempfile hh_2011_2022
	save `hh_2011_2022', replace
	
	use "${user}/data/processed/ces/welfare_agg_17.dta", clear	
	append using "${user}/data/processed/ces/welfare_agg_17_pds.dta"
	append using "${user}/data/processed/ces/welfare_agg_17_lumpexp.dta"
	append using  "${user}/data/processed/ces/welfare_agg_17_hosp.dta"	
	append using  "${user}/data/processed/ces/welfare_agg_17_rent.dta"	
	append using  "${user}/data/processed/ces/welfare_agg_17_all.dta"	
		
	merge m:1 hhid year using "`hh_2011_2022'", keepusing(fsu stratum sub_stratum sss) keep(3) nogen

 	replace scenario = "A. Baseline real expenditure aggregate" if scenario =="{}"
 	replace scenario = "B. Include imputed value of PDS rations and free school items" if scenario =="{_pds}"
 	replace scenario = "C. Exclude purchase value of durables and lumpy expenses" if scenario =="{_lumpexp}"
 	replace scenario = "D. Exclude hospitalization" if scenario =="{_hosp}"
 	replace scenario = "E. Exclude rental expenses" if scenario =="{_rent}"
 	replace scenario = "F. Final real welfare aggregate" if scenario =="{_all}"

 	gen scenario_num = 1 if scenario == "A. Baseline real expenditure aggregate"
 	replace scenario_num = 2 if scenario == "B. Include imputed value of PDS rations and free school items"
 	replace scenario_num = 3 if scenario == "C. Exclude purchase value of durables and lumpy expenses"
	replace scenario_num = 4 if scenario == "D. Exclude hospitalization"
 	replace scenario_num = 5 if scenario == "E. Exclude rental expenses"
 	replace scenario_num = 6 if scenario == "F. Final real welfare aggregate"
	
	lab def sector_desc 1 "Rural" 2 "Urban"
	lab val sector sector_desc
	
	*Create a concatenation of strata, substratum  (1st stage and 2nd stage)
	gen hyphen = "-"
 	egen strata_c = concat(state hyphen sector hyphen stratum hyphen sub_stratum hyphen sss)
	
	*Set the Survey Design (PSU, weights, strata)
	svyset fsu [pweight=pwt], strata(strata_c) singleunit(certainty)
	
	*Step 1. Construct 2017 poverty lines, expressed in 2017 PPP

		foreach i of glo povlines17 {
			gen double pline_`i'= (`i'/10000)*(365/12)*ppp17
			}
			

	*Step 2. Calculate dummies for poor households

	foreach i of glo povlines17 {
		gen double poor_`i'  	= .
		replace poor_`i' 	= welfare_agg17_sp  <= pline_`i' 
		}	

	gen poor_215_perc = poor_215*100
	gen poor_365_perc = poor_365*100
	gen poor_685_perc = poor_685*100
	
	table (scenario) (sector year) [aw=pwt], stat(mean welfare_agg17_sp) nformat(%12.0fc) notot
	collect export "${user}/output/excel/tables.xlsx", sheet("Table 10", replace) cell(A1) modify
	table (scenario) (year) [aw=pwt], stat(mean welfare_agg17_sp) nformat(%12.0fc) notot
	collect export "${user}/output/excel/tables.xlsx", sheet("Table 10") cell(F3) modify
	
	putexcel set "${user}/output/excel/tables.xlsx", sheet("Table 10") modify
	putexcel B1 = ("Marginal effects of adjustments to the real welfare aggregate (in INR, 2017 prices)") ///
	G2 = ("National") F5=("") F6=("") F7=("") F8=("") F9=("") F10=("") F11=("")


	/*==============================================================================
		*Table 11. Extreme poverty rates at each adjustment stage ($2.15 per day, 2017 PPP)
	==============================================================================*/
		
	*********************************
	*Poverty rates (point estimates)
	*********************************
	
	preserve
	
		*Compute poverty rates by year and scenario (by sector) --> 24 point estimations
		svy: mean poor_215_perc, over(year sector scenario_num)  noheader
		
		*Grab the point estimations in a 1x24 vector
		mat means_sec = e(b)
		mat list means_sec
		
		*Compute poverty rates by year and scenario (national) --> 12 point estimations
		svy: mean poor_215_perc, over(year scenario_num) noheader
	
		*Grab the estimations in a 1x12 vector
		mat means_nat = e(b)
		mat list means_nat

		*Crate an empty 6x6 matrix for the 36 point estimations for combinations of year-sector-scenario
		mat define poor_215 = J(6, 6, .)
		
		*Name columns by sector-year and rows by scenario
		mat colnames poor_215 = rural_2011 rural_2022 urban_2011 urban_2022 national_2011 national_2022
		mat rownames poor_215 = baseline_real pds lumpy hospitalization rental final_real
			
		mat list means_sec
		
		*Assign elements of means vectors (means_sec) to the poverty rates matrix (poor_215)
		
		*First column for Rural 2011
		mat poor_215[1,1] = means_sec[1,1]
		mat poor_215[2,1] = means_sec[1,2]
		mat poor_215[3,1] = means_sec[1,3]
		mat poor_215[4,1] = means_sec[1,4]
		mat poor_215[5,1] = means_sec[1,5]
		mat poor_215[6,1] = means_sec[1,6]	
		
		
		*Second column for Rural 2022
		mat poor_215[1,2] = means_sec[1,13]
		mat poor_215[2,2] = means_sec[1,14]
		mat poor_215[3,2] = means_sec[1,15]
		mat poor_215[4,2] = means_sec[1,16]
		mat poor_215[5,2] = means_sec[1,17]
		mat poor_215[6,2] = means_sec[1,18]	
		
		
		*Third column for Urban 2011
		mat poor_215[1,3] = means_sec[1,7]
		mat poor_215[2,3] = means_sec[1,8]
		mat poor_215[3,3] = means_sec[1,9]
		mat poor_215[4,3] = means_sec[1,10]
		mat poor_215[5,3] = means_sec[1,11]
		mat poor_215[6,3] = means_sec[1,12]
		
		
		*Fourth Column is for Urban 2022
		mat poor_215[1,4] = means_sec[1,19]
		mat poor_215[2,4] = means_sec[1,20]
		mat poor_215[3,4] = means_sec[1,21]
		mat poor_215[4,4] = means_sec[1,22]
		mat poor_215[5,4] = means_sec[1,23]
		mat poor_215[6,4] = means_sec[1,24]
		
	
		*National numbers
		svy: mean poor_215_perc, over(year scenario_num) noheader
		mat means_nat = e(b)
		mat list means_nat
		
		*Fifth column is National 2011 
		mat poor_215[1,5] = means_nat[1,1]
		mat poor_215[2,5] = means_nat[1,2]
		mat poor_215[3,5] = means_nat[1,3]
		mat poor_215[4,5] = means_nat[1,4]
		mat poor_215[5,5] = means_nat[1,5]
		mat poor_215[6,5] = means_nat[1,6]	
		
		*Sixth column is National 2022
		mat poor_215[1,6] = means_nat[1,7]
		mat poor_215[2,6] = means_nat[1,8]
		mat poor_215[3,6] = means_nat[1,9]
		mat poor_215[4,6] = means_nat[1,10]
		mat poor_215[5,6] = means_nat[1,11]
		mat poor_215[6,6] = means_nat[1,12]
		
		mat list poor_215
				
		clear
		svmat poor_215, names(col)
		
		gen scenario = "."
		replace scenario = "A. Baseline real expenditure aggregate" in 1
		replace scenario = "B. Include imputed value of PDS rations and free school items" in 2
		replace scenario = "C. Exclude purchase value of durables and lumpy expenses" in 3
		replace scenario = "D. Exclude hospitalization" in 4
		replace scenario = "E. Exclude rental expenses" in 5 
		replace scenario = "F. Final real welfare aggregate" in 6
		
		order scenario
		tostring rural* urban* national*, replace force format(%9.1f) 
		
		*Export matrix with results to Excel
		export excel using "${user}/output/excel/tables.xlsx", firstrow(variables) sheet("Table 11", replace) cell(A2) keepcellfmt
		putexcel set "${user}/output/excel/tables.xlsx", sheet("Table 11") modify
		putexcel A1 = ("Extreme poverty rates at each adjustment stage ($2.15 per day, 2017 PPP, in %)") 
	restore
	
	*********************************
	*Poverty rates (Standard errors)
	*********************************
	preserve
	
		*Compute poverty rates by year and scenario (by sector) --> 24 point estimations
		svy: mean poor_215_perc, over(year sector scenario_num) noheader
		
		*Grab the diagonal of the variance-covariance matrix in a 1x24 vector
		mat variance_sec = e(V)
		mat v_sec = vecdiag(variance_sec)
		
		*Crate an empty 6x6 matrix for the 36 variances of the point estimations for combinations of year-sector-scenario
		mat define se_215 = J(6, 6, .)
		
		*Name columns by sector-year and rows by scenario
		mat colnames se_215 = rural_2011 rural_2022 urban_2011 urban_2022 national_2011 national_2022
		mat rownames se_215 = baseline_real pds lumpy hospitalization rental final_real
		
		*Assign elements of variance vector (v_sec) to the poverty variance matrix (se_215)
		
		*First column: Rural 2011
		mat se_215[1, 1] = sqrt(v_sec[1,1])
		mat se_215[2, 1] = sqrt(v_sec[1,2])
		mat se_215[3, 1] = sqrt(v_sec[1,3])
		mat se_215[4, 1] = sqrt(v_sec[1,4])
		mat se_215[5, 1] = sqrt(v_sec[1,5])
		mat se_215[6, 1] = sqrt(v_sec[1,6])
		
		*Second column: Rural 2022
		mat se_215[1, 2] = sqrt(v_sec[1,13])
		mat se_215[2, 2] = sqrt(v_sec[1,14])
		mat se_215[3, 2] = sqrt(v_sec[1,15])
		mat se_215[4, 2] = sqrt(v_sec[1,16])
		mat se_215[5, 2] = sqrt(v_sec[1,17])
		mat se_215[6, 2] = sqrt(v_sec[1,18])
		
		*Third column: Urban 2011
		mat se_215[1, 3] = sqrt(v_sec[1,7])
		mat se_215[2, 3] = sqrt(v_sec[1,8])
		mat se_215[3, 3] = sqrt(v_sec[1,9])
		mat se_215[4, 3] = sqrt(v_sec[1,10])
		mat se_215[5, 3] = sqrt(v_sec[1,11])
		mat se_215[6, 3] = sqrt(v_sec[1,12])
		
		*Fourth column: Urban 2022
		mat se_215[1, 4] = sqrt(v_sec[1,19])
		mat se_215[2, 4] = sqrt(v_sec[1,20])
		mat se_215[3, 4] = sqrt(v_sec[1,21])
		mat se_215[4, 4] = sqrt(v_sec[1,22])
		mat se_215[5, 4] = sqrt(v_sec[1,23])
		mat se_215[6, 4] = sqrt(v_sec[1,24])
		
		*Compute poverty rates by year and scenario (national) --> 12 point estimations
		svy: mean poor_215_perc, over(year scenario_num) noheader
		
		*grab the diagonal of the variance-covariance matrix 
		mat variance_nat = e(V)
		mat v_nat = vecdiag(variance_nat)
		
		*Fifth column: National 2011
		mat se_215[1, 5] = sqrt(v_nat[1,1])
		mat se_215[2, 5] = sqrt(v_nat[1,2])
		mat se_215[3, 5] = sqrt(v_nat[1,3])
		mat se_215[4, 5] = sqrt(v_nat[1,4])
		mat se_215[5, 5] = sqrt(v_nat[1,5])
		mat se_215[6, 5] = sqrt(v_nat[1,6])
		
		*Sixth column: National 2022
		mat se_215[1, 6] = sqrt(v_nat[1,7])
		mat se_215[2, 6] = sqrt(v_nat[1,8])
		mat se_215[3, 6] = sqrt(v_nat[1,9])
		mat se_215[4, 6] = sqrt(v_nat[1,10])
		mat se_215[5, 6] = sqrt(v_nat[1,11])
		mat se_215[6, 6] = sqrt(v_nat[1,12])
		
		clear
		svmat se_215, names(col)
		
		gen scenario = "."
		replace scenario = "A. Baseline real expenditure aggregate" in 1
		replace scenario = "B. Include imputed value of PDS rations and free school items" in 2
		replace scenario = "C. Exclude purchase value of durables and lumpy expenses" in 3
		replace scenario = "D. Exclude hospitalization" in 4
		replace scenario = "E. Exclude rental expenses" in 5 
		replace scenario = "F. Final real welfare aggregate" in 6
		
		order scenario
		tostring rural* urban* national*, replace force format(%9.1f) 
		
		*Export SE matrix to excel
		export excel using "${user}/output/excel/tables.xlsx", firstrow(variables) sheet("Table 11", modify) cell(A11) keepcellfmt
		putexcel set "${user}/output/excel/tables.xlsx", sheet("Table 11") modify
		putexcel A10 = ("Standard error at each adjustment stage ($2.15 per day, 2017 PPP, in %)") 

	restore
		


	/*==============================================================================
		*Table 12. LMIC poverty rates at each adjustment stage ($3.65 per day, 2017 PPP)
	==============================================================================*/

	*********************************
	*Poverty rates (point estimates)
	*********************************
	preserve
	
		*Compute poverty rates by year and scenario (by sector) --> 24 point estimations
		svy: mean poor_365_perc, over(year sector scenario_num)  noheader
		
		*Grab the point estimations in a 1x24 vector
		mat means_sec = e(b)
		mat list means_sec
		
		*Compute poverty rates by year and scenario (national) --> 12 point estimations
		svy: mean poor_365_perc, over(year scenario_num) noheader
	
		*Grab the estimations in a 1x12 vector
		mat means_nat = e(b)
		mat list means_nat

		*Crate an empty 6x6 matrix for the 36 point estimations for combinations of year-sector-scenario
		mat define poor_365 = J(6, 6, .)
		
		*Name columns by sector-year and rows by scenario
		mat colnames poor_365 = rural_2011 rural_2022 urban_2011 urban_2022 national_2011 national_2022
		mat rownames poor_365 = baseline_real pds lumpy hospitalization rental final_real
			
		mat list means_sec
		
		*Assign elements of means vectors (means_sec) to the poverty rates matrix (poor_215)
		
		*First column for Rural 2011
		mat poor_365[1,1] = means_sec[1,1]
		mat poor_365[2,1] = means_sec[1,2]
		mat poor_365[3,1] = means_sec[1,3]
		mat poor_365[4,1] = means_sec[1,4]
		mat poor_365[5,1] = means_sec[1,5]
		mat poor_365[6,1] = means_sec[1,6]	
		
		
		*Second column for Rural 2022
		mat poor_365[1,2] = means_sec[1,13]
		mat poor_365[2,2] = means_sec[1,14]
		mat poor_365[3,2] = means_sec[1,15]
		mat poor_365[4,2] = means_sec[1,16]
		mat poor_365[5,2] = means_sec[1,17]
		mat poor_365[6,2] = means_sec[1,18]	
		
		
		*Third column for Urban 2011
		mat poor_365[1,3] = means_sec[1,7]
		mat poor_365[2,3] = means_sec[1,8]
		mat poor_365[3,3] = means_sec[1,9]
		mat poor_365[4,3] = means_sec[1,10]
		mat poor_365[5,3] = means_sec[1,11]
		mat poor_365[6,3] = means_sec[1,12]
		
		
		*Fourth Column is for Urban 2022
		mat poor_365[1,4] = means_sec[1,19]
		mat poor_365[2,4] = means_sec[1,20]
		mat poor_365[3,4] = means_sec[1,21]
		mat poor_365[4,4] = means_sec[1,22]
		mat poor_365[5,4] = means_sec[1,23]
		mat poor_365[6,4] = means_sec[1,24]
		
	
		*National numbers
		svy: mean poor_365_perc, over(year scenario_num) noheader
		mat means_nat = e(b)
		mat list means_nat
		
		*Fifth column is National 2011 
		mat poor_365[1,5] = means_nat[1,1]
		mat poor_365[2,5] = means_nat[1,2]
		mat poor_365[3,5] = means_nat[1,3]
		mat poor_365[4,5] = means_nat[1,4]
		mat poor_365[5,5] = means_nat[1,5]
		mat poor_365[6,5] = means_nat[1,6]	
		
		*Sixth column is National 2022
		mat poor_365[1,6] = means_nat[1,7]
		mat poor_365[2,6] = means_nat[1,8]
		mat poor_365[3,6] = means_nat[1,9]
		mat poor_365[4,6] = means_nat[1,10]
		mat poor_365[5,6] = means_nat[1,11]
		mat poor_365[6,6] = means_nat[1,12]
		
		mat list poor_365
				
		clear
		svmat poor_365, names(col)
		
		gen scenario = "."
		replace scenario = "A. Baseline real expenditure aggregate" in 1
		replace scenario = "B. Include imputed value of PDS rations and free school items" in 2
		replace scenario = "C. Exclude purchase value of durables and lumpy expenses" in 3
		replace scenario = "D. Exclude hospitalization" in 4
		replace scenario = "E. Exclude rental expenses" in 5 
		replace scenario = "F. Final real welfare aggregate" in 6
		
		order scenario
		tostring rural* urban* national*, replace force format(%9.1f) 
		
		*Export matrix with results to Excel
		export excel using "${user}/output/excel/tables.xlsx", firstrow(variables) sheet("Table 12", replace) cell(A2) keepcellfmt
		putexcel set "${user}/output/excel/tables.xlsx", sheet("Table 12") modify
		putexcel A1 = ("LMIC poverty rates at each adjustment stage ($3.65 per day, 2017 PPP, in %)") 
	restore
	
	*********************************
	*Poverty rates (Standard errors)
	*********************************
	preserve
	
		*Compute poverty rates by year and scenario (by sector) --> 24 point estimations
		svy: mean poor_365_perc, over(year sector scenario_num) noheader
		
		*Grab the diagonal of the variance-covariance matrix in a 1x24 vector
		mat variance_sec = e(V)
		mat v_sec = vecdiag(variance_sec)
		
		*Crate an empty 6x6 matrix for the 36 variances of the point estimations for combinations of year-sector-scenario
		mat define se_365 = J(6, 6, .)
		
		*Name columns by sector-year and rows by scenario
		mat colnames se_365 = rural_2011 rural_2022 urban_2011 urban_2022 national_2011 national_2022
		mat rownames se_365 = baseline_real pds lumpy hospitalization rental final_real
		
		*Assign elements of variance vector (v_sec) to the poverty variance matrix (se_215)
		
		*First column: Rural 2011
		mat se_365[1, 1] = sqrt(v_sec[1,1])
		mat se_365[2, 1] = sqrt(v_sec[1,2])
		mat se_365[3, 1] = sqrt(v_sec[1,3])
		mat se_365[4, 1] = sqrt(v_sec[1,4])
		mat se_365[5, 1] = sqrt(v_sec[1,5])
		mat se_365[6, 1] = sqrt(v_sec[1,6])
		
		*Second column: Rural 2022
		mat se_365[1, 2] = sqrt(v_sec[1,13])
		mat se_365[2, 2] = sqrt(v_sec[1,14])
		mat se_365[3, 2] = sqrt(v_sec[1,15])
		mat se_365[4, 2] = sqrt(v_sec[1,16])
		mat se_365[5, 2] = sqrt(v_sec[1,17])
		mat se_365[6, 2] = sqrt(v_sec[1,18])
		
		*Third column: Urban 2011
		mat se_365[1, 3] = sqrt(v_sec[1,7])
		mat se_365[2, 3] = sqrt(v_sec[1,8])
		mat se_365[3, 3] = sqrt(v_sec[1,9])
		mat se_365[4, 3] = sqrt(v_sec[1,10])
		mat se_365[5, 3] = sqrt(v_sec[1,11])
		mat se_365[6, 3] = sqrt(v_sec[1,12])
		
		*Fourth column: Urban 2022
		mat se_365[1, 4] = sqrt(v_sec[1,19])
		mat se_365[2, 4] = sqrt(v_sec[1,20])
		mat se_365[3, 4] = sqrt(v_sec[1,21])
		mat se_365[4, 4] = sqrt(v_sec[1,22])
		mat se_365[5, 4] = sqrt(v_sec[1,23])
		mat se_365[6, 4] = sqrt(v_sec[1,24])
		
		*Compute poverty rates by year and scenario (national) --> 12 point estimations
		svy: mean poor_365_perc, over(year scenario_num) noheader
		
		*grab the diagonal of the variance-covariance matrix 
		mat variance_nat = e(V)
		mat v_nat = vecdiag(variance_nat)
		
		*Fifth column: National 2011
		mat se_365[1, 5] = sqrt(v_nat[1,1])
		mat se_365[2, 5] = sqrt(v_nat[1,2])
		mat se_365[3, 5] = sqrt(v_nat[1,3])
		mat se_365[4, 5] = sqrt(v_nat[1,4])
		mat se_365[5, 5] = sqrt(v_nat[1,5])
		mat se_365[6, 5] = sqrt(v_nat[1,6])
		
		*Sixth column: National 2022
		mat se_365[1, 6] = sqrt(v_nat[1,7])
		mat se_365[2, 6] = sqrt(v_nat[1,8])
		mat se_365[3, 6] = sqrt(v_nat[1,9])
		mat se_365[4, 6] = sqrt(v_nat[1,10])
		mat se_365[5, 6] = sqrt(v_nat[1,11])
		mat se_365[6, 6] = sqrt(v_nat[1,12])
		
		clear
		svmat se_365, names(col)
		
		gen scenario = "."
		replace scenario = "A. Baseline real expenditure aggregate" in 1
		replace scenario = "B. Include imputed value of PDS rations and free school items" in 2
		replace scenario = "C. Exclude purchase value of durables and lumpy expenses" in 3
		replace scenario = "D. Exclude hospitalization" in 4
		replace scenario = "E. Exclude rental expenses" in 5 
		replace scenario = "F. Final real welfare aggregate" in 6
		
		order scenario
		tostring rural* urban* national*, replace force format(%9.1f) 
		
		*Export SE matrix to excel
		export excel using "${user}/output/excel/tables.xlsx", firstrow(variables) sheet("Table 12", modify) cell(A11) keepcellfmt
		putexcel set "${user}/output/excel/tables.xlsx", sheet("Table 12") modify
		putexcel A10 = ("Standard error at each adjustment stage ($3.65 per day, 2017 PPP, in %)") 

	restore
		

	/*==============================================================================
		*Table 13. UMIC poverty rates at each adjustment stage ($6.85 per day, 2017 PPP)
	==============================================================================*/

	*********************************
	*Poverty rates (point estimates)
	*********************************

	preserve
	
		*Compute poverty rates by year and scenario (by sector) --> 24 point estimations
		svy: mean poor_685_perc, over(year sector scenario_num)  noheader
		
		*Grab the point estimations in a 1x24 vector
		mat means_sec = e(b)
		mat list means_sec
		
		*Compute poverty rates by year and scenario (national) --> 12 point estimations
		svy: mean poor_685_perc, over(year scenario_num) noheader
	
		*Grab the estimations in a 1x12 vector
		mat means_nat = e(b)
		mat list means_nat

		*Crate an empty 6x6 matrix for the 36 point estimations for combinations of year-sector-scenario
		mat define poor_685 = J(6, 6, .)
		
		*Name columns by sector-year and rows by scenario
		mat colnames poor_685 = rural_2011 rural_2022 urban_2011 urban_2022 national_2011 national_2022
		mat rownames poor_685 = baseline_real pds lumpy hospitalization rental final_real
			
		mat list means_sec
		
		*Assign elements of means vectors (means_sec) to the poverty rates matrix (poor_215)
		
		*First column for Rural 2011
		mat poor_685[1,1] = means_sec[1,1]
		mat poor_685[2,1] = means_sec[1,2]
		mat poor_685[3,1] = means_sec[1,3]
		mat poor_685[4,1] = means_sec[1,4]
		mat poor_685[5,1] = means_sec[1,5]
		mat poor_685[6,1] = means_sec[1,6]	
		
		
		*Second column for Rural 2022
		mat poor_685[1,2] = means_sec[1,13]
		mat poor_685[2,2] = means_sec[1,14]
		mat poor_685[3,2] = means_sec[1,15]
		mat poor_685[4,2] = means_sec[1,16]
		mat poor_685[5,2] = means_sec[1,17]
		mat poor_685[6,2] = means_sec[1,18]	
		
		
		*Third column for Urban 2011
		mat poor_685[1,3] = means_sec[1,7]
		mat poor_685[2,3] = means_sec[1,8]
		mat poor_685[3,3] = means_sec[1,9]
		mat poor_685[4,3] = means_sec[1,10]
		mat poor_685[5,3] = means_sec[1,11]
		mat poor_685[6,3] = means_sec[1,12]
		
		
		*Fourth Column is for Urban 2022
		mat poor_685[1,4] = means_sec[1,19]
		mat poor_685[2,4] = means_sec[1,20]
		mat poor_685[3,4] = means_sec[1,21]
		mat poor_685[4,4] = means_sec[1,22]
		mat poor_685[5,4] = means_sec[1,23]
		mat poor_685[6,4] = means_sec[1,24]
		
	
		*National numbers
		svy: mean poor_685_perc, over(year scenario_num) noheader
		mat means_nat = e(b)
		mat list means_nat
		
		*Fifth column is National 2011 
		mat poor_685[1,5] = means_nat[1,1]
		mat poor_685[2,5] = means_nat[1,2]
		mat poor_685[3,5] = means_nat[1,3]
		mat poor_685[4,5] = means_nat[1,4]
		mat poor_685[5,5] = means_nat[1,5]
		mat poor_685[6,5] = means_nat[1,6]	
		
		*Sixth column is National 2022
		mat poor_685[1,6] = means_nat[1,7]
		mat poor_685[2,6] = means_nat[1,8]
		mat poor_685[3,6] = means_nat[1,9]
		mat poor_685[4,6] = means_nat[1,10]
		mat poor_685[5,6] = means_nat[1,11]
		mat poor_685[6,6] = means_nat[1,12]
		
		mat list poor_685
				
		clear
		svmat poor_685, names(col)
		
		gen scenario = "."
		replace scenario = "A. Baseline real expenditure aggregate" in 1
		replace scenario = "B. Include imputed value of PDS rations and free school items" in 2
		replace scenario = "C. Exclude purchase value of durables and lumpy expenses" in 3
		replace scenario = "D. Exclude hospitalization" in 4
		replace scenario = "E. Exclude rental expenses" in 5 
		replace scenario = "F. Final real welfare aggregate" in 6
		
		order scenario
		tostring rural* urban* national*, replace force format(%9.1f) 
		
		*Export matrix with results to Excel
		export excel using "${user}/output/excel/tables.xlsx", firstrow(variables) sheet("Table 13", replace) cell(A2) keepcellfmt
		putexcel set "${user}/output/excel/tables.xlsx", sheet("Table 13") modify
		putexcel A1 = ("UMIC poverty rates at each adjustment stage ($6.85 per day, 2017 PPP, in %)") 
	restore
	
	*********************************
	*Poverty rates (standard errors)
	*********************************
	
		preserve
	
		*Compute poverty rates by year and scenario (by sector) --> 24 point estimations
		svy: mean poor_685_perc, over(year sector scenario_num) noheader
		
		*Grab the diagonal of the variance-covariance matrix in a 1x24 vector
		mat variance_sec = e(V)
		mat v_sec = vecdiag(variance_sec)
		
		*Crate an empty 6x6 matrix for the 36 variances of the point estimations for combinations of year-sector-scenario
		mat define se_685 = J(6, 6, .)
		
		*Name columns by sector-year and rows by scenario
		mat colnames se_685 = rural_2011 rural_2022 urban_2011 urban_2022 national_2011 national_2022
		mat rownames se_685 = baseline_real pds lumpy hospitalization rental final_real
		
		*Assign elements of variance vector (v_sec) to the poverty variance matrix (se_215)
		
		*First column: Rural 2011
		mat se_685[1, 1] = sqrt(v_sec[1,1])
		mat se_685[2, 1] = sqrt(v_sec[1,2])
		mat se_685[3, 1] = sqrt(v_sec[1,3])
		mat se_685[4, 1] = sqrt(v_sec[1,4])
		mat se_685[5, 1] = sqrt(v_sec[1,5])
		mat se_685[6, 1] = sqrt(v_sec[1,6])
		
		*Second column: Rural 2022
		mat se_685[1, 2] = sqrt(v_sec[1,13])
		mat se_685[2, 2] = sqrt(v_sec[1,14])
		mat se_685[3, 2] = sqrt(v_sec[1,15])
		mat se_685[4, 2] = sqrt(v_sec[1,16])
		mat se_685[5, 2] = sqrt(v_sec[1,17])
		mat se_685[6, 2] = sqrt(v_sec[1,18])
		
		*Third column: Urban 2011
		mat se_685[1, 3] = sqrt(v_sec[1,7])
		mat se_685[2, 3] = sqrt(v_sec[1,8])
		mat se_685[3, 3] = sqrt(v_sec[1,9])
		mat se_685[4, 3] = sqrt(v_sec[1,10])
		mat se_685[5, 3] = sqrt(v_sec[1,11])
		mat se_685[6, 3] = sqrt(v_sec[1,12])
		
		*Fourth column: Urban 2022
		mat se_685[1, 4] = sqrt(v_sec[1,19])
		mat se_685[2, 4] = sqrt(v_sec[1,20])
		mat se_685[3, 4] = sqrt(v_sec[1,21])
		mat se_685[4, 4] = sqrt(v_sec[1,22])
		mat se_685[5, 4] = sqrt(v_sec[1,23])
		mat se_685[6, 4] = sqrt(v_sec[1,24])
		
		*Compute poverty rates by year and scenario (national) --> 12 point estimations
		svy: mean poor_685_perc, over(year scenario_num) noheader
		
		*grab the diagonal of the variance-covariance matrix 
		mat variance_nat = e(V)
		mat v_nat = vecdiag(variance_nat)
		
		*Fifth column: National 2011
		mat se_685[1, 5] = sqrt(v_nat[1,1])
		mat se_685[2, 5] = sqrt(v_nat[1,2])
		mat se_685[3, 5] = sqrt(v_nat[1,3])
		mat se_685[4, 5] = sqrt(v_nat[1,4])
		mat se_685[5, 5] = sqrt(v_nat[1,5])
		mat se_685[6, 5] = sqrt(v_nat[1,6])
		
		*Sixth column: National 2022
		mat se_685[1, 6] = sqrt(v_nat[1,7])
		mat se_685[2, 6] = sqrt(v_nat[1,8])
		mat se_685[3, 6] = sqrt(v_nat[1,9])
		mat se_685[4, 6] = sqrt(v_nat[1,10])
		mat se_685[5, 6] = sqrt(v_nat[1,11])
		mat se_685[6, 6] = sqrt(v_nat[1,12])
		
		clear
		svmat se_685, names(col)
		
		gen scenario = "."
		replace scenario = "A. Baseline real expenditure aggregate" in 1
		replace scenario = "B. Include imputed value of PDS rations and free school items" in 2
		replace scenario = "C. Exclude purchase value of durables and lumpy expenses" in 3
		replace scenario = "D. Exclude hospitalization" in 4
		replace scenario = "E. Exclude rental expenses" in 5 
		replace scenario = "F. Final real welfare aggregate" in 6
		
		order scenario
		tostring rural* urban* national*, replace force format(%9.1f) 
		
		*Export SE matrix to excel
		export excel using "${user}/output/excel/tables.xlsx", firstrow(variables) sheet("Table 13", modify) cell(A11) keepcellfmt
		putexcel set "${user}/output/excel/tables.xlsx", sheet("Table 13") modify
		putexcel A10 = ("Standard error at each adjustment stage ($6.85 per day, 2017 PPP, in %)") 

	restore
			
	
	
	/*==============================================================================
		*Table 14. Headcount poverty estimates, hypothetical IPLs in 2021PPP
	==============================================================================*/

	*Construct welfare aggregate in 2021 prices (for both 2011 & 2022)

	use          "${user}/data/processed/ces/mpce_2011_all.dta", clear
	append using "${user}/data/processed/ces/mpce_2022_all.dta"
	
	drop if mi(hhid)
	
		g double welfare_agg21_nom = .
		g double welfare_agg21_wy = .
		g double welfare_agg21_sp = .
		
	foreach v of glo svy_yr {	
		replace welfare_agg21_nom 	= mpce_nom*(${cpi_2021}/${cpi_`v'}) 		if year ==`v'
		replace welfare_agg21_wy 	= mpce_wy_def*(${cpi_2021}/${cpi_`v'}) 	if year ==`v'
		replace welfare_agg21_sp 	= mpce_sp_def_ind*(${cpi_2021}/${cpi_`v'}) if year ==`v' //Use All-India 
		}
	
	keep hhid state sector year welfare_agg21* mpce_* pwt

	*Construct 2021 poverty lines, expressed in 2021 PPP	
	foreach i of glo povlines21 {
		g double pline_`i' 		= (`i'/10000)*(365/12)*ppp21
		}
		
	*Calculate Poverty Rates under different Poverty Lines and PPPs

	foreach i of glo  povlines21 {
		g double poor_nom`i'_21 = .
		g double poor_wy`i'_21 	= .
		g double poor_sp`i'_21  = .
		}
			
	*Under 2021 Poverty Lines, expressed in 2021 PPP
	foreach v of glo svy_yr  	{	
	foreach i of glo povlines21 {
		replace poor_nom`i'_21 = welfare_agg21_nom <= pline_`i' if year==`v'
		replace poor_wy`i'_21  = welfare_agg21_wy <= pline_`i'  if year==`v'
		replace poor_sp`i'_21  = welfare_agg21_sp <= pline_`i'  if year==`v'
		}	
		}	
		
	*Fix labels 
		lab define state_lab 	1000 "India", add
		lab define sector_lab 	1 "Rural" 2 "Urban" 3 "All", replace
		lab val state state_lab
		lab val sector sector_lab
				
		gen  poor_sp25984_21_perc = 100*poor_sp25984_21
		gen poor_sp30000_21_perc = 100*poor_sp30000_21
		gen poor_sp33984_21_perc = 100*poor_sp33984_21
		gen poor_sp37984_21_perc = 100*poor_sp37984_21
		
		gen poor_sp42000_21_perc = 100*poor_sp42000_21
		gen poor_sp44112_21_perc = 100*poor_sp44112_21
		gen poor_sp48112_21_perc = 100*poor_sp48112_21
		gen poor_sp52112_21_perc = 100*poor_sp52112_21
		
		gen poor_sp82786_21_perc = 100*poor_sp82786_21
		gen poor_sp86786_21_perc = 100*poor_sp86786_21
		gen poor_sp90786_21_perc = 100*poor_sp90786_21
		gen poor_sp94786_21_perc = 100*poor_sp94786_21
		
		table year [aw=pwt], stat(mean poor_sp25984_21_perc  poor_sp30000_21_perc  poor_sp33984_21_perc  poor_sp37984_21_perc ) nformat(%9.1f) sformat("%s%%") notot
		collect export "${user}/output/excel/tables.xlsx", sheet("Table 14", replace) cell(A2) modify

		table year [aw=pwt], stat(mean poor_sp42000_21_perc  poor_sp44112_21_perc  poor_sp48112_21_perc  poor_sp52112_21_perc ) nformat(%9.1f) sformat("%s%%") notot
		collect export "${user}/output/excel/tables.xlsx", sheet("Table 14") cell(A8) modify

		table year [aw=pwt], stat(mean poor_sp82786_21_perc  poor_sp86786_21_perc  poor_sp90786_21_perc  poor_sp94786_21_perc ) nformat(%9.1f) sformat("%s%%") notot
		collect export "${user}/output/excel/tables.xlsx", sheet("Table 14") cell(A14) modify
		
		putexcel set "${user}/output/excel/tables.xlsx", sheet("Table 14") modify
		putexcel A1=("Extreme poverty") A7=("LMIC poverty") A13=("UMIC poverty")
		
	/*==============================================================================
		*TABLE 15: Gini index
	==============================================================================*/

	use "${user}/data/processed/ces/welfare_agg_17.dta", clear	
	append using "${user}/data/processed/ces/welfare_agg_17_pds.dta"
	append using "${user}/data/processed/ces/welfare_agg_17_lumpexp.dta"
	append using  "${user}/data/processed/ces/welfare_agg_17_hosp.dta"	
	append using  "${user}/data/processed/ces/welfare_agg_17_rent.dta"	
	append using  "${user}/data/processed/ces/welfare_agg_17_all.dta"		
	
	encode scenario, gen(scenario_num)
	
	levelsof scenario, local(scenario)
	foreach s of local scenario {
		di in red "`s'"
	}
	
	*All-India, rural and urban gini - define and store results in matrix for all scenarios
	mat drop _all
		foreach y of numlist 2011 2022 {
			foreach s of numlist 1/6 {
				mat define gini_`y'_`s' = J(1, 4, .)
				mat rownames gini_`y'_`s' = `y'
				mat colnames gini_`y'_`s' = rural urban national scenario_num
			
			foreach i of numlist 1 2 {
				di in red "sector - `i', year - `y', scenario - `s'"
				ainequal welfare_agg17_sp  [aw=pwt] if sector==`i' & year==`y' & scenario_num==`s'
				mat gini_`y'_`s' [1,`i'] = `r(gini_1)'		
				}
					di in red "year - `y', scenario - `s'"
					ainequal welfare_agg17_sp  [aw=pwt] if year==`y' & scenario_num==`s'
					mat gini_`y'_`s' [1,3] = `r(gini_1)'	
					mat gini_`y'_`s' [1,4] = `s'	
					}
					}
	
	*Combine matrix for each scenario
	foreach s of numlist 1/6 {
		mat define gini_`s' = J(2,4,.)
		mat gini_`s' = gini_2011_`s' \ gini_2022_`s'
	}
	
	mat define gini = J(2, 4,.)
	mat gini = gini_6 \ gini_4 \ gini_3 \ gini_2 \ gini_5 \ gini_1 
	
	clear
	svmat gini, names(col)
		
	replace rural = rural*100
	format rural %9.1f
		
	replace urban = urban*100
	format urban %9.1f
	
	replace national = national*100
	format national %9.1f
	
	gen scenario = "."
	replace scenario = "A. Baseline real expenditure aggregate" if scenario_num == 6
	replace scenario = "B. Include imputed value of PDS rations and free school items" if scenario_num == 4
	replace scenario = "C. Exclude purchase value of durables and lumpy expenses" if scenario_num == 3
	replace scenario = "D. Exclude hospitalization" if scenario_num == 2
	replace scenario = "E. Exclude rental expenses" if scenario_num == 5 
	replace scenario = "F. Final real welfare aggregate" if scenario_num == 1
	
	gen year = . 
	replace year = 2011 in 1 
	replace year = 2011 in 3 
	replace year = 2011 in 5 
	replace year = 2011 in 7 
	replace year = 2011 in 9
	replace year = 2011 in 11
	replace year = 2022 if missing(year)
	
	reshape wide rural urban national, i(scenario) j(year)
	drop scenario_num
	order scenario rural2011 rural2022 urban2011 urban2022 national2011 national2022
	
	tostring rural2011, gen(rural_2011) force format(%9.1f)
	tostring rural2022, gen(rural_2022) force format(%9.1f)
	tostring urban2011, gen(urban_2011) force format(%9.1f)
	tostring urban2022, gen(urban_2022) force format(%9.1f)
	tostring national2011, gen(national_2011) force format(%9.1f)
	tostring national2022, gen(national_2022) force format(%9.1f)
	
	drop rural2011 rural2022 urban2011 urban2022 national2011 national2022
	
	export excel using "${user}/output/excel/tables.xlsx", firstrow(variables) sheet("Table 15", replace) keepcellfmt
					
	/*==============================================================================
		*Table 16. Poverty and inequality after correcting for outliers at 3 and 4 standard deviations
	==============================================================================*/

	use "${user}/output/welfare_pov_final.dta", clear
	gen scenario = "A. Baseline"
	append using "${user}/output/sensitivity_checks/outliers/welfare_pov_final_out3_all.dta"
	replace scenario = "B. 3 SD" if missing(scenario)
	append using "${user}/output/sensitivity_checks/outliers/welfare_pov_final_out4_all.dta"	
	replace scenario = "C. 4 SD" if missing(scenario)
		
	*Poverty
	table sector (year scenario) [aw=pwt], stat(mean poor_215_perc) nformat(%9.2f) 
	collect export "${user}/output/excel/tables.xlsx", sheet("Table 16", replace) cell(A1) modify
	
	table sector (year scenario) [aw=pwt], stat(mean poor_365_perc) nformat(%9.2f) 
	collect export "${user}/output/excel/tables.xlsx", sheet("Table 16") cell(A10) modify

	table sector (year scenario) [aw=pwt], stat(mean poor_685_perc) nformat(%9.2f) 
	collect export "${user}/output/excel/tables.xlsx", sheet("Table 16") cell(A20) modify
	
	putexcel set "${user}/output/excel/tables.xlsx", sheet("Table 16") modify
	putexcel B1 = ("Extreme poverty rates at each adjustment stage ($2.15 per day, 2017 PPP, in %)") ///
	B10 = ("LMIC poverty rates at each adjustment stage ($3.65 per day, 2017 PPP, in %)") ///
	B20 = ("UMIC poverty rates at each adjustment stage ($3.65 per day, 2017 PPP, in %)") ///
	A8=( "National") A17=( "National") A27=( "National") E4:E8=("") I4:I8=("") ///
	E13:E17=("") I13:I17=("") E23:E27=("") I23:I27=("") J2:M8=("") J11:M17=("") J21:M27=("") 
	
	*Gini
	encode scenario, gen(scenario_num)
		
	levelsof scenario, local(scenario)
	foreach s of local scenario {
		di in red "`s'"
	}
	
	*All-India, rural and urban gini - define and store results in matrix for all scenarios
	mat drop _all
		foreach y of numlist 2011 2022 {
			foreach s of numlist 1/3 {
				mat define gini_`y'_`s' = J(4, 1, .)
				mat rownames gini_`y'_`s' = rural urban national scenario_num
				mat colnames gini_`y'_`s' = `y'

			foreach i of numlist 1 2 {
				di in red "sector - `i', year - `y', scenario - `s'"
				ainequal welfare_agg17_sp  [aw=pwt] if sector==`i' & year==`y' & scenario_num==`s'
				mat gini_`y'_`s' [`i',1] = `r(gini_1)'		
				}
			
			di in red "year - `y', scenario - `s'"
					ainequal welfare_agg17_sp  [aw=pwt] if year==`y' & scenario_num==`s'
					mat gini_`y'_`s' [3,1] = `r(gini_1)'	
					mat gini_`y'_`s' [4,1] = `s'	
					}
					}
	
	*Combine matrix for each scenario
	mat gini_2011 = gini_2011_1, gini_2011_2, gini_2011_3
	mat gini_2022 = gini_2022_1, gini_2022_2, gini_2022_3

	mat gini = gini_2011, gini_2022
		
	clear
	svmat gini, names(year)
	
	foreach i of numlist 1/6 {
		replace year`i' = year`i'*100
	}
	
	tostring year1, gen(year2011_base) force format(%9.2f)
	tostring year2, gen(year2011_3sd) force format(%9.2f)
	tostring year3, gen(year2011_4sd) force format(%9.2f)
	tostring year4, gen(year2022_base) force format(%9.2f)
	tostring year5, gen(year2022_3sd) force format(%9.2f)
	tostring year6, gen(year2022_4sd) force format(%9.2f)

	drop year1 year2 year3 year4 year5 year6
	drop in 4
	
	gen sector = "Rural" in 1 
	replace sector = "Urban" in 2
	replace sector = "National" in 3
	
	order sector

	export excel using "${user}/output/excel/tables.xlsx", firstrow(variables) sheet("Table 16", modify) cell(A30) keepcellfmt
	
	/*==============================================================================
		*Table 17. Poverty and inequality rates incorporating different temporal adjustments
	==============================================================================*/

	use   "${user}/output/sensitivity_checks/inter_temporal/welfare_pov_final.dta", clear
	keep year hhid pwt sector poor_215_perc poor_365_perc poor_685_perc welfare_agg17_sp
	gen scenario = "A. Baseline"
	
	preserve
	use "${user}/output/sensitivity_checks/inter_temporal/welfare_pov_final.dta", clear
	keep year hhid pwt sector poor_215_uv1_perc poor_365_uv1_perc poor_685_uv1_perc welfare_agg17_uvtemp_v1
	rename poor_215_uv1_perc poor_215_perc
	rename poor_365_uv1_perc poor_365_perc
	rename poor_685_uv1_perc poor_685_perc
	gen scenario = "B. UV v1"
	
	tempfile uv_v1
	save `uv_v1'
	restore
	
	preserve
	use "${user}/output/sensitivity_checks/inter_temporal/welfare_pov_final.dta", clear
	keep year hhid pwt sector poor_215_uv2_perc poor_365_uv2_perc poor_685_uv2_perc welfare_agg17_uvtemp_v2
	rename poor_215_uv2_perc poor_215_perc
	rename poor_365_uv2_perc poor_365_perc
	rename poor_685_uv2_perc poor_685_perc
	gen scenario = "C. UV v2"
	
	tempfile uv_v2
	save `uv_v2'
	restore
	
	append using `uv_v1'
	append using `uv_v2'
		
	table sector (year scenario)  [aw=pwt], stat(mean poor_215_perc)  nformat(%9.2f) 
	collect export "${user}/output/excel/tables.xlsx", sheet("Table 17", replace) cell(A1) modify
	
	table sector (year scenario)  [aw=pwt], stat(mean poor_365_perc)  nformat(%9.2f) 
	collect export "${user}/output/excel/tables.xlsx", sheet("Table 17") cell(A10) modify
	
	table sector (year scenario)  [aw=pwt], stat(mean poor_685_perc)  nformat(%9.2f) 
	collect export "${user}/output/excel/tables.xlsx", sheet("Table 17") cell(A20) modify
	
	putexcel set "${user}/output/excel/tables.xlsx", sheet("Table 17") modify
	putexcel B1 = ("Extreme poverty rates at each adjustment stage ($2.15 per day, 2017 PPP, in %)") ///
	B10 = ("LMIC poverty rates at each adjustment stage ($3.65 per day, 2017 PPP, in %)") ///
	B20 = ("UMIC poverty rates at each adjustment stage ($3.65 per day, 2017 PPP, in %)") ///
	A8=( "National") A17=( "National") A27=( "National") E4:E8=("") I4:I8=("") ///
	E13:E17=("") I13:I17=("") E23:E27=("") I23:I27=("") J2:M8=("") J11:M17=("") J21:M27=("") 
	
	*Gini
	encode scenario, gen(scenario_num)
	
	replace welfare_agg17_sp = welfare_agg17_uvtemp_v1 if scenario_num==2
	replace welfare_agg17_sp = welfare_agg17_uvtemp_v2 if scenario_num==3
	
	levelsof scenario, local(scenario)
	foreach s of local scenario {
		di in red "`s'"
	}
	
	*All-India, rural and urban gini - define and store results in matrix for all scenarios
	mat drop _all
		foreach y of numlist 2011 2022 {
			foreach s of numlist 1/3 {
				mat define gini_`y'_`s' = J(4, 1, .)
				mat rownames gini_`y'_`s' = rural urban national scenario_num
				mat colnames gini_`y'_`s' = `y'

			foreach i of numlist 1 2 {
				di in red "sector - `i', year - `y', scenario - `s'"
				ainequal welfare_agg17_sp  [aw=pwt] if sector==`i' & year==`y' & scenario_num==`s'
				mat gini_`y'_`s' [`i',1] = `r(gini_1)'		
				}
			
			di in red "year - `y', scenario - `s'"
					ainequal welfare_agg17_sp  [aw=pwt] if year==`y' & scenario_num==`s'
					mat gini_`y'_`s' [3,1] = `r(gini_1)'	
					mat gini_`y'_`s' [4,1] = `s'	
					}
					}
	
	*Combine matrix for each scenario
	mat gini_2011 = gini_2011_1, gini_2011_2, gini_2011_3
	mat gini_2022 = gini_2022_1, gini_2022_2, gini_2022_3

	mat gini = gini_2011, gini_2022
		
	clear
	svmat gini, names(year)
	
	foreach i of numlist 1/6 {
		replace year`i' = year`i'*100
	}
	
	tostring year1, gen(year2011_base) force format(%9.2f)
	tostring year2, gen(year2011_uv1) force format(%9.2f)
	tostring year3, gen(year2011_uv2) force format(%9.2f)
	tostring year4, gen(year2022_base) force format(%9.2f)
	tostring year5, gen(year2022_uv1) force format(%9.2f)
	tostring year6, gen(year2022_uv2) force format(%9.2f)

	drop year1 year2 year3 year4 year5 year6
	drop in 4
	
	gen sector = "Rural" in 1 
	replace sector = "Urban" in 2
	replace sector = "National" in 3
	
	order sector
	
	export excel using "${user}/output/excel/tables.xlsx", firstrow(variables) sheet("Table 17", modify) cell(A30) keepcellfmt
	
	/*==============================================================================
		*Table 18. Poverty and inequality rates incorporating different household sizes
	==============================================================================*/


	use "${user}/output/welfare_pov_final.dta", clear
	keep if year==2022
	gen scenario = "A. FDC"
	append using  "${user}/output/sensitivity_checks/hhsize/welfare_pov_final_h3.dta"
	replace scenario = "B. CSQ" if missing(scenario)
	append using   "${user}/output/sensitivity_checks/hhsize/welfare_pov_final_h4.dta"
	replace scenario = "C. DGQ" if missing(scenario)
	
	gen hhwt = pwt/hhsize
	table scenario [aw=hhwt], stat(mean hhsize) //Average household size 
		
	*2.15
	table sector (scenario) [aw=pwt], stat(mean poor_215_perc) nformat(%9.2f) totals(scenario)
	collect label dim scenario "Poverty rates ($2.15, in %)"
	collect export "${user}/output/excel/tables.xlsx", sheet("Table 18", replace) cell(A1) modify
	
	*3.65
	table sector (scenario) [aw=pwt], stat(mean poor_365_perc) nformat(%9.2f) totals(scenario)
	collect label dim scenario "Poverty rates ($3.65, in %)"
	collect export "${user}/output/excel/tables.xlsx", sheet("Table 18") cell(A8) modify
	
	*6.85
	table sector (scenario) [aw=pwt], stat(mean poor_685_perc) nformat(%9.2f) totals(scenario)
	collect label dim scenario "Poverty rates ($6.85, in %)"
	collect export "${user}/output/excel/tables.xlsx", sheet("Table 18") cell(A15) modify
	
	putexcel set "${user}/output/excel/tables.xlsx", sheet("Table 18") modify
	putexcel A6=(" National") A13=(" National") A20=(" National")
	
	
	*Gini
	encode scenario, gen(scenario_num)
	
		mat drop _all
		foreach y of numlist 2022 {
			foreach s of numlist 1/3 {
				mat define gini_`y'_`s' = J(4, 1, .)
				mat rownames gini_`y'_`s' = rural urban national scenario_num
				mat colnames gini_`y'_`s' = `y'

			foreach i of numlist 1 2 {
				di in red "sector - `i', year - `y', scenario - `s'"
				ainequal welfare_agg17_sp  [aw=pwt] if sector==`i' & year==`y' & scenario_num==`s'
				mat gini_`y'_`s' [`i',1] = `r(gini_1)'		
				}
			
			di in red "year - `y', scenario - `s'"
					ainequal welfare_agg17_sp  [aw=pwt] if year==`y' & scenario_num==`s'
					mat gini_`y'_`s' [3,1] = `r(gini_1)'	
					mat gini_`y'_`s' [4,1] = `s'	
					}
					}
	
	*Combine matrix for each scenario
	mat gini_2022 = gini_2022_1, gini_2022_2, gini_2022_3
		
	clear
	svmat gini_2022, names(year)
	
	foreach i of numlist 1/3 {
		replace year`i' = year`i'*100
	}

	tostring year1, gen(year2022_fdq) force format(%9.2f)
	tostring year2, gen(year2022_csq) force format(%9.2f)
	tostring year3, gen(year2022_dgq) force format(%9.2f)
	
	drop in 4
	
	gen sector = "Rural" in 1 
	replace sector = "Urban" in 2
	replace sector = "National" in 3
	
	order sector
	drop year1 year2 year3
	
	export excel using "${user}/output/excel/tables.xlsx", firstrow(variables) sheet("Table 18", modify) cell(A22) keepcellfmt 

	/*==============================================================================
										*ANNEXES
	==============================================================================*/
	
	/*==============================================================================
		*Table A.2.1. New items added in 2022-23/split from 2011-12 (share of MPCE and incidence)
	==============================================================================*/

	use "${user}/data/processed/ces/master_consumption_2022.dta", clear
	
	gen new_item = inlist(item, 3, 4, 5, 6, 7, 76, 13, 12, 14, 15, 263, 11, 30, 31, 32, 33, 34, 36, 37, 432, 97, 43, 44, 45, 46, 47, 48, 50, 40, 41, 42, 35, 27, 465, 23, 158, 178, 188, 61, 62, 70, 71, 72, 73, 74, 75)
 	keep if new_item==1
	
	keep hhid item value_total_30d 
	replace value_total_30d = 0 if inlist(item, 61, 62, 70, 71, 72, 73, 74, 75) //Do this to count these as purchases
	fastreshape wide value_total_30d, i(hhid) j(item)
		
	collapse (mean) value_total_30d*, by(hhid)
	merge 1:1 hhid using "${user}/data/processed/ces/mpce_2022", keepusing(mpce_nom pwt) 
	
	local numlist 3 4 5 6 7 76 13 12 14 15 263 11 30 31 32 33 34 36 37 432 97 43 44 45 46 47 48 50 40 41 42 35 27 465 23 158 178 188 61 62 70 71 72 73 74 75	
	foreach i of local numlist {		
		gen hh_purchased`i' = value_total_30d`i'!=.
	}
	
	drop _m
	
	merge 1:1 hhid using "${user}/data/processed/ces/master_hh_2022", keepusing(hhsize year) keep(3) nogen
	
	foreach i of local numlist {		
		gen mpce_`i' = value_total_30d`i'/hhsize
		replace mpce_`i' = 0 if missing(mpce_`i')
		gen sh_mpce`i' = mpce_`i'/mpce_nom
	}
	
	preserve
	keep hhid pwt hh_purchased*
	fastreshape long hh_purchased, i(hhid) j(item)
	collapse (mean) hh_purchased [aw=pwt], by(item)
	tempfile hh_purchased
	save `hh_purchased'
	restore
	
	preserve
	keep hhid pwt sh_mpce*
	fastreshape long sh_mpce, i(hhid) j(item)
	collapse (mean) sh_mpce [aw=pwt], by(item)
	tempfile sh_mpce
	save `sh_mpce'
	restore
	
	use `hh_purchased', clear
	merge 1:1 item using `sh_mpce', keepusing(sh_mpce) keep(3) nogen
	
	replace hh_purchased = hh_purchased*100
	replace sh_mpce = sh_mpce*100
	
	format hh_purchased sh_mpce %9.1f
	
	merge 1:1 item using "${user}/data/processed/ces/master_item_list_2022", keepusing(item_desc) keep(3) nogen
	gen year = 2022
	order item_desc item year
	
	tostring hh_purchased, gen(hh_purchase) force format(%9.1f)
	tostring sh_mpce, gen(mpce_sh) force format(%9.1f)
	drop hh_purchased sh_mpce
	
	export excel "${user}/output/excel/tables.xlsx", firstrow(variables) sheet("Table A.2.1", modify) cell(A2) 
	putexcel set "${user}/output/excel/tables.xlsx", sheet("Table A.2.1") modify
	putexcel A1=("(a) New items introduced in CES 2022-23 or split of items from those in 2011-12")
	
	/*==============================================================================
		*Table A.2.1. Items removed from 2011-12 (share of MPCE and incidence)
	==============================================================================*/

	use "${user}/data/processed/ces/master_consumption_2011.dta", clear
		
	gen old_item = inlist(item, 506, 511, 330)
	keep if old_item==1
		
	keep hhid item value_total_30d 
	reshape wide value_total_30d, i(hhid) j(item)
		
	collapse (mean) value_total_30d*, by(hhid)
	merge 1:1 hhid using "${user}/data/processed/ces/mpce_2011", keepusing(mpce_nom pwt) 
	
	foreach i of numlist 506 511 330 {		
		gen hh_purchased`i' = value_total_30d`i'!=.
	}
	
	drop _m
	merge 1:1 hhid using "${user}/data/processed/ces/master_hh_2011", keepusing(hhsize year) keep(3) nogen
	
	foreach i of numlist 506 511 330 {		
		gen mpce_`i' = value_total_30d`i'/hhsize
		replace mpce_`i' = 0 if missing(mpce_`i')
		gen sh_mpce`i' = mpce_`i'/mpce_nom
	}
	
	reshape long hh_purchased sh_mpce, i(hhid) j(item)
	collapse (mean) hh_purchased sh_mpce [aw=pwt], by(item)
	
	replace hh_purchased = hh_purchased*100
	replace sh_mpce = sh_mpce*100
	
	format hh_purchased sh_mpce %9.1f
	
	merge 1:1 item using "${user}/data/processed/ces/master_item_list_2011", keepusing(item_desc) keep(3) nogen
	gen year = 2011
	order item_desc item year
	
	tostring hh_purchased, gen(hh_purchase) force format(%9.1f)
	tostring sh_mpce, gen(mpce_sh) force format(%9.1f)
	drop hh_purchased sh_mpce
	
	export excel "${user}/output/excel/tables.xlsx", firstrow(variables) sheet("Table A.2.1", modify) cell(A50) 
	putexcel set "${user}/output/excel/tables.xlsx", sheet("Table A.2.1") modify
	putexcel A49=("(b) Items in 2011-12 CES that are removed from 2022-23 CES")
				
	/*==============================================================================
		*Table A.7.1 - A.7.4: Transition of individuals between deciles after adjustments
	==============================================================================*/

		
		foreach i of numlist 2011 2022  {
			foreach s of numlist 1 2 {	
				use "${user}/data/processed/ces/welfare_agg_17.dta", clear	
				xtile deciles_base = welfare_agg17_sp if year==`i' & sector==`s' [aw=pwt], nq(10)	
				keep hhid deciles_base pwt
				drop if deciles_base==.
				tempfile baseline
				save `baseline', replace
			
				use "${user}/data/processed/ces/welfare_agg_17_all.dta", clear	
				xtile deciles_final = welfare_agg17_sp if year==`i' & sector==`s' [aw=pwt], nq(10)	
				keep hhid deciles_final pwt
				drop if deciles_final==.
				tempfile final
				save `final', replace
				
				use `baseline', clear
				merge 1:1 hhid using `final', keep(3) nogen
				table deciles_base deciles_final [aw=pwt], stat(percent) nformat(%9.1f) sformat("%s%%") notot
				collect export "${user}/output/excel/tables.xlsx", sheet("A.7.1_`i'_`s'", replace) cell(A1) modify
			}
		}
	
	* =============================================================================*
		di in red "THE END OF 08_tables" 
	* =============================================================================*
	cap log close
	exit	
