
	loc date: display %tdCCYY-NN-DD =daily("`c(current_date)'", "DMY")
	cap log close
	log using "${user}/output/log/09_figures_`date'", replace

	/* =============================================================================
			Project			: India poverty estimates - 2011-12 & 2022-23 
			Dofile			: 08_tables.do
			Last modified	: 27th March 2025
			Inputs			: "${user}/data/raw/ces"											
			Outputs			: "${user}/output/excel/tables.xlsx
							  "${user}/output/excel/figures/2a.png
							  "${user}/output/excel/figures/2b.png
							  "${user}/output/excel/figures/3a.png
							  "${user}/output/excel/figures/3b.png
							  "${user}/output/excel/figures/5a.png
							  "${user}/output/excel/figures/5b.png					  
			File purpose	: Codes for creating tables in the methodological note
	==============================================================================*/

		glo cpi_2011 = 113.606952605421    //avg monthly cpi survey year (Jul-11 to June-12) IFS
		glo cpi_2017 = 159.181198120117    //avg monthly cpi calendar year (jan-17 to dec-17)  IFS
		glo cpi_2022 =  211.9832504895     //avg monthly cpi survey year (Aug-22 to July-23) IFS
			
	/*==============================================================================
		*FIGURE 2A: Share of imputed free and subsidized items in nominal exp by deciles
					2011-12
	==============================================================================*/

	*Start with nominal consumption data
	use "${user}/data/processed/ces/master_consumption_2011_all.dta", clear
	keep if pds_imputed_valid==1 
		
 	fastreshape wide value_total_all, i(hhid) j(item)
 	merge m:1 hhid using "${user}/data/processed/ces/master_hh_2011.dta", nogen	
 	reshape long value_total_all, i(hhid) j(item)
	replace value_total_all = 0 if missing(value_total_all)
	
	merge m:1 item using "${user}/data/processed/ces/master_item_list_2011.dta", keepusing(recall_period subtotal survey_type) keep(3) nogen
	merge m:1 hhid using "${user}/data/processed/ces/master_hh_2011.dta", keepusing(state sector district hhwt hhsize pwt) keep(3) nogen	
	
	*Convert to 30 day recall
	gen value_total_30d = value_total_all
	replace value_total_30d = value_total_all*30/7 if recall_period==7 //no edible oil in 2011
	
	*Total expenditure on items dropped for each household by groups
	bys hhid : egen value_food = total(value_total_30d) 

	*Collapse expenditure at household level
	collapse (mean) value_food  (mean) pwt hhsize, by(hhid state sector)
	
	*Convert household expenditure to MPCE			
	gen mpce_food_imp = value_food/hhsize

	*Merge with nominal MPCE data at housheold level
	keep hhid mpce_* pwt state sector
	merge 1:1 hhid using "${user}/data/processed/ces/mpce_2011", keepusing(mpce_nom) keep(3) nogen	
	tostring hhid, replace

	*Create deciles and ventiles
	xtile deciles = mpce_nom [aw=pwt], nq(10)

	*Create share 		
	gen sh_food = mpce_food_imp/mpce_nom
	
	*Export average shares
	table deciles [aw=pwt], stat(mean sh_food)
	
	*Collapse dataset at deciles level and create bar graph 
	collapse (mean) sh_food [aw=pwt], by(deciles)	
	gen food_perc = sh_food*100 

	*Graph and export
	graph bar food_perc, over(deciles) bar(1, bcolor(maroon) lcolor(maroon)) blabel(bar, size(small) color(black) format(%9.1f)) legend(label(1 "Food and Kerosene") pos(12)) yscale(off) ///
    title(" Share of imputed free and subsidized items in nominal exp - 2011-12", size(medium)) 
	graph export "${user}/output/figures/2a.png", as(png) replace
	
	/*==============================================================================
	*FIGURE 2B: Share of imputed free and subsidized items in nominal exp by deciles
				2022-23
	==============================================================================*/
	use "${user}/data/processed/ces/master_consumption_2022_all.dta", clear
	
	keep if pds_imputed_valid==1 
	
 	fastreshape wide value_total_all, i(hhid) j(item)
 	merge m:1 hhid using "${user}/data/processed/ces/master_hh_2022.dta", nogen	
 	reshape long value_total_all, i(hhid) j(item)
	replace value_total_all = 0 if missing(value_total_all)
	
	merge m:1 item using "${user}/data/processed/ces/master_item_list_2022.dta", keepusing(recall_period subtotal agg_item survey_type) keep(3) nogen
	merge m:1 hhid using "${user}/data/processed/ces/master_hh_2022.dta", keepusing(state sector district hhwt hhsize pwt) keep(3) nogen	
	
	*Convert to 30 day recall
	gen value_total_30d = value_total_all
	replace value_total_30d = value_total_all*30/7 if recall_period==7 //edible oil
	
	*Total expenditure on items dropped for each household by groups
	bys hhid : egen value_food = total(value_total_30d) 
	
	*Adjust household size and convert expenditure to monthly 
	preserve
		use "${user}/data/processed/ces/level15_2022.dta", clear
		keep hhid hhsize section_new hhwt
		fre section_new

		drop if section_new==1 //dropping HCQ

		reshape wide hhsize, i(hhid) j(section_new)
		lab var hhsize2 "HHsize from FDQ"
		lab var hhsize3 "HHsize from CSQ"
		lab var hhsize4 "HHsize from DGQ"
		
		tempfile hhsize_adjust
		save `hhsize_adjust'
	restore
	merge m:1 hhid using `hhsize_adjust', keep(3) nogen
	
	gen value_adj_food = value_food
	replace value_adj_food = value_food*hhsize2/hhsize3 if survey_type==2
			
	*Collapse expenditure at household level
	collapse (mean) value_adj_food  (mean) pwt hhsize, by(hhid state sector)
	
	*Save tempfile for food and kerosene imputations
	tempfile food_imp
	save `food_imp', replace
	
	*Non-food imputations	

	use  "${user}/data/processed/ces/master_consumption_2022_all.dta", clear
	
	keep if nf_imputed_valid==1 
		
 	fastreshape wide value_total_all, i(hhid) j(item)
 	merge m:1 hhid using  "${user}/data/processed/ces/master_hh_2022.dta", nogen	
 	reshape long value_total_all, i(hhid) j(item)
	replace value_total_all = 0 if missing(value_total_all)
	
	merge m:1 item using  "${user}/data/processed/ces/master_item_list_2022.dta", keepusing(recall_period subtotal agg_item survey_type) keep(3) nogen
	merge m:1 hhid using "${user}/data/processed/ces/master_hh_2022.dta", keepusing(state sector district hhwt hhsize pwt) keep(3) nogen	
	
	*Convert to 30 day recall
	gen value_total_30d = value_total_all
	replace value_total_30d = value_total_all*30/365 if recall_period==365 
	
	*Total expenditure on items dropped for each household by groups
	bys hhid : egen value_nf = total(value_total_30d) 

	*Adjust household size and convert expenditure to monthly 
	preserve
		use  "${user}/data/processed/ces/level15_2022.dta", clear
		keep hhid hhsize section_new hhwt
		fre section_new

		drop if section_new==1 //dropping HCQ

		reshape wide hhsize, i(hhid) j(section_new)
		lab var hhsize2 "HHsize from FDQ"
		lab var hhsize3 "HHsize from CSQ"
		lab var hhsize4 "HHsize from DGQ"
		
		tempfile hhsize_adjust
		save `hhsize_adjust'
	restore
	merge m:1 hhid using `hhsize_adjust', keep(3) nogen
	
	gen value_adj_nf = value_nf
	replace value_adj_nf = value_nf*hhsize2/hhsize4 if survey_type==3
		
	*Collapse expenditure at household level
	collapse (mean) value_adj_nf  (mean) pwt hhsize, by(hhid state sector)
	
	*Merge with food_imp
	merge 1:1 hhid using `food_imp', keepusing(value_adj_food) keep(3) nogen

	*Convert household expenditure to MPCE			
	gen mpce_food_imp = value_adj_food/hhsize
	gen mpce_nf_imp = value_adj_nf/hhsize

	*Merge with nominal MPCE data at housheold level
	keep hhid mpce_* pwt state sector	
	merge 1:1 hhid using "${user}/data/processed/ces/mpce_2022", keepusing(mpce_nom) keep(3) nogen	

	*Create deciles 
	xtile deciles = mpce_nom [aw=pwt], nq(10)

	*Create share 		
	gen sh_food = mpce_food_imp/mpce_nom
	gen sh_nf = mpce_nf_imp/mpce_nom

	*Export average shares
	table deciles [aw=pwt], stat(mean sh_food) stat(mean sh_nf)

	*Collapse dataset at deciles level and create bar graph 
	collapse (mean) sh_food sh_nf [aw=pwt], by(deciles)
	
	gen food_perc = sh_food*100 
	gen nf_perc = sh_nf*100 

	*Graph and export
	graph bar food_perc nf_perc , over(deciles) bar(1, bcolor(maroon) lcolor(maroon)) bar(2, bcolor(emerald) lcolor(emerald)) blabel(bar, size(small) color(black) format(%9.1f)) legend(label(1 "Food and Kerosene") label(2 "School uniform and shoes") pos(12) cols(2)) yscale(off) ///
    title(" Share of imputed free and subsidized items in nominal exp - 2022-23", size(medium)) 
	
	graph export "${user}/output/figures/2b.png", as(png) replace
	
	/*==============================================================================
	*FIGURE 3A: Share of items dropped in nominal expenditure - 2011-12
	==============================================================================*/

	*Start with nominal consumption data

	use  "${user}/data/processed/ces/master_consumption_2011.dta", clear
	
	keep if inlist(item, 520, 640, 641, 642, 560, 561, 562, 563, 565, 566, 567, 568, 550, 551, 552, 553, 554, 555, 556, 557, 558, 600, 601, 602, 603, 604, 605, 606, 607, 608, 621, 622, 623, 624, 626, 627, 628, 620, 580, 581, 582, 583, 584, 585, 586, 587, 588, 590, 591, 592, 541, 410, 411, 412, 413, 414, 415, 416, 417, 418)
	
 	fastreshape wide value_total_30d, i(hhid) j(item)
 	merge m:1 hhid using  "${user}/data/processed/ces/master_hh_2011.dta", nogen	
 	reshape long value_total_30d, i(hhid) j(item)
	replace value_total_30d = 0 if missing(value_total_30d)
	
	merge m:1 item using  "${user}/data/processed/ces/master_item_list_2011.dta", keepusing(recall_period subtotal) keep(3) nogen
	merge m:1 hhid using  "${user}/data/processed/ces/master_hh_2011.dta", keepusing(state sector district hhwt hhsize pwt) keep(3) nogen	
	
	*Dummies for durables, jewelry, funniture, and hospital expenses
	gen durables = inlist(item, 560, 561, 562, 563, 565, 566, 567, 568, 580, 581, 582, 583, 584, 585, 586, 587, 588, 590, 591, 592, 600, 601, 602, 603, 604, 605, 606, 607, 608, 621, 623, 624, 626, 627, 628)
	gen jewelry = inlist(item, 640, 641)
	gen furniture = inrange(item, 550, 558)
	gen hosp = inrange(item, 410, 418)
	gen rent = item==520
	gen taxes = item==541
	
	*Total expenditure on items dropped for each household by groups
	bys hhid : egen value_durables = total(value_total_30d) if durables==1
	bys hhid : egen value_jewelry = total(value_total_30d) if jewelry==1
	bys hhid : egen value_furniture = total(value_total_30d) if furniture==1
	bys hhid : egen value_hosp = total(value_total_30d) if hosp==1
	bys hhid : egen value_rent = total(value_total_30d) if rent==1
	bys hhid : egen value_taxes = total(value_total_30d) if taxes==1
	
	*Collapse expenditure at household level
	collapse (mean) value_durables value_jewelry value_furniture value_hosp value_rent value_taxes (mean) pwt hhsize, by(hhid state sector)
	
	*Convert household expenditure to MPCE
	local exp durables jewelry furniture hosp rent taxes
	foreach var of local exp {			
	gen mpce_`var' = value_`var'/hhsize
	}

	*Merge with nominal MPCE data at housheold level
	keep hhid mpce_* pwt state sector
	merge 1:1 hhid using "${user}/data/processed/ces/mpce_2011", keepusing(mpce_nom) keep(3) nogen	
	tostring hhid, replace

	*Create deciles and ventiles
	xtile deciles = mpce_nom [aw=pwt], nq(10)

	*Create share 
	local exp durables jewelry furniture hosp rent taxes
	foreach var of local exp {			
	gen sh_`var' = mpce_`var'/mpce_nom
	}	
	
	*Export average expenditure 
	table deciles [aw=pwt], stat(mean sh_*)
	
	*Collapse dataset at deciles level and create stacked bar graph 
	collapse (mean) sh_* [aw=pwt], by(deciles)
	
	gen durables_perc = sh_durables*100
	gen jewelry_perc = sh_jewelry*100
	gen furniture_perc = sh_furniture*100
	gen hosp_perc = sh_hosp*100
	gen rent_perc = sh_rent*100
	gen taxes_perc = sh_taxes*100
	
	graph bar durables_perc jewelry_perc furniture_perc hosp_perc rent_perc taxes_perc, over(decile) ///
    bar(1, bcolor(maroon)) bar(2, bcolor(gold)) bar(3, bcolor(green)) ///
    bar(4, bcolor(navy)) bar(5, bcolor(cranberry)) bar(6, bcolor(orange)) ///
    stack ///
    blabel(bar, size(vsmall) color(black) format(%9.1f) pos(center)) ///
    title("Share of items dropped in nominal expenditure - 2011-12", size(medium)) ///
	legend(label(1 "Durables") label(2 "Jewelry + Wrist watches") label(3 "Furniture") ///
    label(4 "Hospitalisation") label(5 "Rent") label(6 "Taxes") pos(12) cols(6)) yscale(off)
	
	graph export "${user}/output/figures/3a.png", as(png) replace
	
	/*==============================================================================
	*FIGURE 3B: Share of items dropped in nominal expenditure - 2022-23
	==============================================================================*/	
	*Start with nominal consumption data

	use "${user}/data/processed/ces/master_consumption_2022.dta", clear
	
	keep if inlist(item, 43, 44, 45, 46, 47, 48, 560, 561, 562, 563, 565, 566, 567, 568, 580, 581, 582, 583, 584, 585, 586, 587, 588, 590, 591, 592, 600, 601, 602, 603, 604, 605, 606, 607, 608, 621, 623, 624, 626, 627, 628, 640, 641, 550, 558, 410, 418, 520, 899)
	
 	fastreshape wide value_total_30d, i(hhid) j(item)
 	merge m:1 hhid using "${user}/data/processed/ces/master_hh_2022.dta", nogen	
 	reshape long value_total_30d, i(hhid) j(item)
	replace value_total_30d = 0 if missing(value_total_30d)
	
	merge m:1 item using "${user}/data/processed/ces/master_item_list_2022.dta", keepusing(recall_period subtotal agg_item survey_type) keep(3) nogen
	merge m:1 hhid using "${user}/data/processed/ces/master_hh_2022.dta", keepusing(state sector district hhwt hhsize pwt) keep(3) nogen	
	
	*Dummies for durables, jewelry, funniture, and hospital expenses
	gen durables = inlist(item, 43, 44, 45, 46, 47, 48, 560, 561, 562, 563, 565, 566, 567, 568, 580, 581, 582, 583, 584, 585, 586, 587, 588, 590, 591, 592, 600, 601, 602, 603, 604, 605, 606, 607, 608, 621, 623, 624, 626, 627, 628)
	gen jewelry = inlist(item, 640, 641)
	gen furniture = inrange(item, 550, 558)
	gen hosp = inrange(item, 410, 418)
	gen rent = item==520
	gen taxes = item==899
	
	*Total expenditure on items dropped for each household by groups
	bys hhid : egen value_durables = total(value_total_30d) if durables==1
	bys hhid : egen value_jewelry = total(value_total_30d) if jewelry==1
	bys hhid : egen value_furniture = total(value_total_30d) if furniture==1
	bys hhid : egen value_hosp = total(value_total_30d) if hosp==1
	bys hhid : egen value_rent = total(value_total_30d) if rent==1
	bys hhid : egen value_taxes = total(value_total_30d) if taxes==1

	*Adjust household size and convert expenditure to monthly 
	preserve
		use "${user}/data/processed/ces/level15_2022.dta", clear
		keep hhid hhsize section_new hhwt
		fre section_new

		drop if section_new==1 //dropping HCQ

		reshape wide hhsize, i(hhid) j(section_new)
		lab var hhsize2 "HHsize from FDQ"
		lab var hhsize3 "HHsize from CSQ"
		lab var hhsize4 "HHsize from DGQ"
		
		tempfile hhsize_adjust
		save `hhsize_adjust'
	restore
	merge m:1 hhid using `hhsize_adjust', keep(3) nogen
	
	local exp durables jewelry furniture hosp rent taxes
	foreach var of local exp {		
	gen value_adj_`var' = value_`var'*hhsize2/hhsize4 if survey_type==3
	replace value_adj_`var' = value_`var'*hhsize2/hhsize3 if survey_type==2
	}
	
	
	*Collapse expenditure at household level
	collapse (mean) value_adj_durables value_adj_jewelry value_adj_furniture value_adj_hosp value_adj_rent value_adj_taxes (mean) pwt hhsize, by(hhid state sector)
	
	*Convert household expenditure to MPCE
	local exp durables jewelry furniture hosp rent taxes
	foreach var of local exp {			
	gen mpce_`var' = value_adj_`var'/hhsize
	}

	*Merge with nominal MPCE data at housheold level
	keep hhid mpce_* pwt state sector
	merge 1:1 hhid using "${user}/data/processed/ces/mpce_2022", keepusing(mpce_nom) keep(3) nogen	

	*Create deciles and ventiles
	xtile deciles = mpce_nom [aw=pwt], nq(10)

	*Create share 
	local exp durables jewelry furniture hosp rent taxes
	foreach var of local exp {			
	gen sh_`var' = mpce_`var'/mpce_nom
	}	
	
	*Tabulate average shares
	table deciles [aw=pwt], stat(mean sh_*)

	*Collapse dataset at deciles level and create stacked bar graph 
	collapse (mean) sh_* [aw=pwt], by(deciles)
	
	gen durables_perc = sh_durables*100
	gen jewelry_perc = sh_jewelry*100
	gen furniture_perc = sh_furniture*100
	gen hosp_perc = sh_hosp*100
	gen rent_perc = sh_rent*100
	gen taxes_perc = sh_taxes*100
	
	graph bar durables_perc jewelry_perc furniture_perc hosp_perc rent_perc taxes_perc, over(decile) ///
    bar(1, bcolor(maroon)) bar(2, bcolor(gold)) bar(3, bcolor(green)) ///
    bar(4, bcolor(navy)) bar(5, bcolor(cranberry)) bar(6, bcolor(orange)) ///
    stack ///
    blabel(bar, size(vsmall) color(black) format(%9.1f) pos(center)) ///
    title("Share of items dropped in nominal expenditure - 2022-23", size(medium)) ///
	legend(label(1 "Durables") label(2 "Jewelry + Wrist watches") label(3 "Furniture") ///
    label(4 "Hospitalisation") label(5 "Rent") label(6 "Taxes") pos(12) cols(6)) yscale(off)
	
	graph export "${user}/output/figures/3b.png", as(png) replace

				
	/*==============================================================================
		*Figure 5 - Data preparation - 2011-12 
	==============================================================================*/

	use "${user}/data/processed/ces/master_consumption_wy_2011_all.dta", clear
	merge m:1 hhid using "${user}/data/processed/ces/master_hh_2011.dta", keepusing(hhsize state sector district pwt)
	drop _m
	merge m:1 item  using "${user}/data/processed/ces/master_item_list_2011.dta", keepusing(subtotal commodity_group recall_period )
	drop _m
		
	* Drop subtotals
	drop if subtotal==1 
	
	*merge m:1 item using "${other_data}/dta/item_list_2011.dta", keepusing(recall_period commodity_group) keep(3) nogen
	*merge m:1 hhid using "${data_cons}/master_hh_2011.dta", keepusing(state sector district hhsize pwt) keep(3) nogen	
	
	*Step 2. Ajust consumption value to 30days.
	g double value_adj${s} 			= value_total${s} 			if recall_period==30
		replace value_adj${s} 		= value_total${s}*(30/7) 	if recall_period==7
		replace value_adj${s} 		= value_total${s}*(30/365) 	if recall_period==365
	
	g double value_def_adj${s} 		= value_deflated${s} 		if recall_period==30
		replace value_def_adj${s} 	= value_deflated${s}*(30/7) 	if recall_period==7
		replace value_def_adj${s} 	= value_deflated${s}*(30/365) 	if recall_period==365

	*Step 3. Collapse from item level to commodity group level.
	collapse (sum) value_adj${s} value_def_adj${s} (mean) pwt hhsize, by(hhid state sector district commodity_group)
	
	*Step 4. Reshape to create balanced panel. Each HH should have 25 commodity groups.
	fastreshape wide value_adj${s} value_def_adj${s}, i(hhid) j(commodity_group)
	fastreshape long value_adj${s} value_def_adj${s}, i(hhid) j(commodity_group)
	
	*Step 5. Expenditures at CG level. Calculate nominal and temporally deflated MPCE. Check whether nominal MPCE matches report.
	g double exp_nom 	= value_adj${s}/hhsize
	g double exp_wy_def = value_def_adj${s}/hhsize	
		bys hhid : egen double mpce_nom = total(exp_nom)		// MPCE #1 
		bys hhid : egen double mpce_wy_def = total(exp_wy_def)	// MPCE #2
	
	lab var mpce_nom 			"MPCE - nominal"
	lab var mpce_wy_def 		"MPCE - inter-temporally deflated"

	*Step 6. Calculate share of other commodity groups (except 15 CGs) in nominal expenditure. 
	g sp_dum = inrange(commodity_group, 1, 15)
		lab var sp_dum 			"Indicator for CG in spatial deflators"
	bys hhid : egen double exp_other = total(exp_nom) if sp_dum==0
	g double sh_other = exp_other/mpce_nom
		lab var sh_other 		"Expenditure share of remaining commodity groups"
		
	*Step 7.  Merge to get spatial deflators and normalise to 1 at HH level. 

	merge m:1 state sector commodity_group using "${user}/data/processed/ces/2011_spatial_deflators.dta", keepusing(sp_def_sec_2011 sp_def_ind_2011) nogen
	
	* deflate at CG level
	g double exp_def_temp_sec = exp_wy_def/sp_def_sec_2011		
	g double exp_def_temp_ind = exp_wy_def/sp_def_ind_2011

	bys hhid : egen double cg15_agg_wy_def = total(exp_wy_def) if sp_dum==1
		lab var cg15_agg_wy_def "Agg for 15CG - inter-temporally deflated"

	bys hhid: egen double cg15_sp_def_sec = total(exp_def_temp_sec) if sp_dum==1
	bys hhid: egen double cg15_sp_def_ind = total(exp_def_temp_ind) if sp_dum==1
	 
	g double implicit_sp_def_sec 		= cg15_agg_wy_def/cg15_sp_def_sec
	g double implicit_sp_def_ind 		= cg15_agg_wy_def/cg15_sp_def_ind
	bys sector: egen double sp_def_sec	= wmean(implicit_sp_def_sec), weights(pwt)
	g double sp_rel_sec 				= implicit_sp_def_sec/sp_def_sec
	
	tabstat sp_rel_sec [aw=pwt], by(sector) //check should add to 1
	
	lab var implicit_sp_def_sec "Spatial deflator at sector (unadj)"
	lab var sp_rel_sec 			"Spatial deflator relative to sector"
	
	egen double sp_def_ind 	= wmean(implicit_sp_def_ind), weights(pwt)
	g double sp_rel_ind 	= implicit_sp_def_ind/sp_def_ind
	
	tabstat sp_rel_ind [aw=pwt] //check should add to 1
	
	lab var implicit_sp_def_ind "Spatial deflator at India (unadj)"
	lab var sp_rel_ind 			"Spatial deflator relative to India"
	
	g double exp_sp_15_sec 					= exp_wy_def/sp_rel_sec	if sp_dum==1
	g double exp_sp_15_ind 					= exp_wy_def/sp_rel_ind	if sp_dum==1
	bys hhid : egen double mpce_sp_15_sec 	= total(exp_sp_15_sec)
	bys hhid : egen double mpce_sp_15_ind 	= total(exp_sp_15_ind)
	
	lab var mpce_sp_15_sec "MPCE - spatially adjusted for 15 commodity groups - All India-Sector base"
	lab var mpce_sp_15_ind "MPCE - spatially adjusted for 15 commodity groups - All India base"
			
	*Step 8. Adjust constructed MPCE (step 7) to add back the share of other commodity groups. 
	g double mpce_sp_def_sec = mpce_sp_15_sec / (1-sh_other)		// MPCE # 3
	g double mpce_sp_def_ind = mpce_sp_15_ind / (1-sh_other)		// MPCE # 4

	lab var mpce_sp_def_sec "MPCE - spatially adjusted - AllIndia-Sector base"
	lab var mpce_sp_def_ind "MPCE - spatially adjusted - allIndia base"
		
	*Step 9. Gen food and non-food
	bys hhid : egen mpce_food = total(exp_sp_15_ind) if inrange(commodity_group, 1, 11)
	
	*Step 10. Collapse at hh level
	collapse (mean) mpce_food mpce_sp_def_ind pwt, by(hhid state sector)
	gen real_wa = mpce_sp_def_ind*(${cpi_2017}/${cpi_2011})
	gen real_wa_food = mpce_food*(${cpi_2017}/${cpi_2011})
	gen real_wa_nf = real_wa - real_wa_food
	
	gen sh_nf = real_wa_nf/real_wa
	xtile deciles_rural = real_wa if sector==1 [aw=pwt], nq(10)
	xtile deciles_urban = real_wa if sector==2 [aw=pwt], nq(10)

	*Collapse deciles and save tempfile
	table deciles_rural [aw=pwt], stat(mean sh_nf)
	table deciles_urban [aw=pwt], stat(mean sh_nf)
	
	preserve
	collapse (mean) sh_nf [aw=pwt], by(deciles_rural)
	rename sh_nf sh_nf_2011
	tempfile sh_nf_2011_r
	save `sh_nf_2011_r'
	restore
	
	preserve
	collapse (mean) sh_nf [aw=pwt], by(deciles_urban)
	rename sh_nf sh_nf_2011
	tempfile sh_nf_2011_u
	save `sh_nf_2011_u'
	restore
	
	/*==============================================================================
		*Figure 5 - Data preparation - 2022-23
	==============================================================================*/

	* Step 1. From master_consumption. Drop subtotals, merge master_hh & item_list to retrieve vars.
	use "${user}/data/processed/ces/master_consumption_wy_2022_all.dta", clear
	merge m:1 hhid using "${user}/data/processed/ces/master_hh_2022.dta", keepusing(pwt state sector stratum district)
	drop _m
	merge m:1 item  using "${user}/data/processed/ces/master_item_list_2022.dta", keepusing(subtotal sub_grains commodity_group survey_type recall_period agg_item)
	drop _m
	
	
	* Drop subtotals
	drop if subtotal==1  | sub_grains ==1
	drop if agg_item==1
	
	* Specific complexity in 2022 with multiple hhsizes (for each questionaire)
		preserve
		use "${user}/data/processed/ces/level15_2022.dta", clear
			keep hhid hhsize section_new hhwt
			fre section_new
			drop if section_new==1 //dropping HCQ
		reshape wide hhsize, i(hhid) j(section_new)
		la var hhsize2 "HHsize from FDQ"
		la var hhsize3 "HHsize from CSQ"
		la var hhsize4 "HHsize from DGQ"
			
		tempfile hhsize_adjust
		save `hhsize_adjust'
		restore
	
		merge m:1 hhid using `hhsize_adjust', keep(3) nogen
		
		g double value_adj1 	= value_total${s} 		if survey_type==1 
			replace value_adj1 	= value_total${s} *(hhsize2/hhsize3) if survey_type==2
			replace value_adj1 	= value_total${s} *(hhsize2/hhsize4) if survey_type==3
		
		g double value_def1 	= value_deflated${s} if survey_type==1  
			replace value_def1 	= value_deflated${s} *(hhsize2/hhsize3) if survey_type==2 
			replace value_def1 	= value_deflated${s} *(hhsize2/hhsize4) if survey_type==3
		
	*Step 2. Ajust consumption value to 30days.
	g double value_adj 		= value_adj1 			if recall_period==30
		replace value_adj 	= value_adj1*(30/7)	 	if recall_period==7
		replace value_adj 	= value_adj1*(30/365) 	if recall_period==365
	
	g double value_def_adj 		= value_def1 			if recall_period==30
		replace value_def_adj 	= value_def1*(30/7) 	if recall_period==7
		replace value_def_adj 	= value_def1*(30/365) 	if recall_period==365
	
		drop value_adj1 value_def1 hhsize3 hhsize4 
		
		ren hhsize2 hhsize

	*Step 3. Collapse from item level to commodity group level.
	collapse (sum) value_adj value_def_adj (mean) pwt hhsize, by(hhid state sector stratum commodity_group)
	
	*Step 4. Reshape to create balanced panel. Each HH should have 25 commodity groups.
	fastreshape wide value_adj value_def_adj , i(hhid) j(commodity_group)
	fastreshape long value_adj value_def_adj , i(hhid) j(commodity_group)
	
	*Step 5. Calculate nominal and temporally deflated MPCE. Check whether nominal MPCE matches report.
	g double exp_nom 	= value_adj/hhsize
	g double exp_wy_def = value_def_adj/hhsize
	
	bys hhid : egen double mpce_nom 	= total(exp_nom)			// MPCE #1
	bys hhid : egen double mpce_wy_def 	= total(exp_wy_def)		// MPCE #2
	
	la var mpce_nom 	"MPCE - nominal "
	la var mpce_wy_def 	"MPCE - inter-temporally deflated "
	
	*Step 6. Calculate share of other commodity groups (except 15 CGs) in nominal expenditure. 
	g sp_dum = inrange(commodity_group, 1, 15)
	lab var sp_dum "Indicator for CG in spatial deflators"
	
	bys hhid : egen double exp_other = total(exp_nom) if sp_dum==0
	g double sh_other = exp_other/mpce_nom
	lab var sh_other "Expenditure share of remaining commodity groups"
	
	*Step 7. Merge to get spatial deflators and normalise to 1 at HH level. 

	merge m:1 state sector commodity_group using "${user}/data/processed/ces/2022_spatial_deflators.dta", keepusing(sp_def_sec_2022 sp_def_ind_2022) nogen
	
	* Deflate at CG level
	g double exp_def_temp_sec = exp_wy_def/sp_def_sec_2022		
	g double exp_def_temp_ind = exp_wy_def/sp_def_ind_2022

	bys hhid : egen double cg15_agg_wy_def = total(exp_wy_def) if sp_dum==1
	lab var cg15_agg_wy_def 	"Agg for 15CG - inter-temporally deflated"
	bys hhid: egen double cg15_sp_def_sec = total(exp_def_temp_sec) if sp_dum==1
	bys hhid: egen double cg15_sp_def_ind = total(exp_def_temp_ind) if sp_dum==1
	 
	g double implicit_sp_def_sec = cg15_agg_wy_def/cg15_sp_def_sec
	g double implicit_sp_def_ind = cg15_agg_wy_def/cg15_sp_def_ind
	
	bys sector: egen double sp_def_sec= wmean(implicit_sp_def_sec), weights(pwt)
	g double sp_rel_sec = implicit_sp_def_sec/sp_def_sec
	
	tabstat sp_rel_sec [aw=pwt], by(sector) //check should add to 1
	
	lab var implicit_sp_def_sec 	"Spatial deflator at sector (unadj)"
	lab var sp_rel_sec 				"Spatial deflator relative to sector"
	
	egen double sp_def_ind = wmean(implicit_sp_def_ind), weights(pwt)
	g double  sp_rel_ind = implicit_sp_def_ind/sp_def_ind
	
	tabstat sp_rel_ind [aw=pwt] //check should add to 1
	
	lab var implicit_sp_def_ind 	"Spatial deflator at India (unadj)"
	lab var sp_rel_ind 				"Spatial deflator relative to India"
	
	g double exp_sp_15_sec = exp_wy_def/sp_rel_sec	if sp_dum==1
	g double exp_sp_15_ind = exp_wy_def/sp_rel_ind	if sp_dum==1
	bys hhid : egen double mpce_sp_15_sec = total(exp_sp_15_sec)
	bys hhid : egen double mpce_sp_15_ind = total(exp_sp_15_ind)
	
	lab var mpce_sp_15_sec "MPCE - spatially adjusted for 15 commodity groups - All India-Sector base "
	lab var mpce_sp_15_ind "MPCE - spatially adjusted for 15 commodity groups - All India base "
		
	*Step 8. Adjust constructed MPCE (step 7) to add back the share of other commodity groups. 
	g double mpce_sp_def_sec = mpce_sp_15_sec / (1-sh_other)
	g double mpce_sp_def_ind = mpce_sp_15_ind / (1-sh_other)
	la var mpce_sp_def_sec "MPCE - spatially adjusted - AllIndia-Sector base"	// MPCE #3
	la var mpce_sp_def_ind "MPCE - spatially adjusted - AllIndia base"			// MPE #4
			
	*Step 9. Gen food and non-food
	bys hhid : egen mpce_food = total(exp_sp_15_ind) if inrange(commodity_group, 1, 11)
	
	*Step 10. Collapse at hh level
	collapse (mean) mpce_food mpce_sp_def_ind pwt, by(hhid state sector stratum)
	gen real_wa = mpce_sp_def_ind*(${cpi_2017}/${cpi_2022})
	gen real_wa_food = mpce_food*(${cpi_2017}/${cpi_2022})
	gen real_wa_nf = real_wa - real_wa_food
	
	gen sh_nf = real_wa_nf/real_wa
	xtile deciles_rural = real_wa if sector==1 [aw=pwt], nq(10)
	xtile deciles_urban = real_wa if sector==2 [aw=pwt], nq(10)

	*Collapse deciles and save tempfile
	table deciles_rural [aw=pwt], stat(mean sh_nf)
	table deciles_urban [aw=pwt], stat(mean sh_nf)
		
	preserve
	collapse (mean) sh_nf [aw=pwt], by(deciles_rural)
	rename sh_nf sh_nf_2022
	tempfile sh_nf_2022_r
	save `sh_nf_2022_r'
	restore
	
	preserve
	collapse (mean) sh_nf [aw=pwt], by(deciles_urban)
	rename sh_nf sh_nf_2022
	tempfile sh_nf_2022_u
	save `sh_nf_2022_u'
	restore

	/*==============================================================================
	Figure 5A: Non-food share in real welfare aggregate by deciles - Rural
	==============================================================================*/

	use `sh_nf_2011_r', clear	
	merge 1:1 deciles_rural using `sh_nf_2022_r'
	
	gen sh_nf_2011_perc = sh_nf_2011*100
	gen sh_nf_2022_perc = sh_nf_2022*100
	
	graph bar sh_nf_2011_perc sh_nf_2022_perc , over(deciles) bar(1, bcolor(maroon) lcolor(maroon)) bar(2, bcolor(emerald) lcolor(emerald)) blabel(bar, size(small) color(black) format(%9.0f)) legend(label(1 "2011-12") label(2 "2022-23") pos(12) cols(2)) yscale(off) ///
    title("Non-food share in real welfare aggregate - Rural", size(medium)) 
	
	graph export "${user}/output/figures/5a.png", as(png) replace
	
	/*==============================================================================
	Figure 5B: Non-food share in real welfare aggregate by deciles - Urban
	==============================================================================*/

	use `sh_nf_2011_u', clear	
	merge 1:1 deciles_urban using `sh_nf_2022_u'
	
	gen sh_nf_2011_perc = sh_nf_2011*100
	gen sh_nf_2022_perc = sh_nf_2022*100
	
	graph bar sh_nf_2011_perc sh_nf_2022_perc , over(deciles) bar(1, bcolor(maroon) lcolor(maroon)) bar(2, bcolor(emerald) lcolor(emerald)) blabel(bar, size(small) color(black) format(%9.0f)) legend(label(1 "2011-12") label(2 "2022-23") pos(12) cols(2)) yscale(off) ///
    title("Non-food share in real welfare aggregate - Urban", size(medium)) 
	
	graph export "${user}/output/figures/5b.png", as(png) replace

	/*==============================================================================
	Figure 6A: Extreme poverty rates
	==============================================================================*/

	use "${user}/output/welfare_pov_final", clear
	
	preserve
	collapse (mean) poor_215_perc [aw=pwt], by(year sector)
	tempfile sector_215
	save `sector_215'
	restore
	
	preserve
	collapse (mean) poor_215_perc [aw=pwt], by(year)
	tempfile national_215
	save `national_215'
	restore
	
	use `sector_215', clear
	append using `national_215'
	label drop sector
	replace sector = 3 if missing(sector)
	
	label define sector ///
	1 "Rural" 2 "Urban" 3 "National"
	lab value sector "sector"
	
	reshape wide poor_215_perc, i(sector) j(year)	
	
	graph bar poor_215_perc2011 poor_215_perc2022, over(sector)  ///
	bar(1, bcolor(maroon) lcolor(maroon)) bar(2, bcolor(emerald) lcolor(emerald)) blabel(bar, size(small) color(black) format(%9.1f)) legend(label(1 "2011-12") label(2 "2022-23") pos(12) cols(2)) yscale(range(0 100)) ylabel(0(20)100)  ///
	title("Extreme poverty line ($2.15 per day, 2017PPP)", size(medium))
	
	graph export "${user}/output/figures/6a.png", as(png) replace
	
	/*==============================================================================
	Figure 6B: LMIC poverty rates
	==============================================================================*/

	use "${user}/output/welfare_pov_final", clear
	
	preserve
	collapse (mean) poor_365_perc [aw=pwt], by(year sector)
	tempfile sector_365
	save `sector_365'
	restore
	
	preserve
	collapse (mean) poor_365_perc [aw=pwt], by(year)
	tempfile national_365
	save `national_365'
	restore
	
	use `sector_365', clear
	append using `national_365'
	label drop sector
	replace sector = 3 if missing(sector)
	
	label define sector ///
	1 "Rural" 2 "Urban" 3 "National"
	lab value sector "sector"
	
	reshape wide poor_365_perc, i(sector) j(year)	
	
	graph bar poor_365_perc2011 poor_365_perc2022, over(sector)  ///
	bar(1, bcolor(maroon) lcolor(maroon)) bar(2, bcolor(emerald) lcolor(emerald)) blabel(bar, size(small) color(black) format(%9.1f)) legend(label(1 "2011-12") label(2 "2022-23") pos(12) cols(2)) yscale(range(0 100)) ylabel(0(20)100)  ///
	title("LMIC poverty line ($3.65 per day, 2017PPP)", size(medium))
	
	graph export "${user}/output/figures/6b.png", as(png) replace

	/*==============================================================================
		Figure 6C: UMIC poverty rates
	==============================================================================*/

	use "${user}/output/welfare_pov_final", clear
	
	preserve
	collapse (mean) poor_685_perc [aw=pwt], by(year sector)
	tempfile sector_685
	save `sector_685'
	restore
	
	preserve
	collapse (mean) poor_685_perc [aw=pwt], by(year)
	tempfile national_685
	save `national_685'
	restore
	
	use `sector_685', clear
	append using `national_685'
	label drop sector
	replace sector = 3 if missing(sector)
	
	label define sector ///
	1 "Rural" 2 "Urban" 3 "National"
	lab value sector "sector"
	
	reshape wide poor_685_perc, i(sector) j(year)	
	
	graph bar poor_685_perc2011 poor_685_perc2022, over(sector)  ///
	bar(1, bcolor(maroon) lcolor(maroon)) bar(2, bcolor(emerald) lcolor(emerald)) blabel(bar, size(small) color(black) format(%9.1f)) legend(label(1 "2011-12") label(2 "2022-23") pos(12) cols(2)) yscale(range(0 100)) ylabel(0(20)100) ///
	title("UMIC poverty line ($6.85 per day, 2017PPP)", size(medium))
	
	graph export "${user}/output/figures/6c.png", as(png) replace

	/*==============================================================================
		*Figure A.1.1: Share of urban population implied in CES survey weights vs. other sources
	==============================================================================*/
		
	import excel "${user}/data/raw/other/Population_Projections_WDI.xlsx", sheet("Sheet1") firstrow clear
	gen wdi_urban = WDIUrbanPopulation*100
	gen ces_urban = CES*100
	gen wdi_extra_urban = ExtrapolationonWDI*100
	gen moh_urban = MOH*100
	
	format wdi_urban wdi_extra_urban ces_urban moh_urban %9.1f
	
		twoway ///
		(line wdi_urban Year, lcolor(maroon) lwidth(medthick)) ///
		(line wdi_extra_urban Year, lcolor(maroon) lpattern(dash) lwidth(medthick)) ///
		(scatter ces_urban Year, msymbol(circle) mlabel(ces_urban) mlabpos(6) ///
		 msize(medium) mlabcolor(black) mcolor(emerald) mlabsize(2.7)) ///
		(scatter moh_urban Year, msymbol(triangle) mlabel(moh_urban) mlabpos(6) ///
		 msize(medium) mlabcolor(black) mcolor(navy) mlabsize(2.7)), ///
		xscale(range(2000 2022)) xlabel(2000(2)2022)   ///
		yscale(range(20 50)) ylabel(20(10)50) ///	 		
		legend(order(1 "WDI Urban Population" 2 "Extrapolation on WDI" 3 "CES" 4 "MOH") pos(12) cols(5)) ///
		title("Share of urban population implied in CES survey weights vs. other sources", size(med)) 
 		graph export "${user}/output/figures/A.1.1.png", as(png) replace
		
	

	/*==============================================================================
		*Figure A.7.1: Cummulative Density Functions
	==============================================================================*/	
		
	use "${user}/data/processed/ces/welfare_agg_17", clear
	
	gen log_nom = log(welfare_agg17_nom)
	gen log_sp_base = log(welfare_agg17_sp)
	
	append using "${user}/data/processed/ces/welfare_agg_17_all"
	gen log_sp = log(welfare_agg17_sp) if scenario=="{_all}"
	
	foreach i of numlist 2011 2022 {
		foreach s of numlist 1 2 {
			cumul log_nom if year==`i' & scenario=="{}" & sector==`s' [aw=pwt], gen(nom_base_`i'_`s') 
			cumul log_sp_base if year ==`i' & scenario=="{}" & sector==`s' [aw=pwt], gen(sp_base_`i'_`s') 
			cumul log_sp if year==`i' & scenario=="{_all}" & sector==`s' [aw=pwt], gen(sp_all_`i'_`s') 
		}
	}
	
		foreach i of numlist 2011 2022 {
			foreach s of numlist 1 2 {
			twoway (line nom_base_`i'_`s' log_nom if year==`i' & sector==`s' [aw=pwt], sort lwidth(0.3) lcolor(maroon)) ///
			(line sp_base_`i'_`s' log_sp_base if year==`i' & sector==`s' [aw=pwt], sort lwidth(0.3) lcolor(orange)) ///
			(line sp_all_`i'_`s' log_sp if year==`i' & sector==`s' [aw=pwt], sort lwidth(0.3) lcolor(navy)), ///
			legend(order(1 "Nominal expenditure" 2 "Real expenditure" 3 "Real welfare") pos(12) col(3)) ///
			xtitle("Log consumption aggregate in 2017 prices") ///
			ytitle("Cumulative frequency distribution") ///
			ylabel (0(0.1)1) ///
			xlabel (4(2)14) ///
			ylabel(, nogrid) xlabel(, nogrid)
 			graph export "${user}/output/figures/A.7.1_`i'_`s'.png", as(png) replace
		}
		}
		
	/*==============================================================================
		*Figure A.7.2: Impact of adjustments on welfare aggregate
	==============================================================================*/

	foreach i of numlist 2011 2022{
		foreach s of numlist 1 2 {	
				
			use "${user}/data/processed/ces/welfare_agg_17.dta", clear	
			xtile decile = welfare_agg17_sp if year==`i' & sector==`s' [aw=pwt], nq(10)	
			tempfile baseline
			save `baseline', replace
	
			use "${user}/data/processed/ces/welfare_agg_17_pds.dta", clear
			xtile decile = welfare_agg17_sp if year==`i' & sector==`s' [aw=pwt], nq(10)
			tempfile pds
			save `pds', replace
	
			use "${user}/data/processed/ces/welfare_agg_17_lumpexp.dta", clear
			xtile decile = welfare_agg17_sp if year==`i' & sector==`s' [aw=pwt], nq(10)
			tempfile lumpy
			save `lumpy', replace
	
			use "${user}/data/processed/ces/welfare_agg_17_hosp.dta", clear
			xtile decile = welfare_agg17_sp if year==`i' & sector==`s' [aw=pwt], nq(10)
			tempfile hosp
			save `hosp', replace
	
			use "${user}/data/processed/ces/welfare_agg_17_rent.dta", clear
			xtile decile = welfare_agg17_sp if year==`i' & sector==`s' [aw=pwt], nq(10)
			tempfile rent
			save `rent', replace
			
			use "${user}/data/processed/ces/welfare_agg_17_all.dta", clear
			xtile decile = welfare_agg17_sp if year==`i' & sector==`s' [aw=pwt], nq(10)	
			tempfile all
			save `all', replace
			
			use `baseline', clear
			append using `pds'
			append using `lumpy'
			append using `hosp'
			append using `rent'	
			append using `all'
	
		table scenario decile [aw=pwt], stat(mean welfare_agg17_sp) 
		
		collapse welfare_agg17_sp [aw=pwt], by(scenario decile)

		drop if missing(decile)
		encode scenario, gen(scenario_num)
		fre scenario_num
		drop scenario
		reshape wide welfare_agg17_sp, i(decile) j(scenario_num)
		
		gen pds_base = (welfare_agg17_sp4 - welfare_agg17_sp6)/welfare_agg17_sp6 * 100
		gen lump_base = (welfare_agg17_sp3 - welfare_agg17_sp6)/welfare_agg17_sp6 * 100
		gen hosp_base = (welfare_agg17_sp2 - welfare_agg17_sp6)/welfare_agg17_sp6 * 100
		gen rent_base = (welfare_agg17_sp5 - welfare_agg17_sp6)/welfare_agg17_sp6 * 100
		gen all_base = (welfare_agg17_sp1 - welfare_agg17_sp6)/welfare_agg17_sp6 * 100
		
		drop welfare_agg17_sp*
		
		format all_base %9.1f
		
		twoway ///
		(line pds_base decile, lcolor(pink) lwidth(medthick)) ///
		(line lump_base decile, lcolor(gold) lwidth(medthick)) ///
		(line hosp_base decile, lcolor(emerald) lwidth(medthick)) ///
		(line rent_base decile, lcolor(navy) lwidth(medthick)) ///
		(line all_base decile, lcolor(maroon) lwidth(medthick)) ///
		(scatter all_base decile, msymbol(circle) mlabel(all_base) mlabpos(6) ///
		 msize(medium) mlabcolor(maroon) mcolor(maroon) mlabsize(2.5)), ///		
		legend(order(1 "Impute PDS + Non-food free" 2 "Excl. lumpy exp" 3 "Exc. hosp" 4 "Exc. rent" 5 "Final welfare agg") pos(12) cols(5)) ///
		title("Impact of adjustments on welfare aggregate - `i',`s'", size(med)) ///
		xtitle("Consumption Deciles") ///
		ytitle("% change compared to the real expenditure agg")
 		graph export "${user}/output/figures/A.7.2_`i'_`s'.png", as(png) replace
		}
	}
	
	/*==============================================================================
		*Figure A.7.3A: Percentile-based measure of dispersion in final real welfare agg
	==============================================================================*/

	use "${user}/data/processed/ces/welfare_agg_17_all.dta", clear	
	
	preserve
	xtile decile = welfare_agg17_sp if year==2011 & sector==1 [aw=pwt], nq(10)
	collapse welfare_agg17_sp [aw=pwt], by(year sector decile)
	keep if inlist(decile, 1, 10)
	reshape wide welfare_agg17_sp, i(sector year) j(decile)
	tempfile 2011_1
	save `2011_1', replace
	restore
	
	preserve
	xtile decile = welfare_agg17_sp if year==2011 & sector==2 [aw=pwt], nq(10)
	collapse welfare_agg17_sp [aw=pwt], by(year sector decile)
	keep if inlist(decile, 1, 10)
	reshape wide welfare_agg17_sp, i(sector year) j(decile)
	tempfile 2011_2
	save `2011_2', replace
	restore
	
	preserve
	xtile decile = welfare_agg17_sp if year==2011 [aw=pwt], nq(10)
	collapse welfare_agg17_sp [aw=pwt], by(year decile)
	keep if inlist(decile, 1, 10)
	reshape wide welfare_agg17_sp, i(year) j(decile)
	tempfile 2011
	save `2011', replace
	restore
	
	preserve
	xtile decile = welfare_agg17_sp if year==2022 & sector==1 [aw=pwt], nq(10)
	collapse welfare_agg17_sp [aw=pwt], by(year sector decile)
	keep if inlist(decile, 1, 10)
	reshape wide welfare_agg17_sp, i(sector year) j(decile)
	tempfile 2022_1
	save `2022_1', replace
	restore
	
	preserve
	xtile decile = welfare_agg17_sp if year==2022 & sector==2 [aw=pwt], nq(10)
	collapse welfare_agg17_sp [aw=pwt], by(year sector decile)
	keep if inlist(decile, 1, 10)
	reshape wide welfare_agg17_sp, i(sector year) j(decile)
	tempfile 2022_2
	save `2022_2', replace
	restore
	
	preserve
	xtile decile = welfare_agg17_sp if year==2022 [aw=pwt], nq(10)
	collapse welfare_agg17_sp [aw=pwt], by(year decile)
	keep if inlist(decile, 1, 10)
	reshape wide welfare_agg17_sp, i(year) j(decile)
	tempfile 2022
	save `2022', replace
	restore
		
	use `2011_1', clear
	append using `2011_2'
	append using `2011'
	append using `2022_1'
	append using `2022_2'
	append using `2022'
	gen P90_P10 = welfare_agg17_sp10 / welfare_agg17_sp1
	format P90_P10 %9.1f
	

	replace sector = 3 if missing(sector)
	
	label drop sector
	label define sector ///
	1 "Rural" 2 "Urban" 3 "National"
	lab value sector "sector"
	
	drop welfare_agg17_sp*
	reshape wide P90_P10, i(sector) j(year)	
	
	graph bar P90_P102011 P90_P102022, over(sector)  ///
	bar(1, bcolor(maroon) lcolor(maroon)) bar(2, bcolor(emerald) lcolor(emerald)) blabel(bar, size(small) color(black) format(%9.1f)) legend(label(1 "2011-12") label(2 "2022-23") pos(12) cols(2)) yscale(off) ///
	title("Ratio of real welfare aggregate of top decile to bottom decile", size(medium))
	graph export "${user}/output/figures/A.7.3.a.png", as(png) replace

	/*==============================================================================
		*Figure A.7.3B: Percentile-based measure of dispersion in final real welfare agg
	==============================================================================*/

	use "${user}/data/processed/ces/welfare_agg_17_all.dta", clear	
	
	preserve
	xtile quantile = welfare_agg17_sp if year==2011 & sector==1 [aw=pwt], nq(4)
	collapse welfare_agg17_sp [aw=pwt], by(year sector quantile)
	keep if inlist(quantile, 1, 4)
	reshape wide welfare_agg17_sp, i(sector year) j(quantile)
	tempfile 2011_1
	save `2011_1', replace
	restore
	
	preserve
	xtile quantile = welfare_agg17_sp if year==2011 & sector==2 [aw=pwt], nq(4)
	collapse welfare_agg17_sp [aw=pwt], by(year sector quantile)
	keep if inlist(quantile, 1, 4)
	reshape wide welfare_agg17_sp, i(sector year) j(quantile)
	tempfile 2011_2
	save `2011_2', replace
	restore
	
	preserve
	xtile quantile = welfare_agg17_sp if year==2011 [aw=pwt], nq(4)
	collapse welfare_agg17_sp [aw=pwt], by(year quantile)
	keep if inlist(quantile, 1, 4)
	reshape wide welfare_agg17_sp, i(year) j(quantile)
	tempfile 2011
	save `2011', replace
	restore
	
	preserve
	xtile quantile = welfare_agg17_sp if year==2022 & sector==1 [aw=pwt], nq(4)
	collapse welfare_agg17_sp [aw=pwt], by(year sector quantile)
	keep if inlist(quantile, 1, 4)
	reshape wide welfare_agg17_sp, i(sector year) j(quantile)
	tempfile 2022_1
	save `2022_1', replace
	restore
	
	preserve
	xtile quantile = welfare_agg17_sp if year==2022 & sector==2 [aw=pwt], nq(4)
	collapse welfare_agg17_sp [aw=pwt], by(year sector quantile)
	keep if inlist(quantile, 1, 4)
	reshape wide welfare_agg17_sp, i(sector year) j(quantile)
	tempfile 2022_2
	save `2022_2', replace
	restore
	
	preserve
	xtile quantile = welfare_agg17_sp if year==2022 [aw=pwt], nq(4)
	collapse welfare_agg17_sp [aw=pwt], by(year quantile)
	keep if inlist(quantile, 1, 4)
	reshape wide welfare_agg17_sp, i(year) j(quantile)
	tempfile 2022
	save `2022', replace
	restore
		
	use `2011_1', clear
	append using `2011_2'
	append using `2011'
	append using `2022_1'
	append using `2022_2'
	append using `2022'
	gen P75_P25 = welfare_agg17_sp4 / welfare_agg17_sp1
	format P75_P25 %9.1f
	
	replace sector = 3 if missing(sector)	
	
	label drop sector
	label define sector ///
	1 "Rural" 2 "Urban" 3 "National"
	lab value sector "sector"
	
	drop welfare_agg17_sp*
	reshape wide P75_P25, i(sector) j(year)	
	
	graph bar P75_P252011 P75_P252022, over(sector)  ///
	bar(1, bcolor(maroon) lcolor(maroon)) bar(2, bcolor(emerald) lcolor(emerald)) blabel(bar, size(small) color(black) format(%9.1f)) legend(label(1 "2011-12") label(2 "2022-23") pos(12) cols(2)) yscale(off)  ///
	title("Ratio of real welfare aggregate of top quantile to bottom  quantile", size(medium))
	graph export "${user}/output/figures/A.7.3.b.png", as(png) replace

	* =============================================================================*
		di in red "THE END OF 09_figures" 
	* =============================================================================*
	cap log close
	exit
