
	loc date: display %tdCCYY-NN-DD =daily("`c(current_date)'", "DMY")
	cap log close
	log using "${user}/output/sensitivity_checks/add_housing/log/02b_housing_2022_postmatch_`date'.log", replace

	/* =============================================================================
	Project			: India poverty estimates - 2011-12 & 2022-23 
	Dofile			: 02d_housing_2022
	Last modified	: April 11th 2025

	Inputs			:  // From R-Script
					  "${user}/data/processed/other/sensitivity_checks/add_housing/train_R.dta"
					
						// Additional for cleaning 2011
					   "${user}/data/processed/ces/master_consumption_2011.dta"
					   "${user}/data/processed/ces/block0102_2011_mmrp.dta"
					   "${user}/data/processed/ces/block03a_2011_mmrp2.dta"
					   "${user}/data/processed/ces/block03b_2011_mmrp.dta"
					   "${user}/data/processed/ces/mpce_2011.dta"
																				
	Output			:  "${user}/data/processed/ces/sensitivity_checks/add_housing/rents_hh_2022.dta"
					   "${user}/data/processed/ces/sensitivity_checks/add_housing/rents_hh_2011.dta"
					   "${user}/data/processed/ces/sensitivity_checks/add_housing/housing_predictions2022.dta"

	*Steps			:  *4. Propensity score matching to select self-reporters, 2022 <<== From R
					   *5. Hedonic model, 2022
					   *6. Clean rents for 2011 
	============================================================================ */	
		
		
	*===============================================================================
	* 4. Propensity score matching: select owners to enlarge sample
	*===============================================================================
		
	use "${user}/data/processed/ces/sensitivity_checks/add_housing/rents_hh_2022_prematch.dta", clear	
		
		
		* Refer to specialized R Script for matching
		
		*5.1) Merge to R output dataset including subset for training model
		merge 1:1 hhid using "${user}/data/processed/ces/sensitivity_checks/add_housing/train_R.dta" , keepusing(renter)
			g train=0 
			replace train = 1 if _merge == 3 | typeof_dwelling==2 // keep matched owners + all renters 
			drop _merge
		save "${user}/data/processed/ces/sensitivity_checks/add_housing/rents_hh_2022.dta", replace	
		
	*===============================================================================
	*5. Hedonic model for housing rental imputation 2022
	*===============================================================================

		*5.1) Fit model
		*5.1.1) Dependent variable
		glo Y "l_rent"
				
		*5.1.2) Vector of Regressors
		glo X "l_hhsize  i.wall_material i.roof_material i.floor_material i.drinking_water i.latrine_type i.lighting mobile internet i.cooking log_time_to_water i.caste television laptop air_conditioner car refrigerator washing_machine nic_agro nic_industry nic_services nic_public hindu"

		sum ${X}
		
			*6.1.3) Parameters
			glo fe1 state
			glo fe2 sector
			glo fe3 sss
			glo fe4 survey_month
			glo w pwt
			glo fam gamma
			glo link log
			glo tol 1e-17

		*5.2) Model estimation 
			eststo model: reg ${Y} ${X} i.${fe1} i.${fe2} i.${fe3} i.${fe4} [aw = ${w}] if train==1
		
		*5.3)  Predicted values 
		*Output: vectors y_pred (usual antilog transformation), y_pred_duan (with duan's correction)
		estimates restore model
		scalar rmse 		= e(rmse) 
		predict y_pred
		predict y_res, resid
		g double eresid 	= exp(y_res)
		sum eresid [aw = ${w}]
		g double y_pred_duan = log(exp(y_pred) * r(mean))	 
		
		g double res_duan_sq 	= (y_pred_duan - ${Y})^2
			sum res_duan_sq  [aw = ${w}] if train==1
			scalar mse_duan = r(mean)
			scalar rmse_duan = mse_duan^(1/2)

		*5.4) Final vector of rents imputation
		*5.4.1) Assigning predictions of the hedonic model
		g  use_value = exp(y_pred_duan)               
				replace use_value = rent_w1 if train==1 // keep original responses from renters and matched owners/others
			
		*5.4.2) Winsorize results (1%) by type of dwelling
			winsor2 use_value, cuts(1 99) suff(_w1) by(typeof_dwelling) 
		
		*5.5) Adjusting to merge
		*5.5.1) Make dataset comparable to master_consumption so it can be appended for the marginal adjustments
			g item 			= 520
			g scode 		= 4000   // housing for cpi
			ren use_value_w1 value_total_all_hedonic 
			g qty_total 	= .
			destring year, replace
			g source 		= .
			g qty_new 		= .
			
			g value_total = value_total_all_hedonic 
			
			codebook hhid // 261,696 HHs. 
			sum value_total if item==520 // Only  235,968  have valid imputation. 
			isid hhid
				
		*5.6) Save vector for plugging into analysis
			keep hhid  item survey_month year value_total value_total_all_hedonic qty_total qty_new source renter y_pred l_rent train
			order hhid  survey_month year item qty_total qty_new value_total value_total_all_hedonic source 
			
		save "${user}/data/processed/ces/sensitivity_checks/add_housing/housing_predictions2022.dta",replace
		
	*===============================================================================
	*6. Clean rents for 2011 
	*===============================================================================

		*Cleaning 2011 consumption data and merging required auxiliary datasets
		use "${user}/data/processed/ces/master_consumption_2011.dta", clear
			g double rent_actual = 0
				replace rent_actual  = value_total if item == 520
			g double rent_imputed = 0
				replace rent_imputed = value_total if item == 539
			collapse (sum) rent*, by(hhid)
			merge 1:1 hhid using "${user}/data/processed/ces/block0102_2011_mmrp.dta", keepusing(sector) nogen
			merge 1:1 hhid using "${user}/data/processed/ces/block03a_2011_mmrp.dta", keepusing(hhsize) nogen
			merge 1:1 hhid using "${user}/data/processed/ces/block03b_2011_mmrp.dta", keepusing(dwellingcode hhwt) nogen
		
		*Dummy variable for whether hh rented or self-reported rents
			g rent_actual01 	= rent_actual>0 & rent_actual<.
			g rent_imputed01 	= rent_imputed>0 & rent_imputed<.
		
		* Adding MPCE 
			merge 1:1 hhid using "${user}/data/processed/ces/mpce_2011.dta", keepusing(mpce_nom pwt) // This is the baseline without adjustments
					g mpce_q20 =.
						forval i=1/2{
					xtile mpce_q20_`i' = mpce_nom [w=pwt] if sector==`i', nq(20)
					replace mpce_q20 = mpce_q20_`i' if sector==`i'
					}
		lab var mpce_q20 "Vigintile of nominal expenditures pc, by sector"
		drop  mpce_q20_*
		g renter = rent_actual>0 & rent_actual<. & dwellingcode==2
					
		save "${user}/data/processed/ces/sensitivity_checks/add_housing/rents_hh_2011.dta", replace	
				
	*===============================================================================
	di in red "THE END OF 02d_housing_2022"
	*===============================================================================
	log close
	exit