
		
	/*==============================================================================
		*Table 8: Share of household reporting actual rental values 
	==============================================================================*/

	*2022
	use "${user}/data/processed/ces/sensitivity_checks/add_housing/rents_hh_2022.dta", clear	
	* Dummy variable for whether hh rented or self-reported rents
		g rent_actual01  = rent_actual	>0 & rent_actual<.
		g rent_imputed01 = rent_imputed	>0 & rent_imputed<.
		g rent02 = (rent_actual>0 & rent_actual<.) | (rent_imputed>0 & rent_imputed<.)
		
	* If home-owner
		g owner = 0
			replace owner = 1 if typeof_dwelling==1
		*If owner that reports imputed rents
		g owner_impute = 0
			replace owner_impute = 1 if (owner==1 & rent_imputed01==1)
		*If owner that does not report imputed rents
		g owner_nonimpute = 0
			replace owner_nonimpute = 1 if (owner==1 & rent_imputed01==0)

	* If renter (claims to be a renter)
		g renter_claim = 0
			replace renter_claim = 1 if typeof_dwelling==2
		*If renter that reports actual rents: renter (claims to be a renter and reports rent expenditure)

	* Collapse by sector	
		preserve	
			collapse (mean) owner owner_impute owner_nonimpute renter_claim renter [w=hhwt], by(sector)
			gsort - sector
			order sector renter_claim owner renter owner_impute owner_nonimpute
			keep sector renter_claim owner renter owner_impute owner_nonimpute
		tempfile sector2022
		save "`sector2022'", replace
		restore

	* Collapse all
		preserve
			collapse (mean) owner owner_impute owner_nonimpute renter_claim renter [w=hhwt]
			order renter_claim owner renter owner_impute owner_nonimpute
			keep renter_claim owner renter owner_impute owner_nonimpute
			append using "`sector2022'"
			g year=2022
		tempfile all2022
		save "`all2022'", replace
		restore	
				
	* 2011
	use "${user}/data/processed/ces/sensitivity_checks/add_housing/rents_hh_2011.dta", clear
		//g renter = rent_actual>0 & rent_actual<. & dwellingcode==2

	* If owner
	g owner = 0
		replace owner = 1 if dwellingcode==1
		* If owner that reports imputed rents
		g owner_impute = 0
			replace owner_impute = 1 if (owner==1 & rent_imputed01==1)
		* Owner that does not report imputed rents
		g owner_nonimpute = 0
			replace owner_nonimpute = 1 if (owner==1 & rent_imputed01==0)

	* If renter	
	g renter_claim = 0
		replace renter_claim = 1 if dwellingcode==2
		* If renter that reports actual rents
		*g renter_impute = renter // WHY IS THIS FROZEN?

	*Collapse by sector	
	preserve	
		collapse (mean) owner owner_impute owner_nonimpute renter_claim renter [w=hhwt], by(sector)
		gsort - sector
		order sector renter_claim owner renter owner_impute owner_nonimpute
		keep  sector renter_claim owner renter owner_impute owner_nonimpute
		tempfile sector2011
		save "`sector2011'", replace
	restore

	*Collapse all
	collapse (mean) owner owner_impute owner_nonimpute renter_claim renter [w=hhwt]
		order renter_claim owner renter owner_impute owner_nonimpute
		keep  renter_claim owner renter owner_impute owner_nonimpute
		append using "`sector2011'"
		g year=2011
		append using "`all2022'"
		tempfile all20112022
		save "`all20112022'", replace

	* Format table with 2011 & 2022
		replace sector=3 if sector==.
		lab define sector_labels 1 "Rural" 2 "Urban" 3 "All"
		lab val sector sector_labels
		order year sector
		
		
		gen renter_claim_perc = 100*renter_claim
		gen owner_perc = 100*owner
		gen renter_perc = 100*renter
		gen owner_impute_perc = 100*owner_impute
		gen owner_nonimpute_perc = 100*owner_nonimpute
		
		format renter_claim_perc %9.1f
		format owner_perc %9.1f
		format renter_perc %9.1f
		format owner_impute_perc %9.1f
		format owner_nonimpute_perc %9.1f
		
		keep year sector renter_claim_perc owner_perc renter_perc owner_impute_perc owner_nonimpute_perc
	
	* Export table
	export excel using "${user}/output/excel/tables.xlsx", sheet("Table 8", replace) firstrow(variables)
	
	
		
	/*==============================================================================
		*Table A.6.1 Potential effects of including predicted houshing values 2022-23
	==============================================================================*/

	use "${user}/output/welfare_pov_final.dta", clear
	keep if year==2022
	gen scenario = "A. Without housing"
	append using  "${user}/output/sensitivity_checks/add_housing/welfare_pov_final.dta"
	replace scenario = "B. Including housing predictions" if missing(scenario)
		
	table sector (scenario) [aw=pwt], stat(mean poor_215_perc poor_365_perc poor_685_perc) nformat(%9.1f) sformat("%s%%") 
	collect export "${user}/output/excel/tables.xlsx", sheet("Table A.6.1", replace) cell(A1) modify 
	
	putexcel set "${user}/output/excel/tables.xlsx", sheet("Table A.6.1") modify
	putexcel D2=("") D5=("") D6=("") D7=("") D9=("") D10=("") D11=("") D13=("") D14=("") D15=("")
	
	*Gini
	encode scenario, gen(scenario_num)
			
	levelsof scenario, local(scenario)
	foreach s of local scenario {
			di in red "`s'"
		}
		
	*All-India, rural and urban gini - define and store results in matrix for all scenarios
	mat drop _all
		foreach y of numlist 2022 {
			foreach s of numlist 1/2 {
				mat define gini_`y'_`s' = J(1, 4, .)
				mat rownames gini_`y'_`s' = `y'
				mat colnames gini_`y'_`s' = rural urban national scenario_num
				
			foreach i of numlist 1 2 {
				di in red "sector - `i', year - `y', scenario - `s'"
				ainequal welfare_agg17_sp  [aw=pwt] if sector==`i' & year==`y' & scenario_num==`s'
				mat gini_`y'_`s' [1,`i'] = `r(gini_1)'		
				}
					di in red "year - `y', scenario - `s'"
					ainequal welfare_agg17_sp  [aw=pwt] if year==`y' & scenario_num==`s'
					mat gini_`y'_`s' [1,3] = `r(gini_1)'	
					mat gini_`y'_`s' [1,4] = `s'	
					}
					}
		
	*Combine matrix for each scenario
	mat gini_2022 = gini_2022_1 \ gini_2022_2 
			
	clear
	svmat gini_2022, names(col)
			
	replace rural = rural*100
	format rural %9.1f
			
	replace urban = urban*100
	format urban %9.1f
		
	replace national = national*100
	format national %9.1f
		
	gen scenario = "."
	replace scenario = "A. Without housing" if scenario_num == 1
	replace scenario = "B. Including housing predictions" if scenario_num == 2
	
	order scenario national rural urban
	drop scenario_num
	export excel using "${user}/output/excel/tables.xlsx", firstrow(variables) sheet("Table A.6.1", modify) cell(A17) 
	
	
	
	/*==============================================================================
		*Figure 4: Share of renters, by vigintile and sector
	==============================================================================*/
		
	*2011 - Share of renters, by sector and q20 
	use "${user}/data/processed/ces/sensitivity_checks/add_housing/rents_hh_2011.dta", clear
		g renter_rural = renter if sector==1
		g renter_urban = renter if sector==2
		
	tabstat renter [w=hhwt] if sector==1, by(mpce_q20) 
	tabstat renter [w=hhwt] if sector==2, by(mpce_q20) 
		
		collapse (mean) renter* [w=hhwt], by(mpce_q20 sector)
		g grenter_rural = renter_rural*100
		g grenter_urban = renter_urban*100
		
		graph bar grenter_rural grenter_urban, over(mpce_q20) ///
			ylabel(0(10)60) yscale(range(0 60)) ///
			bar(1, color(blue%60)) bar(2, color(red%60)) ///
			legend(order(1 "Rural" 2 "Urban") position(12)) ///
			title("Share of renters by vigintile and sector, 2011-12") ///
			bargap(20)
	graph export "${user}/output/figures/4a.png", as(png) height(1000) replace
	
*2022 - Share of renters, by sector and q20 
	use "${user}/data/processed/ces/sensitivity_checks/add_housing/rents_hh_2022.dta", clear	
		g renter_rural = renter if sector==1
		g renter_urban = renter if sector==2
		
	tabstat renter [w=hhwt] if sector==1, by(mpce_q20) 
	tabstat renter [w=hhwt] if sector==2, by(mpce_q20) 
			
	collapse (mean) renter* [w=hhwt], by(mpce_q20 sector)
		g grenter_rural = renter_rural*100
		g grenter_urban = renter_urban*100
		
	graph bar grenter_rural grenter_urban, over(mpce_q20) ///
		ylabel(0(10)60) yscale(range(0 60)) ///
		bar(1, color(blue%60)) bar(2, color(red%60)) ///
		legend(order(1 "Rural" 2 "Urban") position(12)) ///
		title("Share of renters by vigintile and sector, 2022-23") ///
		bargap(20)
		graph export "${user}/output/figures/4b.png", as(png) height(1000) replace
		
		
				
	/*==============================================================================
		*Prepare data for various graphs for hedonic annex
	==============================================================================*/

	*Retrieve final welfare vector in scenario _all
	use "${user}/data/processed/ces/mpce_2022_all.dta", clear
		keep hhid state sector mpce_sp_def_ind pwt
		ren mpce_sp_def_ind vector_all
		
	merge 1:1 hhid using "${user}/data/processed/ces/sensitivity_checks/add_housing/mpce_2022_all_hedonic.dta", keepusing(mpce_sp_def_ind) 
		ren mpce_sp_def_ind vector_all_hedonic
	
	*Construct q for all scenario
	foreach levs in 20 100{
			g mpce_q`levs'=.
			forval i=1/2{
			xtile mpce_q`levs'_`i' = vector_all [w=pwt] if sector==`i', nq(`levs')
			replace mpce_q`levs'=mpce_q`levs'_`i' if sector==`i'
			}
			}
	lab var mpce_q20 "Vigintile of real welfare aggregate (all adjustments, pre hedonic)"
		
	save "${user}/data/processed/ces/sensitivity_checks/add_housing/mpce_2022_all_hedonic_forgraphics.dta", replace
	
	/*==============================================================================
		*Figure A.6.1. Distribution of housing and non-housing shares by welfare vigintiles
	==============================================================================*/

	* Housing shares after hedonic model
	use "${user}/data/processed/ces/sensitivity_checks/add_housing/mpce_2022_all_hedonic_forgraphics.dta", clear

	* Calculate real housing value for each HH and housing shares
	g rent_real = vector_all_hedonic - vector_all // Diference in models
		g l_rent = log(rent_real)
		g l_mpce = log(vector_all)
		g rent_sh 	= 100 *(rent_real/vector_all)
		g other_sh 	= 100 - rent_sh 

	*Rural
	graph bar (mean) rent_sh other_sh [w=pwt] if sector==1, over(mpce_q20_1 , gap(*0.5) ) stack ///
		b1title("Welfare vigintile") ///
		yscale(range(0 100)) ylabel(0(10)100, format(%3.0f) angle(0) labsize(medium)) ///
		ytitle("Share (%)", size(medium))  ///
		blabel(bar, position(center) format(%9.1f)  size(small) color(white)) ///
		bargap(5) ///
		legend(order(1 "Housing" 2 "Non-Housing") size(medium) position(12) ring(1)) ///
		graphregion(color(white)) bgcolor(white)
	graph export "${user}/output/figures/A.6.1.a.png", as(png) height(1000) replace
	
	*Urban
	graph bar (mean) rent_sh other_sh [w=pwt] if sector==2, over(mpce_q20_2 , gap(*0.5) ) stack ///
		b1title("Welfare vigintile") ///
		yscale(range(0 100)) ylabel(0(10)100, format(%3.0f) angle(0) labsize(medium)) ///
		ytitle("Share (%)", size(medium))  ///
		blabel(bar, position(center) format(%9.1f)  size(small) color(white)) ///
		bargap(5) ///
		legend(order(1 "Housing" 2 "Non-Housing") size(medium) position(12) ring(1)) ///
		graphregion(color(white)) bgcolor(white)
		graph export "${user}/output/figures/A.6.1.b.png", as(png) height(1000) replace
	
	
	sum rent_sh other_sh [w=pwt] if sector==1
	sum rent_sh other_sh [w=pwt] if sector==2


	/*==============================================================================
		*Figure A.6.2. Changes in welfare distribution, with housing value prediction	
	==============================================================================*/

	use "${user}/data/processed/ces/sensitivity_checks/add_housing/mpce_2022_all_hedonic_forgraphics.dta", clear

	g l_vector_all 			= log(vector_all)
	g l_vector_all_hedonic 	= log(vector_all_hedonic)
	
	
	twoway (kdensity l_vector_all if sector ==1 [w=pwt]) (kdensity l_vector_all_hedonic if sector==1 [w=pwt]),  legend(order(1 "Without Rents" 2 "With Rents") position(12) ring(1))  xtitle("Log of real welfare aggregate") ytitle("Density")
	graph export "${user}/output/figures/A.6.2.a.png", as(png) replace
	
	twoway (kdensity l_vector_all if sector==2 [w=pwt])   (kdensity l_vector_all_hedonic if sector==2 [w=pwt]),  legend(order(1 "Without Rents" 2 "With Rents") position(12) ring(1))  xtitle("Log of real welfare aggregate") ytitle("Density")
	graph export "${user}/output/figures/A.6.2.b.png", as(png) replace

	/*==============================================================================
		*Figure A.6.3. Changes in Lorenz Curves, with housing value prediction
	==============================================================================*/

	use "${user}/data/processed/ces/sensitivity_checks/add_housing/mpce_2022_all_hedonic_forgraphics.dta", clear
	
	*National
	glcurve vector_all [aw=pwt], lorenz gl(g1) p(p1) nograph 
	glcurve vector_all_hedonic [aw=pwt], lorenz gl(g2) p(p2) nograph
	// We tested that aw and fw gives same result
	

	
	*Rural
	glcurve vector_all if sector==1 [aw=pwt], lorenz gl(g3) p(p3) nograph
	glcurve vector_all_hedonic if sector==1 [aw=pwt], lorenz gl(g4) p(p4) nograph

	twoway (line g3 p3, sort) (line g4 p4, sort) ///
		(function y = x, range(0 1) lcolor(black) ) ///
		, xlabel(0(.2)1) ylabel(0(.2)1) ///
		xtitle("Cumulative share of population") ///
		ytitle("Cumulative share of welfare") ///
		title("Comparison of Lorenz Curves") ///
	   legend(order(1 "Without Rents" 2 "With Rents" 3 "Line of equality") position(12) ring(1)) 
	graph export "${user}/output/figures/A.6.3.a.png", as(png) replace

	*Urban
	glcurve vector_all if sector==2 [aw=pwt], lorenz gl(g5) p(p5) nograph
	glcurve vector_all_hedonic if sector==2 [aw=pwt], lorenz gl(g6) p(p6) nograph

	twoway (line g5 p5, sort) (line g6 p6, sort) ///
		(function y = x, range(0 1) lcolor(black) ) ///
		, xlabel(0(.2)1) ylabel(0(.2)1) ///
		xtitle("Cumulative share of population") ///
		ytitle("Cumulative share of welfare") ///
		title("Comparison of Lorenz Curves") ///
	   legend(order(1 "Without Rents" 2 "With Rents" 3 "Line of equality") position(12) ring(1)) 
	graph export "${user}/output/figures/A.6.3.b.png", as(png) replace



	/*==============================================================================
		*Figure A.6.4. Hedonic model's prediction accuracy	
	==============================================================================*/
	
	use "${user}/data/processed/ces/sensitivity_checks/add_housing/housing_predictions2022.dta", clear

	twoway (scatter y_pred l_rent if renter==0, mcolor(red%40)) ///
		   (scatter y_pred l_rent if renter==1, mcolor(green%40)) ///
		   (line l_rent  l_rent, lcolor(black)) if train==1, ///
		   xscale(range(0 12)) xlabel(0(2)12)   ///
		   xtitle("Log of rent") ///
		   ytitle("Prediction") ///
		   yscale(range(0 12)) ylabel(0(2)12) ///
		   legend(ring(0) position(4) order(1 "Matched self-reporters" ///
											2 "Renters" ///
											3 "Perfect Fit" )) ///
		   title("Hedonic model accuracy test (within sample)")
	graph export "${user}/output/figures/A.6.4.png", as(png) height(1000) replace
	
