	loc date: display %tdCCYY-NN-DD =daily("`c(current_date)'", "DMY")
	cap log close
	log using "${user}/output/log/07_pov_ineq_h4_`date'", replace

	/* =============================================================================
		Project			: India poverty estimates - 2011-12 & 2022-23 
		Dofile			: 07_pov_ineq.do
		Last modified	: 26th March 2025

		Inputs			: "${user}/data/processed/ces/sensitivity_checks/hhsize/welfare_agg_17_h4_all.dta"
						
		Outputs			: "${user}/output/sensitivity_checks/hhsize/welfare_pov_final_h4.dta"

	================================================================================ */

	* Define macros & scalars
		glo 	povlines17 	215 365 685 
		scalar	ppp17	= 	19.46903992    // https://databank.worldbank.org/source/icp-2017#
			
	* Use the welfare aggregate created for the final "ALL" scenario

	use "${user}/data/processed/ces/sensitivity_checks/hhsize/welfare_agg_17_h4_all.dta", clear
		
	*===============================================================================
	*Step 1. Construct 2017 poverty lines, expressed in INR 2017 PPP
	*===============================================================================

	foreach i of glo povlines17 {
		gen double pline_`i'= (`i'/100)*(365/12)*ppp17
		}
				
	*===============================================================================
	*Step 2. Calculate dummies for poor households
	*===============================================================================

	foreach i of glo povlines17 {
		gen double poor_`i'  	= .
		replace poor_`i' 	= welfare_agg17_sp  <= pline_`i' 
		}	

	keep hhid sector pwt year poor_* welfare_agg17_sp hhsize
		
	cap lab def sector 1 "Rural" 2 "Urban"
	lab val sector sector
	lab var poor_215 "Poverty dummy - below $2.15"
	lab var poor_365 "Poverty dummy - below $3.65"
	lab var poor_685 "Poverty dummy - below $6.85"
	
	gen poor_215_perc = poor_215*100
	gen poor_365_perc = poor_365*100
	gen poor_685_perc = poor_685*100
		
	di in red "Poverty rates under $2.15"
	table sector year [aw=pwt], stat(mean poor_215_perc) totals(year) nformat(%9.1f) sformat("%s%%") 


	
	di in red "Poverty rates under $3.65"
	table sector year [aw=pwt], stat(mean poor_365_perc) totals(year) nformat(%9.1f) sformat("%s%%") 

	di in red "Poverty rates under $6.85"
	table sector year [aw=pwt], stat(mean poor_685_perc) totals(year) nformat(%9.1f) sformat("%s%%") 	

	save "${user}/output/sensitivity_checks/hhsize/welfare_pov_final_h4.dta", replace
	
	*===============================================================================
	*Step 3. Calculate Gini coefficient
	*===============================================================================

	*All-India, rural and urban gini - define and store results in matrix
	mat drop _all
	foreach y of numlist 2022 {		
			mat define gini_`y' = J(1, 3, .)
			mat rownames gini_`y' = `y'
			mat colnames gini_`y' = rural urban national
	foreach i of numlist 1 2 {
		ainequal welfare_agg17_sp  [aw=pwt] if sector==`i' & year==`y'
		mat gini_`y' [1,`i'] = `r(gini_1)'		
	}
	ainequal welfare_agg17_sp  [aw=pwt] if year==`y'
	mat gini_`y' [1,3] = `r(gini_1)'
	}
	
	*Matrix combine
	mat define gini = J(2,3,.)
	mat gini = gini_2022
	
	mat gini_index = 100 * gini
	
	mat list gini_index, format(%9.1f)

				
	* =============================================================================*
		di in red "THE END OF 07_pov_ineq_h4" 
	* =============================================================================*
	cap log close
	exit
