	loc date: display %tdCCYY-NN-DD =daily("`c(current_date)'", "DMY")
	cap log close
	log using "${user}/output/sensitivity_checks/inter_temporal/log/001-005_intertemporal_all_v1_`date'", replace

	/* =============================================================================	
	Project				: 	India poverty estimates - 2011-12 & 2022-23 
	Dofile				: 	05_intertemporal_uv_v1
	Last modified		:   22 Jan 2025	
					
	Inputs				:   "${user}/data/processed/ces/master_consumption_wy_2011_all.dta"
							"${user}/data/processed/ces/master_hh_2011.dta"
							"${user}/data/processed/ces/master_item_list_2011.dta"
							"${user}/data/processed/ces/master_consumption_wy_2022_all.dta"
							"${user}/data/processed/ces/master_hh_2022.dta"
							"${user}/data/processed/ces/master_item_list_2022.dta"						

	Intermediate Output	:	"${output}/sensitivity_checks/inter_temporal/2011_item_level_mmrp_all.dta"
							"${output}/sensitivity_checks/inter_temporal/2022_item_level_mmrp_all.dta"
							"${output}/sensitivity_checks/inter_temporal/temp/`y'_items_long_clean_p`x'_all.dta"
							"${output}/sensitivity_checks/inter_temporal/temp/`y'_non_zero_obs_p`x'_all_v1.dta"
							"${output}/sensitivity_checks/inter_temporal/temp/`y'_med_price_avg_qty_p`x'_all_v1"
												
	Output				:	"${output}/sensitivity_checks/inter_temporal/excel/temporal_inflation_item.xlsx"
							"${output}/sensitivity_checks/inter_temporal/2011_intertemporal_deflators_all_v1.dta"
							"${output}/sensitivity_checks/inter_temporal/2022_intertemporal_deflators_all_v1.dta"
								
	Steps				: 	* 1. Data prep
							* 2. Convert into long and split in parts
							* 3. Retrieve Median price and Quanitities
							* 4. Combine Price and Quantity
							* 5. Calculation of Fisher Indices 
	============================================================================= */

	***********
	*Version 1: using product_codes (meaning that we are including three sources: Market, PDS subsidized and free items)
	***********
		

	*=====================================================================
	* 1. Data prep
	*=====================================================================

	***********************************
	* DATA PREP FOR 2011
	***********************************
	use "${user}/data/processed/ces/master_consumption_wy_2011_all.dta", clear
	merge m:1 hhid using "${user}/data/processed/ces/master_hh_2011.dta", keepusing(state sector)
	drop _m
	merge m:1 item using "${user}/data/processed/ces/master_item_list_2011.dta", keepusing(commodity_group product_code subtotal no_qty)  // Merge with names and units file (created by WB SARPOV)
	drop _m

		* keep items with quantity
			keep if  inrange(commodity_group, 1, 15)
			* Drop subtotals
				drop if subtotal==1  
				drop if no_qty==1  
		
		collapse (sum) qty_total qty_new value_total_all value_deflated_all, by(year hhid product_code commodity_group state sector)
		
		g data_grp =  .
			replace data_grp = 1  if inrange(commodity_group, 1, 5)
			replace data_grp = 2  if inlist(commodity_group, 6) 
			replace data_grp = 3  if inlist(commodity_group, 7,8, 9)
			replace data_grp = 4  if inlist(commodity_group, 10)
			replace data_grp = 5  if inlist(commodity_group, 11, 12, 13)
			replace data_grp = 6  if inlist(commodity_group, 14, 15)
			
		keep year hhid product_code qty_new qty_total value_total_all value_deflated_all data_grp 
		
		save "${user}/data/processed/ces/sensitivity_checks/inter_temporal/2011_item_level_mmrp_all.dta", replace

	***********************************
	* DATA PREP FOR 2022
	***********************************	
	use "${user}/data/processed/ces/master_consumption_wy_2022_all.dta", clear
	merge m:1 hhid using "${user}/data/processed/ces//master_hh_2022.dta", keepusing(state sector)
	drop _m
	merge m:1 item using "${user}/data/processed/ces/master_item_list_2022.dta", keepusing(commodity_group product_code subtotal sub_grains no_qty free agg_item) keep(3)  // Merge with names and units file (created by WB SARPOV)
	drop _m

	keep if  inrange(commodity_group, 1, 15)
	* Drop subtotals
	drop if subtotal == 1 | sub_grains ==1
	drop if agg_item==1	
	*Drop those items without quantities
	drop if no_qty==1  
	
			
	collapse (sum) qty_total qty_new value_total_all value_deflated_all, by(year hhid product_code commodity_group state sector) 
	
	*Create data groups
	g data_grp =  .
		replace data_grp = 1  if inrange(commodity_group, 1, 5)
		replace data_grp = 2  if inlist(commodity_group, 6) 
		replace data_grp = 3  if inlist(commodity_group, 7,8, 9)
		replace data_grp = 4  if inlist(commodity_group, 10)
		replace data_grp = 5  if inlist(commodity_group, 11, 12, 13)
		replace data_grp = 6  if inlist(commodity_group, 14, 15)
	keep year state sector hhid product_code qty_new qty_total value_total_all value_deflated_all data_grp 
	
	save "${user}/data/processed/ces/sensitivity_checks/inter_temporal/2022_item_level_mmrp_all.dta", replace

	/*=======================================================================*/
	* 2. Convert into long and split in parts
	/*=======================================================================*/	
	foreach y of numlist 2011 2022 {
		use "${user}/data/processed/ces/master_item_list_`y'.dta", clear
			keep product_code commodity_group 
			collapse commodity_group , by(product_code)
		tempfile product_info
		save `product_info'
		
		use "${user}/data/processed/ces/sensitivity_checks/inter_temporal/`y'_item_level_mmrp_all.dta", clear
		su data_grp
				local n_max = r(max)
				di "number of parts: `n_max'"
		
		forval x=1/`n_max' {
		preserve
				keep if data_grp== `x'
			* reshape to have all items for all HHIDs	
				fastreshape wide qty_new qty_total value_deflated_all, i(hhid) j(product_code)
					
			* merge to have all HHs in sample
				merge 1:1 hhid using "${user}/data/processed/ces/master_hh_`y'.dta", nogen keepusing(year state sector hhid pwt hhsize)
				
			* convert back to long - Each hh should have 185 items 
			fastreshape long qty_new qty_total value_deflated_all, i(hhid) j(product_code)
			
			merge m:1 product_code using `product_info', keepusing(commodity_group) nogen keep(3)
			
			keep year hhid product_code state sector qty_new qty_total value_deflated_all pwt hhsize commodity_group
			
		save "${user}/data/processed/ces/sensitivity_checks/inter_temporal/temp/`y'_items_long_clean_p`x'_all.dta", replace
		restore	
		}
		} 
	
	/*=======================================================================*/
	* * 3. Retrieve Median Price and Quanitities
	/*=======================================================================*/
		
	foreach y in  2011 2022 {
		foreach x of numlist 1(1)6 {
			use "${user}/data/processed/ces/sensitivity_checks/inter_temporal/temp/`y'_items_long_clean_p`x'_all.dta", clear

			***************
			*ITEM RECODING 	
			***************		
			*Two items are mapped to different Commodity groups in 2011 and 2022
			
			*Bread Bakery (113) is in CG 11 in 2022 but CG 1 in 2011 
			replace commodity_group = 1 if product_code ==113 & year ==2022
			
			*Baby Food (161) is in CG 11 in 2022 byt CG 3 in 2011 
			replace commodity_group = 3 if product_code ==161 & year ==2022
			
			*REcall period change (Take breand and milk products to 7 days in 2011)
			replace value_deflated = value_deflated*7/30 if year == 2011 & inlist(product_code, 113, 160, 161, 162, 163, 164, 165, 166)
			replace qty_total = qty_total*7/30 if year == 2011 & inlist(product_code, 113, 160, 161, 162, 163, 164, 165, 166)
			replace qty_new= qty_new*7/30 if year == 2011 &  inlist(product_code, 113, 160, 161, 162, 163, 164, 165, 166)
				
			*Recode items to harmonize 2011 and 2022 (using product_code instead of item)
			clonevar product_code2 = product_code

				*khoi, lawa in 2011 is "other rice products (khoi/lawa, etc.)" in 2022
			recode product_code2 (104=106) 
			
			*coarse grains are grouped in 2022
			recode product_code2 (115=2) (116=2) (117=2) (118=2) (120=2) (121=2) 

			*Khesari in 2011 is "Other Pulses (Khesari, etc)" in 2022
			recode product_code2  (147=148) 

			*Besan in 2011 is "Besan, Gram Products" in 2022
			recode product_code2  (151=150)  

			*vanaspati, margarine in 2011 is inside a group "edible oil: others  (vanaspati, margarine, others)"
			recode product_code2 (180=95) 

			* jackfruit, pineapple (no.), singara, pears/nashpati, berries, leechi in 2011 are grouped in "other fresh fruits (litchi, pears/ nashpati, singara, jackfruit, berries, pineapple, others)" in 2022
			recode product_code2   (221=93) (223=93) (227=93) (233=93) (234=93) (235=93) (238=93)
			 
			*walnut in 2011 is  "other nuts (almond, pistachio, walnut, hazelnut, etc.)" in 2022
			recode product_code2  (244=245)  
			 
			 *coke, dung cake, coal,  charcoal, candle (no.), gobar gas, petrol (litre) [excl. conveyance], diesel (litre) [excl. conveyance] in  "other fuel&(charcoal, biogas, gobar gas, coal, dung cake, petrol (litre) [excl. conveyance], diesel (litre) [excl. conveyance], other natural gas^ (CNG, etc.), matches (box), candle (no.), etc.)" in 2022 
			 recode product_code2   (330=96) (333=96) (337=96) (340=96) (341=96) (342=96) (343=96) (344=96) 
			 
		 
			*quilt, mattress (no.) is "pillow, quilt, mattress (no.)" in 2011
			recode product_code2  (382=383)  

			*cloth for upholstery, curtains, tablecloth, etc. (metre) changed code
			recode product_code2  (383=384) 

			*mosquito net (no.) changed code 
			recode product_code2 (384=385) 

			*bedding: others changed code 
			recode product_code2  (385=386)  

			*clothing: second-hand 
			recode product_code2  (376=375) 

			*other beverages: cocoa, drinking chocolate, health drinks, etc. was "other beverages: cocoa, chocolate, etc." in 2011 
			recode product_code2  (277=278) 

			*Biscuits was "biscuits, chocolates, etc." in 2011
			recode product_code2 (291=13)
			
			************************************************************************
			
			di in red "No. of households in `y' - part `x'"
			unique hhid
		
			*Quantities and values for median price calculation	
			replace qty_new = . if qty_new == 0
			replace value_deflated = . if value_deflated == 0 //0 changes made

			gen miss_qty = mi(qty_new)
			gen miss_value = mi(value_deflated)

			*Quantities and values for average quantity calculation	
			gen qty_new_recode = qty_new
			replace qty_new_recode = 0 if qty_new==.

			*Average quantity per capita includes ALL HHs 
			gen qty_pc = qty_new/hhsize //average quantity consumed per hhid
			gen qty_pc_recode   = qty_new_recode/hhsize

			gen price = value_deflated/qty_new 
					
			preserve
				drop if mi(qty_new) | mi(value_deflated) 
				gen non_zero_obs = 1
				collapse (sum) non_zero_obs, by(state sector product_code2 commodity_group ) 
				order state sector product_code2 non_zero_obs, first
				save "${user}/data/processed/ces/sensitivity_checks/inter_temporal/temp/`y'_non_zero_obs_p`x'_all_v1.dta", replace
		restore
			
		merge m:1 state sector product_code2 using "${user}/data/processed/ces/sensitivity_checks/inter_temporal/temp/`y'_non_zero_obs_p`x'_all_v1.dta" 

			preserve
				collapse qty_avg = qty_pc  qty_avg_recode = qty_pc_recode (p50) price_st_sec = price [aw=pwt], by(state sector product_code2)
				
				tempfile median_price_avg_qty
				save `median_price_avg_qty'
			restore

		merge m:1 state sector product_code2 using `median_price_avg_qty', nogen
		
		replace price_st_sec =. if non_zero_obs<6 

			* data at State-Sector-Item level
			collapse price_st_sec qty_avg_recode qty_avg non_zero_obs, by(year state sector product_code2  commodity_group)
		
			merge m:1 year state sector using "${user}/data/processed/other/population_MoH.dta", nogen keep(3)

			gen missing_item = mi(qty_avg)
			replace missing_item = 1 if non_zero_obs<6
		 
			* replace quantity missing if non_zero_obs<6
			replace qty_avg_recode = . if missing_item==1  // make 
			
			* Drop UTs 
			drop if inlist(state, 4, 25, 31, 35)
					
			save "${user}/data/processed/ces/sensitivity_checks/inter_temporal/temp/`y'_med_price_avg_qty_p`x'_all_v1" , replace
		}	
	}

   
	
	clear
	foreach i of numlist 11 22 {
			foreach x of numlist 1(1)6 {
			append using "${user}/data/processed/ces/sensitivity_checks/inter_temporal/temp/20`i'_med_price_avg_qty_p`x'_all_v1.dta"
		}
	}


	/*=======================================================================*/
	* 4. Combine Price and Quantity
	/*=======================================================================*/
	
	keep year product_code2  commodity_group state sector price_st_sec qty_avg_recode
		
	reshape wide price_st_sec qty_avg_recode, i( state sector product_code2 commodity_group) j(year)
	
	/*=======================================================================*/
	* 5. Calculate Fisher Index
	*=======================================================================*/
	
	*NOTE: retain items only if unit values available in both 68th round and HCES22 of the state for that item
	
	*preserve 
	*keep if price_st_sec2022 ==. & price_st_sec2011 != . 
	*export excel "${output}/sensitivity_checks/inter_temporal/excel/temporal_inflation_item.xlsx", sheet("uv_dropped_2022_v1", replace) firstrow(variables)
	*restore
	
	*Items without UV in 2011 but with UV in 2011
	
	*Identify and export list of items which will be dropped for each year
	*preserve 
	*keep if price_st_sec2011 ==. & price_st_sec2022 != . 
	*export excel "${output}/sensitivity_checks/inter_temporal/excel/temporal_inflation_item.xlsx", sheet("uv_dropped_2011_v1", replace) firstrow(variables)
	*restore
	
	*Replace UVs as missing whenever unit value is missing (not in common support 2011-12)
	replace price_st_sec2022 =. if price_st_sec2011 ==.
	replace price_st_sec2011 =. if price_st_sec2022 ==.
	
	*Now replace quantities as missing whenever unit value is missing (not in common support 2011-12)
	replace qty_avg_recode2022=. if price_st_sec2022==.
	replace qty_avg_recode2011=. if price_st_sec2011==.
	
	* STEP (5.1): 2011 VALUES AT 2011 PRICES
	
	gen value_2011_2011 = qty_avg_recode2011*price_st_sec2011
	
	* STEP (5.2): 2011 VALUES AT 2022 PRICES
	
	gen value_2011_2022 = qty_avg_recode2011*price_st_sec2022
	
	* STEP (5.3): 2022 VALUES AT 2011 PRICES
	
	gen value_2022_2011 = qty_avg_recode2022*price_st_sec2011
	
	* STEP (5.4): 2022 VALUES AT 2022 PRICES
	
	gen value_2022_2022 = qty_avg_recode2022*price_st_sec2022
	
	gen price_var = ((price_st_sec2022/price_st_sec2011)^(1/11) -1)*100
		
	*Export list of items and their price variation between 2011 and 2022 for inspection
	*export excel "${output}/sensitivity_checks/inter_temporal/excel/temporal_inflation_item.xlsx", sheet("item_inflation_v1", replace) firstrow(variables)
	
	*Aggregate at the commodity group-state-sector level
	
	collapse (sum) value_2011_2011 value_2011_2022 value_2022_2011 value_2022_2022, by( state sector commodity_group)
	
	* STEP (5.5): PAASCHE AND LASPEYRES INDICES FOR EACH COMMODITY GROUP BY STATE-SECTOR
	
	gen paasche =value_2011_2022/value_2011_2011
	gen laspeyres =value_2022_2022/value_2022_2011
	gen intertemporal_fisher_v1=(paasche*laspeyres)^0.5
	
	keep state sector commodity_group intertemporal_fisher_v1
	
	* STEP (5.6) Assign spatial deflators to UTs	

	 drop if inlist(state, 4, 25, 31, 35)
	
	preserve
	keep if inlist(state, 3, 30, 32, 33)
	keep state sector commodity_group intertemporal_fisher_v1
	replace state = 4 if state==3
	replace state = 25 if state==30
	replace state = 31 if state==32
	replace state = 35 if state==33
	tempfile ut_data
	save `ut_data', replace
	restore
	
	append using `ut_data'
	sort state sector commodity_group
	
			
	* STEP (5.7) Save deflators for each survey year 
	
	*Save for 2011
	save "${user}/data/processed/ces/sensitivity_checks/inter_temporal/2011_intertemporal_deflators_all_v1.dta", replace 
	
	*Replace and save for 2022
	replace intertemporal_fisher_v1=1 
	save "${user}/data/processed/ces/sensitivity_checks/inter_temporal/2022_intertemporal_deflators_all_v1.dta", replace
					
	cap log close
	exit
	
	
	