
	loc date: display %tdCCYY-NN-DD =daily("`c(current_date)'", "DMY")
	cap log close
	log using "${user}/output/log/07_intertemporal_pov_ineq_`date'", replace

	/* =============================================================================
		Project			: India Poverty Estimates 
		Dofile			: 07_intertemporal_pov_ineq
		Last modified	: 22 Jan 2025


		Inputs			: "${output}/sensitivity_checks/inter_temporal/master_pov_input_2011_all"
						  "${output}/sensitivity_checks/inter_temporal/master_pov_input_2022_all"
						  "${other_data}/dta/cpi_master_with_ladakh.dta"
					
		Outputs			: "${user}/output/sensitivity_checks/inter_temporal/welfare_pov_final.dta"
					
	============================================================================= */

			glo 	povlines17 	215 365 685 
			scalar	ppp17	= 	19.46903992    // https://databank.worldbank.org/source/icp-2017#
				
	*===========================================================================
	*Step 2. Construct welfare aggregate in 2021 prices (for both 2011 & 2022)

	use "${user}/data/processed/ces/sensitivity_checks/inter_temporal/welfare_agg_17_all.dta", clear

	
	drop if mi(hhid)
			
	*===============================================================================
	*Step 1. Construct 2017 poverty lines, expressed in INR 2017 PPP
	*===============================================================================

	foreach i of glo povlines17 {
		gen double pline_`i'= (`i'/100)*(365/12)*ppp17
		}
			
	*===============================================================================
	*Step 2. Calculate dummies for poor households
	*===============================================================================

	foreach i of glo povlines17 {
		gen double poor_`i'  	= .
		replace poor_`i' 	= welfare_agg17_sp  <= pline_`i' 
		}	
		
			foreach i of glo povlines17 {
		gen double poor_`i'_uv1  	= .
		replace poor_`i'_uv1 	=  welfare_agg17_uvtemp_v1  <= pline_`i' 
		}	
		
			foreach i of glo povlines17 {
		gen double poor_`i'_uv2  	= .
		replace poor_`i'_uv2 	= welfare_agg17_uvtemp_v2  <= pline_`i' 
		}	

	keep hhid sector pwt year poor_* welfare_agg17* hhsize
		

	lab var poor_215 "Poverty dummy - below $2.15"
	lab var poor_365 "Poverty dummy - below $3.65"
	lab var poor_685 "Poverty dummy - below $6.85"
	
	gen poor_215_perc = poor_215*100
	gen poor_215_uv1_perc = poor_215_uv1*100
	gen poor_215_uv2_perc = poor_215_uv2*100
	
	gen poor_365_perc = poor_365*100
	gen poor_365_uv1_perc = poor_365_uv1*100
	gen poor_365_uv2_perc = poor_365_uv2*100
	
	gen poor_685_perc = poor_685*100
	gen poor_685_uv1_perc = poor_685_uv1*100
	gen poor_685_uv2_perc = poor_685_uv2*100
	
		
	di in red "Poverty rates under $2.15"
	table (sector) (year) [aw=pwt], stat(mean poor_215_perc poor_215_uv1_perc poor_215_uv2_perc) totals(year) nformat(%9.1f) sformat("%s%%") 

	di in red "Poverty rates under $3.65"
	table (sector) (year) [aw=pwt], stat(mean poor_365_perc poor_365_uv1_perc poor_365_uv2_perc) totals(year) nformat(%9.1f) sformat("%s%%") 


	di in red "Poverty rates under $6.85"
	table (sector) (year) [aw=pwt], stat(mean poor_685_perc poor_685_uv1_perc poor_685_uv2_perc) totals(year) nformat(%9.1f) sformat("%s%%") 
	
	save "${user}/output/sensitivity_checks/inter_temporal/welfare_pov_final.dta", replace
	
	*===============================================================================
	*Step 3. Calculate Gini coefficient
	*===============================================================================

	*All-India, rural and urban gini - define and store results in matrix
	mat drop _all
	foreach y of numlist 2011 2022 {		
			mat define gini_`y' = J(1, 3, .)
			mat rownames gini_`y' = `y'
			mat colnames gini_`y' = rural urban national
	foreach i of numlist 1 2 {
		ainequal welfare_agg17_sp  [aw=pwt] if sector==`i' & year==`y'
		mat gini_`y' [1,`i'] = `r(gini_1)'		
	}
	ainequal welfare_agg17_sp  [aw=pwt] if year==`y'
	mat gini_`y' [1,3] = `r(gini_1)'
	}
	
	*Matrix combine
	mat define gini = J(2,3,.)
	mat gini = gini_2011 \ gini_2022
	
	mat list gini, format(%9.4f)

				
	* =============================================================================*
		di in red "THE END OF 07_intertemporal_pov_ineq" 
	* =============================================================================*
	cap log close
	exit