
	loc date: display %tdCCYY-NN-DD =daily("`c(current_date)'", "DMY")
	cap log close
	log using "${user}/output/log/07_outliers_pov_ineq${zs}_`date'", replace

	/* =============================================================================
		Project			: India Poverty Estimates 
		Dofile			: 07_outliers_pov_ineq
		Last modified	: 22 Jan 2025

		Inputs			: "${user}/data/processed/ces/sensitivity_checks/outliers/welfare_agg_17${zs}.dta"
						
		Outputs			: "${user}/output/sensitivity_checks/outliers/welfare_pov_final${zs}.dta"
	============================================================================= */

	*Step 0. Define macros & scalars
		glo  	svy_yr 		2022 2011
		glo 	ppp_yr		21 17 
		glo 	povlines17 	215 365 685 
		glo 	povlines21 	300 420 830
		scalar 	ppp17_r = 	17.09197044372559
		scalar 	ppp17_u = 	20.78734588623047
		scalar 	ppp21 	= 	19.4689502716064  // https://databank.worldbank.org/source/icp-2021#
		scalar	ppp17	= 	19.46903992 
		glo cpi_2011 = 113.606952605421    //avg monthly cpi survey year (Jul-11 to June-12) IFS
		glo cpi_2017 = 159.181198120117    //avg monthly cpi calendar year (jan-17 to dec-17)  IFS
		glo cpi_2021 = 192.378723144531    //avg monthly cpi calendar year (jan-21 to dec-21)  IFS
		glo cpi_2022 =  211.9832504895     //avg monthly cpi survey year (Ago-22 to July-23) IFS
		

	use "${user}/data/processed/ces/sensitivity_checks/outliers/welfare_agg_17${zs}.dta", clear
			
	*===============================================================================
		*Step 1. Construct 2017 poverty lines, expressed in INR 2017 PPP
	*===============================================================================

	foreach i of glo povlines17 {
		g double pline_`i'= (`i'/100)*(365/12)*ppp17
		}
		
	*===============================================================================
		*Step 2. Calculate dummies for poor households
	*===============================================================================

	foreach i of glo povlines17 {
		gen double poor_`i'  	= .
		replace poor_`i' 	= welfare_agg17_sp <= pline_`i' 
		}	

	keep hhid sector pwt year poor_* welfare_agg17_sp hhsize
		
	lab var poor_215 "Poverty dummy - below $2.15"
	lab var poor_365 "Poverty dummy - below $3.65"
	lab var poor_685 "Poverty dummy - below $6.85"
	
	gen poor_215_perc = poor_215*100
	gen poor_365_perc = poor_365*100
	gen poor_685_perc = poor_685*100
	

	di in red "Poverty rates under $2.15"
	table sector year [aw=pwt], stat(mean poor_215_perc) totals(year) nformat(%9.1f) sformat("%s%%") 

	
	di in red "Poverty rates under $3.65"
	table sector year [aw=pwt], stat(mean poor_365_perc) totals(year) nformat(%9.1f) sformat("%s%%") 


	di in red "Poverty rates under $6.85"
	table sector year [aw=pwt], stat(mean poor_685_perc) totals(year) nformat(%9.1f) sformat("%s%%") 	

	save "${user}/output/sensitivity_checks/outliers/welfare_pov_final${zs}.dta", replace
	
	*===============================================================================
	*Step 3. Calculate Gini coefficient
	*===============================================================================

	*All-India, rural and urban gini - define and store results in matrix
	mat drop _all
	foreach y of numlist 2011 2022 {		
			mat define gini_`y' = J(1, 3, .)
			mat rownames gini_`y' = `y'
			mat colnames gini_`y' = rural urban national
	foreach i of numlist 1 2 {
		ainequal welfare_agg17_sp  [aw=pwt] if sector==`i' & year==`y'
		mat gini_`y' [1,`i'] = `r(gini_1)'		
	}
	ainequal welfare_agg17_sp  [aw=pwt] if year==`y'
	mat gini_`y' [1,3] = `r(gini_1)'
	}
	
	*Matrix combine
	mat define gini = J(2,3,.)
	mat gini = gini_2011 \ gini_2022
	
	mat list gini, format(%9.4f)
		
	* =============================================================================*
		di in red "THE END OF 07_outliers_pov_ineq" 
	* =============================================================================*
	cap log close
	exit
